Class: MethodRuby::Internal::Transport::BaseClient Abstract Private
- Inherits:
-
Object
- Object
- MethodRuby::Internal::Transport::BaseClient
- Extended by:
- Util::SorbetRuntimeSupport
- Defined in:
- lib/method_ruby/internal/transport/base_client.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Direct Known Subclasses
Constant Summary collapse
- MAX_REDIRECTS =
This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.
from whatwg fetch spec
20- PLATFORM_HEADERS =
This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.
rubocop:disable Style/MutableConstant
{ "x-stainless-arch" => MethodRuby::Internal::Util.arch, "x-stainless-lang" => "ruby", "x-stainless-os" => MethodRuby::Internal::Util.os, "x-stainless-package-version" => MethodRuby::VERSION, "x-stainless-runtime" => ::RUBY_ENGINE, "x-stainless-runtime-version" => ::RUBY_ENGINE_VERSION }
Instance Attribute Summary collapse
- #base_url ⇒ URI::Generic readonly private
- #headers ⇒ Hash{String=>String} readonly private
- #idempotency_header ⇒ String? readonly private
- #initial_retry_delay ⇒ Float readonly private
- #max_retries ⇒ Integer readonly private
- #max_retry_delay ⇒ Float readonly private
- #requester ⇒ MethodRuby::Internal::Transport::PooledNetRequester readonly private
- #timeout ⇒ Float readonly private
Class Method Summary collapse
- .follow_redirect(request, status:, response_headers:) ⇒ Hash{Symbol=>Object} private
- .reap_connection!(status, stream:) ⇒ Object private
- .should_retry?(status, headers:) ⇒ Boolean private
- .validate!(req) ⇒ Object private
Instance Method Summary collapse
-
#initialize(base_url:, timeout: 0.0, max_retries: 0, initial_retry_delay: 0.0, max_retry_delay: 0.0, headers: {}, idempotency_header: nil) ⇒ BaseClient
constructor
private
A new instance of BaseClient.
- #inspect ⇒ String private
-
#request(method, path, query: {}, headers: {}, body: nil, unwrap: nil, page: nil, stream: nil, model: MethodRuby::Internal::Type::Unknown, security: {bearer_auth: true}, options: {}) ⇒ Object
private
Execute the request specified by
req. - #send_request(request, redirect_count:, retry_count:, send_retry_header:) ⇒ Array(Integer, Net::HTTPResponse, Enumerable<String>) private
Methods included from Util::SorbetRuntimeSupport
const_missing, define_sorbet_constant!, sorbet_constant_defined?, to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(base_url:, timeout: 0.0, max_retries: 0, initial_retry_delay: 0.0, max_retry_delay: 0.0, headers: {}, idempotency_header: nil) ⇒ BaseClient
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of BaseClient.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 202 def initialize( base_url:, timeout: 0.0, max_retries: 0, initial_retry_delay: 0.0, max_retry_delay: 0.0, headers: {}, idempotency_header: nil ) @requester = MethodRuby::Internal::Transport::PooledNetRequester.new @headers = MethodRuby::Internal::Util.normalized_headers( self.class::PLATFORM_HEADERS, { "accept" => "application/json", "content-type" => "application/json", "user-agent" => user_agent }, headers ) @base_url_components = MethodRuby::Internal::Util.parse_uri(base_url) @base_url = MethodRuby::Internal::Util.unparse_uri(@base_url_components) @idempotency_header = idempotency_header&.to_s&.downcase @timeout = timeout @max_retries = max_retries @initial_retry_delay = initial_retry_delay @max_retry_delay = max_retry_delay end |
Instance Attribute Details
#base_url ⇒ URI::Generic (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
169 170 171 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 169 def base_url @base_url end |
#headers ⇒ Hash{String=>String} (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
184 185 186 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 184 def headers @headers end |
#idempotency_header ⇒ String? (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
187 188 189 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 187 def idempotency_header @idempotency_header end |
#initial_retry_delay ⇒ Float (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
178 179 180 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 178 def initial_retry_delay @initial_retry_delay end |
#max_retries ⇒ Integer (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
175 176 177 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 175 def max_retries @max_retries end |
#max_retry_delay ⇒ Float (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
181 182 183 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 181 def max_retry_delay @max_retry_delay end |
#requester ⇒ MethodRuby::Internal::Transport::PooledNetRequester (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
191 192 193 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 191 def requester @requester end |
#timeout ⇒ Float (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
172 173 174 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 172 def timeout @timeout end |
Class Method Details
.follow_redirect(request, status:, response_headers:) ⇒ Hash{Symbol=>Object}
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 103 def follow_redirect(request, status:, response_headers:) method, url, headers = request.fetch_values(:method, :url, :headers) location = Kernel.then do URI.join(url, response_headers["location"]) rescue ArgumentError = "Server responded with status #{status} but no valid location header." raise MethodRuby::Errors::APIConnectionError.new( url: url, response: response_headers, message: ) end request = {**request, url: location} case [url.scheme, location.scheme] in ["https", "http"] = "Tried to redirect to a insecure URL" raise MethodRuby::Errors::APIConnectionError.new( url: url, response: response_headers, message: ) else nil end # from whatwg fetch spec case [status, method] in [301 | 302, :post] | [303, _] drop = %w[content-encoding content-language content-length content-location content-type] request = { **request, method: method == :head ? :head : :get, headers: headers.except(*drop), body: nil } else end # from undici if MethodRuby::Internal::Util.uri_origin(url) != MethodRuby::Internal::Util.uri_origin(location) drop = %w[authorization cookie host proxy-authorization] request = {**request, headers: request.fetch(:headers).except(*drop)} end request end |
.reap_connection!(status, stream:) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
157 158 159 160 161 162 163 164 165 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 157 def reap_connection!(status, stream:) case status in (..199) | (300..499) stream&.each { next } in MethodRuby::Errors::APIConnectionError | (500..) MethodRuby::Internal::Util.close_fused!(stream) else end end |
.should_retry?(status, headers:) ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 65 def should_retry?(status, headers:) coerced = MethodRuby::Internal::Util.coerce_boolean(headers["x-should-retry"]) case [coerced, status] in [true | false, _] coerced in [_, 408 | 409 | 429 | (500..)] # retry on: # 408: timeouts # 409: locks # 429: rate limits # 500+: unknown errors true else false end end |
.validate!(req) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 33 def validate!(req) keys = [ :method, :path, :query, :headers, :body, :unwrap, :page, :stream, :model, :security, :options ] case req in Hash req.each_key do |k| unless keys.include?(k) raise ArgumentError.new("Request `req` keys must be one of #{keys}, got #{k.inspect}") end end else raise ArgumentError.new("Request `req` must be a Hash or RequestOptions, got #{req.inspect}") end end |
Instance Method Details
#inspect ⇒ String
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
541 542 543 544 545 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 541 def inspect # rubocop:disable Layout/LineLength "#<#{self.class.name}:0x#{object_id.to_s(16)} base_url=#{@base_url} max_retries=#{@max_retries} timeout=#{@timeout}>" # rubocop:enable Layout/LineLength end |
#request(method, path, query: {}, headers: {}, body: nil, unwrap: nil, page: nil, stream: nil, model: MethodRuby::Internal::Type::Unknown, security: {bearer_auth: true}, options: {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Execute the request specified by req. This is the method that all resource methods call into.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 499 def request(req) self.class.validate!(req) model = req.fetch(:model) { MethodRuby::Internal::Type::Unknown } opts = req[:options].to_h unwrap = req[:unwrap] MethodRuby::RequestOptions.validate!(opts) request = build_request(req.except(:options), opts) url = request.fetch(:url) # Don't send the current retry count in the headers if the caller modified the header defaults. send_retry_header = request.fetch(:headers)["x-stainless-retry-count"] == "0" status, response, stream = send_request( request, redirect_count: 0, retry_count: 0, send_retry_header: send_retry_header ) headers = MethodRuby::Internal::Util.normalized_headers(response.each_header.to_h) decoded = MethodRuby::Internal::Util.decode_content(headers, stream: stream) case req in {stream: Class => st} st.new( model: model, url: url, status: status, headers: headers, response: response, unwrap: unwrap, stream: decoded ) in {page: Class => page} page.new(client: self, req: req, headers: headers, page_data: decoded) else unwrapped = MethodRuby::Internal::Util.dig(decoded, unwrap) MethodRuby::Internal::Type::Converter.coerce(model, unwrapped) end end |
#send_request(request, redirect_count:, retry_count:, send_retry_header:) ⇒ Array(Integer, Net::HTTPResponse, Enumerable<String>)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 |
# File 'lib/method_ruby/internal/transport/base_client.rb', line 393 def send_request(request, redirect_count:, retry_count:, send_retry_header:) url, headers, max_retries, timeout = request.fetch_values(:url, :headers, :max_retries, :timeout) input = {**request.except(:timeout), deadline: MethodRuby::Internal::Util.monotonic_secs + timeout} if send_retry_header headers["x-stainless-retry-count"] = retry_count.to_s end begin status, response, stream = @requester.execute(input) rescue MethodRuby::Errors::APIConnectionError => e status = e end headers = MethodRuby::Internal::Util.normalized_headers(response&.each_header&.to_h) case status in ..299 [status, response, stream] in 300..399 if redirect_count >= self.class::MAX_REDIRECTS self.class.reap_connection!(status, stream: stream) = "Failed to complete the request within #{self.class::MAX_REDIRECTS} redirects." raise MethodRuby::Errors::APIConnectionError.new(url: url, response: response, message: ) in 300..399 self.class.reap_connection!(status, stream: stream) request = self.class.follow_redirect(request, status: status, response_headers: headers) send_request( request, redirect_count: redirect_count + 1, retry_count: retry_count, send_retry_header: send_retry_header ) in MethodRuby::Errors::APIConnectionError if retry_count >= max_retries raise status in (400..) if retry_count >= max_retries || !self.class.should_retry?(status, headers: headers) decoded = Kernel.then do MethodRuby::Internal::Util.decode_content(headers, stream: stream, suppress_error: true) ensure self.class.reap_connection!(status, stream: stream) end raise MethodRuby::Errors::APIStatusError.for( url: url, status: status, headers: headers, body: decoded, request: nil, response: response ) in (400..) | MethodRuby::Errors::APIConnectionError self.class.reap_connection!(status, stream: stream) delay = retry_delay(response || {}, retry_count: retry_count) sleep(delay) send_request( request, redirect_count: redirect_count, retry_count: retry_count + 1, send_retry_header: send_retry_header ) end end |