Module: MethodRuby::Models::AccountCreateParams::Body

Extended by:
Internal::Type::Union
Defined in:
lib/method_ruby/models/account_create_params.rb,
sig/method_ruby/models/account_create_params.rbs

Overview

Request body for creating an account. type is recommended and used for discrimination in generated clients, but the API can also infer the account type from the nested object you provide.

Defined Under Namespace

Classes: ACH, Clearing, DebitCard, Liability

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/account_create_params.rb', line 146

Instance Method Details

#self?.variants ⇒ ::Array[MethodRuby::Models::AccountCreateParams::body]

Returns:

  • (::Array[MethodRuby::Models::AccountCreateParams::body])


415
# File 'sig/method_ruby/models/account_create_params.rbs', line 415

def self?.variants: -> ::Array[MethodRuby::Models::AccountCreateParams::body]