Class: MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource
- Defined in:
- lib/method_ruby/models/account_create_response.rb
Defined Under Namespace
Modules: Attribute, Balance, CardBrand, ConsentStatus, LatestVerificationSession, PaymentInstrument, Payoff, Sensitive, Status, Type, Update Classes: ACH, Clearing, DebitCard, Error, Liability
Instance Attribute Summary collapse
-
#ach ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::ACH?
ACH account details.
-
#attribute ⇒ String, ...
The latest attribute ID.
-
#balance ⇒ String, ...
The latest balance ID.
-
#card_brand ⇒ String, ...
The latest card brand ID.
-
#clearing ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Clearing?
Clearing account details.
-
#consent_status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::ConsentStatus
Current consent status for data access on this account.
-
#created_at ⇒ Time
Timestamp when the account was created.
-
#debit_card ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::DebitCard?
Debit card account details.
-
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Error?
Error details when an account is disabled.
-
#holder_id ⇒ String
The entity ID that owns this account.
-
#id ⇒ String
Unique identifier for the account.
-
#latest_verification_session ⇒ String, ...
The latest verification session ID.
-
#liability ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Liability?
Liability account details.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#payment_instrument ⇒ String, ...
The latest payment instrument ID.
-
#payoff ⇒ String, ...
The latest payoff ID.
-
#products ⇒ Array<String>
Products currently active for this account.
-
#restricted_products ⇒ Array<String>
Products restricted from this account.
-
#sensitive ⇒ String, ...
The latest sensitive ID.
-
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Status
Current status of the account.
- #type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Type
-
#update ⇒ String, ...
The latest update ID.
-
#updated_at ⇒ Time
Timestamp when the account was last updated.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Sensitive::AccountSensitive)
Instance Method Summary collapse
-
#initialize(token: nil) ⇒ Object
constructor
Network token details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token: nil) ⇒ Object
Network token details. Present when type is network_token.
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 226
|
Instance Attribute Details
#ach ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::ACH?
ACH account details. Present when ‘type` is `ach`.
112 |
# File 'lib/method_ruby/models/account_create_response.rb', line 112 optional :ach, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::ACH }, nil?: true |
#attribute ⇒ String, ...
The latest attribute ID. This field is expandable. When expanded, returns the full AccountAttribute object.
119 120 121 |
# File 'lib/method_ruby/models/account_create_response.rb', line 119 optional :attribute, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Attribute }, nil?: true |
#balance ⇒ String, ...
The latest balance ID. This field is expandable. When expanded, returns the full AccountBalance object.
128 129 130 |
# File 'lib/method_ruby/models/account_create_response.rb', line 128 optional :balance, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Balance }, nil?: true |
#card_brand ⇒ String, ...
The latest card brand ID. This field is expandable. When expanded, returns the full AccountCardBrand object.
137 138 139 |
# File 'lib/method_ruby/models/account_create_response.rb', line 137 optional :card_brand, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::CardBrand }, nil?: true |
#clearing ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Clearing?
Clearing account details. Present when ‘type` is `clearing`.
145 146 147 |
# File 'lib/method_ruby/models/account_create_response.rb', line 145 optional :clearing, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Clearing }, nil?: true |
#consent_status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::ConsentStatus
Current consent status for data access on this account.
64 65 |
# File 'lib/method_ruby/models/account_create_response.rb', line 64 required :consent_status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::ConsentStatus } |
#created_at ⇒ Time
Timestamp when the account was created.
71 |
# File 'lib/method_ruby/models/account_create_response.rb', line 71 required :created_at, Time |
#debit_card ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::DebitCard?
Debit card account details. Present when ‘type` is `debit_card`.
153 154 155 |
# File 'lib/method_ruby/models/account_create_response.rb', line 153 optional :debit_card, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::DebitCard }, nil?: true |
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Error?
Error details when an account is disabled.
161 162 163 |
# File 'lib/method_ruby/models/account_create_response.rb', line 161 optional :error, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Error }, nil?: true |
#holder_id ⇒ String
The entity ID that owns this account.
77 |
# File 'lib/method_ruby/models/account_create_response.rb', line 77 required :holder_id, String |
#id ⇒ String
Unique identifier for the account.
58 |
# File 'lib/method_ruby/models/account_create_response.rb', line 58 required :id, String |
#latest_verification_session ⇒ String, ...
The latest verification session ID. This field is expandable. When expanded, returns the full AccountVerificationSession object.
170 171 172 |
# File 'lib/method_ruby/models/account_create_response.rb', line 170 optional :latest_verification_session, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession }, nil?: true |
#liability ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Liability?
Liability account details. Present when ‘type` is `liability`.
178 179 180 |
# File 'lib/method_ruby/models/account_create_response.rb', line 178 optional :liability, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Liability }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
186 187 188 |
# File 'lib/method_ruby/models/account_create_response.rb', line 186 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#payment_instrument ⇒ String, ...
The latest payment instrument ID. This field is expandable. When expanded, returns the full AccountPaymentInstrument object.
195 196 197 |
# File 'lib/method_ruby/models/account_create_response.rb', line 195 optional :payment_instrument, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::PaymentInstrument }, nil?: true |
#payoff ⇒ String, ...
The latest payoff ID. This field is expandable. When expanded, returns the full AccountPayoff object.
204 205 206 |
# File 'lib/method_ruby/models/account_create_response.rb', line 204 optional :payoff, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Payoff }, nil?: true |
#products ⇒ Array<String>
Products currently active for this account.
83 |
# File 'lib/method_ruby/models/account_create_response.rb', line 83 required :products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_products ⇒ Array<String>
Products restricted from this account.
89 |
# File 'lib/method_ruby/models/account_create_response.rb', line 89 required :restricted_products, MethodRuby::Internal::Type::ArrayOf[String] |
#sensitive ⇒ String, ...
The latest sensitive ID. This field is expandable. When expanded, returns the full AccountSensitive object.
213 214 215 |
# File 'lib/method_ruby/models/account_create_response.rb', line 213 optional :sensitive, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Sensitive }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Status
Current status of the account.
95 |
# File 'lib/method_ruby/models/account_create_response.rb', line 95 required :status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Status } |
#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Type
100 |
# File 'lib/method_ruby/models/account_create_response.rb', line 100 required :type, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Type } |
#update ⇒ String, ...
The latest update ID. This field is expandable. When expanded, returns the full AccountUpdate object.
222 223 224 |
# File 'lib/method_ruby/models/account_create_response.rb', line 222 optional :update, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Update }, nil?: true |
#updated_at ⇒ Time
Timestamp when the account was last updated.
106 |
# File 'lib/method_ruby/models/account_create_response.rb', line 106 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 287
|
.variants ⇒ Array(String, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::Sensitive::AccountSensitive)
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 451
|