Class: MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession
- Defined in:
- lib/method_ruby/models/account_create_response.rb
Defined Under Namespace
Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this verification session belongs to.
-
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
-
#created_at ⇒ Time
Timestamp when the verification session was created.
-
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
-
#id ⇒ String
Unique identifier for the verification session.
-
#instant ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
-
#micro_deposits ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
-
#mx ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
-
#network ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
-
#plaid ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
-
#pre_auth ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
-
#standard ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
-
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
-
#teller ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
-
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
-
#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
-
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(number: nil) ⇒ Object
constructor
Populated when the verification session is of type standard.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(number: nil) ⇒ Object
Populated when the verification session is of type standard.
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 1162
|
Instance Attribute Details
#account_id ⇒ String
The account this verification session belongs to.
1050 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1050 required :account_id, String |
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
1082 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1082 optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true |
#created_at ⇒ Time
Timestamp when the verification session was created.
1056 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1056 required :created_at, Time |
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
1088 1089 1090 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1088 optional :error, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Error }, nil?: true |
#id ⇒ String
Unique identifier for the verification session.
1044 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1044 required :id, String |
#instant ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
1096 1097 1098 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1096 optional :instant, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant }, nil?: true |
#micro_deposits ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
1104 1105 1106 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1104 optional :micro_deposits, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits }, nil?: true |
#mx ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
1112 1113 1114 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1112 optional :mx, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Mx }, nil?: true |
#network ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
1120 1121 1122 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1120 optional :network, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network }, nil?: true |
#plaid ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
1128 1129 1130 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1128 optional :plaid, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Plaid }, nil?: true |
#pre_auth ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
1136 1137 1138 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1136 optional :pre_auth, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth }, nil?: true |
#standard ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
1144 1145 1146 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1144 optional :standard, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Standard }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
1062 1063 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1062 required :status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Status } |
#teller ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
1152 1153 1154 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1152 optional :teller, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Teller }, nil?: true |
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
1160 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1160 optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
1069 1070 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1069 required :type, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Type } |
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
1076 |
# File 'lib/method_ruby/models/account_create_response.rb', line 1076 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 1210
|