Class: MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/account_create_response.rb,
sig/method_ruby/models/account_create_response.rbs

Overview

See Also:

  • MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession#network

Defined Under Namespace

Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, NetworkCheck

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, network_check: nil, number: nil) ⇒ Object

Populated when the verification session is of type network.

Parameters:



# File 'lib/method_ruby/models/account_create_response.rb', line 1474


Instance Attribute Details

#billing_zip_code ⇒ String?

The masked billing zip code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1416
# File 'lib/method_ruby/models/account_create_response.rb', line 1416

optional :billing_zip_code, String, nil?: true

#billing_zip_code_check ⇒ Symbol, ...

The billing zip code verification check result.

Parameters:

  • value (MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network::billing_zip_code_check, nil)

Returns:



1422
1423
1424
# File 'lib/method_ruby/models/account_create_response.rb', line 1422

optional :billing_zip_code_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network::BillingZipCodeCheck },
nil?: true

#cvv ⇒ String?

The masked card CVV. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1430
# File 'lib/method_ruby/models/account_create_response.rb', line 1430

optional :cvv, String, nil?: true

#cvv_check ⇒ Symbol, ...

The card CVV verification check result.

Parameters:

  • value (MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network::cvv_check, nil)

Returns:



1436
1437
1438
# File 'lib/method_ruby/models/account_create_response.rb', line 1436

optional :cvv_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network::CvvCheck },
nil?: true

#exp_check ⇒ Symbol, ...

The card expiration verification check result.

Parameters:

  • value (MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network::exp_check, nil)

Returns:



1444
1445
1446
# File 'lib/method_ruby/models/account_create_response.rb', line 1444

optional :exp_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network::ExpCheck },
nil?: true

#exp_month ⇒ String?

The masked card expiration month. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1452
# File 'lib/method_ruby/models/account_create_response.rb', line 1452

optional :exp_month, String, nil?: true

#exp_year ⇒ String?

The masked card expiration year. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1458
# File 'lib/method_ruby/models/account_create_response.rb', line 1458

optional :exp_year, String, nil?: true

#network_check ⇒ Symbol, ...

The network verification check result.

Parameters:

  • value (MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network::network_check, nil)

Returns:



1464
1465
1466
# File 'lib/method_ruby/models/account_create_response.rb', line 1464

optional :network_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network::NetworkCheck },
nil?: true

#number ⇒ String?

The masked card number. Null if the number still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1472
# File 'lib/method_ruby/models/account_create_response.rb', line 1472

optional :number, String, nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/account_create_response.rb', line 1505


Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1130
# File 'sig/method_ruby/models/account_create_response.rbs', line 1130

def to_hash: -> {