Class: MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource
- Defined in:
- lib/method_ruby/models/account_create_response.rb
Defined Under Namespace
Modules: Attribute, Balance, CardBrand, ConsentStatus, LatestVerificationSession, PaymentInstrument, Payoff, Sensitive, Status, Type, Update Classes: ACH, Clearing, DebitCard, Error, Liability
Instance Attribute Summary collapse
-
#ach ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::ACH?
ACH account details.
-
#attribute ⇒ String, ...
The latest attribute ID.
-
#balance ⇒ String, ...
The latest balance ID.
-
#card_brand ⇒ String, ...
The latest card brand ID.
-
#clearing ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Clearing?
Clearing account details.
-
#consent_status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::ConsentStatus
Current consent status for data access on this account.
-
#created_at ⇒ Time
Timestamp when the account was created.
-
#debit_card ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::DebitCard?
Debit card account details.
-
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Error?
Error details when an account is disabled.
-
#holder_id ⇒ String
The entity ID that owns this account.
-
#id ⇒ String
Unique identifier for the account.
-
#latest_verification_session ⇒ String, ...
The latest verification session ID.
-
#liability ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Liability?
Liability account details.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#payment_instrument ⇒ String, ...
The latest payment instrument ID.
-
#payoff ⇒ String, ...
The latest payoff ID.
-
#products ⇒ Array<String>
Products currently active for this account.
-
#restricted_products ⇒ Array<String>
Products restricted from this account.
-
#sensitive ⇒ String, ...
The latest sensitive ID.
-
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Status
Current status of the account.
- #type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Type
-
#update ⇒ String, ...
The latest update ID.
-
#updated_at ⇒ Time
Timestamp when the account was last updated.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Sensitive::AccountSensitive)
Instance Method Summary collapse
-
#initialize(token: nil) ⇒ Object
constructor
Network token details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token: nil) ⇒ Object
Network token details. Present when type is network_token.
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 7398
|
Instance Attribute Details
#ach ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::ACH?
ACH account details. Present when ‘type` is `ach`.
7282 7283 7284 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7282 optional :ach, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::ACH }, nil?: true |
#attribute ⇒ String, ...
The latest attribute ID. This field is expandable. When expanded, returns the full AccountAttribute object.
7291 7292 7293 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7291 optional :attribute, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Attribute }, nil?: true |
#balance ⇒ String, ...
The latest balance ID. This field is expandable. When expanded, returns the full AccountBalance object.
7300 7301 7302 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7300 optional :balance, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Balance }, nil?: true |
#card_brand ⇒ String, ...
The latest card brand ID. This field is expandable. When expanded, returns the full AccountCardBrand object.
7309 7310 7311 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7309 optional :card_brand, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::CardBrand }, nil?: true |
#clearing ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Clearing?
Clearing account details. Present when ‘type` is `clearing`.
7317 7318 7319 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7317 optional :clearing, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Clearing }, nil?: true |
#consent_status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::ConsentStatus
Current consent status for data access on this account.
7232 7233 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7232 required :consent_status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::ConsentStatus } |
#created_at ⇒ Time
Timestamp when the account was created.
7239 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7239 required :created_at, Time |
#debit_card ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::DebitCard?
Debit card account details. Present when ‘type` is `debit_card`.
7325 7326 7327 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7325 optional :debit_card, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::DebitCard }, nil?: true |
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Error?
Error details when an account is disabled.
7333 7334 7335 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7333 optional :error, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Error }, nil?: true |
#holder_id ⇒ String
The entity ID that owns this account.
7245 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7245 required :holder_id, String |
#id ⇒ String
Unique identifier for the account.
7226 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7226 required :id, String |
#latest_verification_session ⇒ String, ...
The latest verification session ID. This field is expandable. When expanded, returns the full AccountVerificationSession object.
7342 7343 7344 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7342 optional :latest_verification_session, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession }, nil?: true |
#liability ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Liability?
Liability account details. Present when ‘type` is `liability`.
7350 7351 7352 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7350 optional :liability, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Liability }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
7358 7359 7360 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7358 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#payment_instrument ⇒ String, ...
The latest payment instrument ID. This field is expandable. When expanded, returns the full AccountPaymentInstrument object.
7367 7368 7369 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7367 optional :payment_instrument, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::PaymentInstrument }, nil?: true |
#payoff ⇒ String, ...
The latest payoff ID. This field is expandable. When expanded, returns the full AccountPayoff object.
7376 7377 7378 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7376 optional :payoff, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Payoff }, nil?: true |
#products ⇒ Array<String>
Products currently active for this account.
7251 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7251 required :products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_products ⇒ Array<String>
Products restricted from this account.
7257 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7257 required :restricted_products, MethodRuby::Internal::Type::ArrayOf[String] |
#sensitive ⇒ String, ...
The latest sensitive ID. This field is expandable. When expanded, returns the full AccountSensitive object.
7385 7386 7387 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7385 optional :sensitive, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Sensitive }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Status
Current status of the account.
7263 7264 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7263 required :status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Status } |
#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Type
7269 7270 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7269 required :type, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Type } |
#update ⇒ String, ...
The latest update ID. This field is expandable. When expanded, returns the full AccountUpdate object.
7394 7395 7396 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7394 optional :update, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Update }, nil?: true |
#updated_at ⇒ Time
Timestamp when the account was last updated.
7276 |
# File 'lib/method_ruby/models/account_create_response.rb', line 7276 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 7459
|
.variants ⇒ Array(String, MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::Sensitive::AccountSensitive)
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 7623
|