Class: MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/account_create_response.rb,
sig/method_ruby/models/account_create_response.rbs

Defined Under Namespace

Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(number: nil) ⇒ Object

Populated when the verification session is of type standard.

Parameters:

  • number (String, nil) (defaults to: nil) —

    The masked card number. Null if the number still needs to be provided.



# File 'lib/method_ruby/models/account_create_response.rb', line 8338

Instance Attribute Details

#account_id ⇒ String

The account this verification session belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


8226
# File 'lib/method_ruby/models/account_create_response.rb', line 8226

required :account_id, String

#auto_verify ⇒ Object?

Populated when the verification session is of type auto_verify.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


8258
# File 'lib/method_ruby/models/account_create_response.rb', line 8258

optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true

#created_at ⇒ Time

Timestamp when the verification session was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


8232
# File 'lib/method_ruby/models/account_create_response.rb', line 8232

required :created_at, Time

#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Error?

Error details when an account verification session fails.



8264
8265
8266
# File 'lib/method_ruby/models/account_create_response.rb', line 8264

optional :error,
-> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Error },
nil?: true

#id ⇒ String

Unique identifier for the verification session.

Parameters:

  • value (String)

Returns:

  • (String)


8220
# File 'lib/method_ruby/models/account_create_response.rb', line 8220

required :id, String

#instant ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Instant?

Populated when the verification session is of type instant.



8272
8273
8274
# File 'lib/method_ruby/models/account_create_response.rb', line 8272

optional :instant,
-> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Instant },
nil?: true

#micro_deposits ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?

Populated when the verification session is of type micro_deposits.



8280
8281
8282
# File 'lib/method_ruby/models/account_create_response.rb', line 8280

optional :micro_deposits,
-> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits },
nil?: true

#mx ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Mx?

Populated when the verification session is of type mx.



8288
8289
8290
# File 'lib/method_ruby/models/account_create_response.rb', line 8288

optional :mx,
-> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Mx },
nil?: true

#network ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network?

Populated when the verification session is of type network.



8296
8297
8298
# File 'lib/method_ruby/models/account_create_response.rb', line 8296

optional :network,
-> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network },
nil?: true

#plaid ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Plaid?

Populated when the verification session is of type plaid.



8304
8305
8306
# File 'lib/method_ruby/models/account_create_response.rb', line 8304

optional :plaid,
-> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Plaid },
nil?: true

#pre_auth ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth?

Populated when the verification session is of type pre_auth.



8312
8313
8314
# File 'lib/method_ruby/models/account_create_response.rb', line 8312

optional :pre_auth,
-> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth },
nil?: true

#standard ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Standard?

Populated when the verification session is of type standard.



8320
8321
8322
# File 'lib/method_ruby/models/account_create_response.rb', line 8320

optional :standard,
-> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Standard },
nil?: true

#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Status

Current status of the verification session.

Parameters:

  • value (MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::status)

Returns:



8238
8239
# File 'lib/method_ruby/models/account_create_response.rb', line 8238

required :status,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Status }

#teller ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Teller?

Populated when the verification session is of type teller.



8328
8329
8330
# File 'lib/method_ruby/models/account_create_response.rb', line 8328

optional :teller,
-> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Teller },
nil?: true

#trusted_provisioner ⇒ Object?

Populated when the verification session is of type trusted_provisioner.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


8336
# File 'lib/method_ruby/models/account_create_response.rb', line 8336

optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true

#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Type

The type of verification.

Parameters:

  • value (MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::type_)

Returns:



8245
8246
# File 'lib/method_ruby/models/account_create_response.rb', line 8245

required :type,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Type }

#updated_at ⇒ Time

Timestamp when the verification session was last updated.

Parameters:

  • value (Time)

Returns:

  • (Time)


8252
# File 'lib/method_ruby/models/account_create_response.rb', line 8252

required :updated_at, Time

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/account_create_response.rb', line 8386

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


6472
# File 'sig/method_ruby/models/account_create_response.rbs', line 6472

def to_hash: -> {