Class: MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/account_create_response.rb

Overview

See Also:

Defined Under Namespace

Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, NetworkCheck

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, network_check: nil, number: nil) ⇒ Object

Populated when the verification session is of type network.

Parameters:



# File 'lib/method_ruby/models/account_create_response.rb', line 8650

Instance Attribute Details

#billing_zip_codeString?

The masked billing zip code.

Returns:

  • (String, nil)


8592
# File 'lib/method_ruby/models/account_create_response.rb', line 8592

optional :billing_zip_code, String, nil?: true

#billing_zip_code_checkSymbol, ...

The billing zip code verification check result.



8598
8599
8600
# File 'lib/method_ruby/models/account_create_response.rb', line 8598

optional :billing_zip_code_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network::BillingZipCodeCheck },
nil?: true

#cvvString?

The masked card CVV. Null if it still needs to be provided.

Returns:

  • (String, nil)


8606
# File 'lib/method_ruby/models/account_create_response.rb', line 8606

optional :cvv, String, nil?: true

#cvv_checkSymbol, ...

The card CVV verification check result.



8612
8613
8614
# File 'lib/method_ruby/models/account_create_response.rb', line 8612

optional :cvv_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network::CvvCheck },
nil?: true

#exp_checkSymbol, ...

The card expiration verification check result.



8620
8621
8622
# File 'lib/method_ruby/models/account_create_response.rb', line 8620

optional :exp_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network::ExpCheck },
nil?: true

#exp_monthString?

The masked card expiration month. Null if it still needs to be provided.

Returns:

  • (String, nil)


8628
# File 'lib/method_ruby/models/account_create_response.rb', line 8628

optional :exp_month, String, nil?: true

#exp_yearString?

The masked card expiration year. Null if it still needs to be provided.

Returns:

  • (String, nil)


8634
# File 'lib/method_ruby/models/account_create_response.rb', line 8634

optional :exp_year, String, nil?: true

#network_checkSymbol, ...

The network verification check result.



8640
8641
8642
# File 'lib/method_ruby/models/account_create_response.rb', line 8640

optional :network_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network::NetworkCheck },
nil?: true

#numberString?

The masked card number. Null if the number still needs to be provided.

Returns:

  • (String, nil)


8648
# File 'lib/method_ruby/models/account_create_response.rb', line 8648

optional :number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/account_create_response.rb', line 8681