Class: MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource
- Defined in:
- lib/method_ruby/models/account_create_response.rb
Defined Under Namespace
Modules: Attribute, Balance, CardBrand, ConsentStatus, LatestVerificationSession, PaymentInstrument, Payoff, Sensitive, Status, Type, Update Classes: ACH, Clearing, DebitCard, Error, Liability
Instance Attribute Summary collapse
-
#ach ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::ACH?
ACH account details.
-
#attribute ⇒ String, ...
The latest attribute ID.
-
#balance ⇒ String, ...
The latest balance ID.
-
#card_brand ⇒ String, ...
The latest card brand ID.
-
#clearing ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Clearing?
Clearing account details.
-
#consent_status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::ConsentStatus
Current consent status for data access on this account.
-
#created_at ⇒ Time
Timestamp when the account was created.
-
#debit_card ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::DebitCard?
Debit card account details.
-
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Error?
Error details when an account is disabled.
-
#holder_id ⇒ String
The entity ID that owns this account.
-
#id ⇒ String
Unique identifier for the account.
-
#latest_verification_session ⇒ String, ...
The latest verification session ID.
-
#liability ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Liability?
Liability account details.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#payment_instrument ⇒ String, ...
The latest payment instrument ID.
-
#payoff ⇒ String, ...
The latest payoff ID.
-
#products ⇒ Array<String>
Products currently active for this account.
-
#restricted_products ⇒ Array<String>
Products restricted from this account.
-
#sensitive ⇒ String, ...
The latest sensitive ID.
-
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Status
Current status of the account.
- #type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Type
-
#update ⇒ String, ...
The latest update ID.
-
#updated_at ⇒ Time
Timestamp when the account was last updated.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Sensitive::AccountSensitive)
Instance Method Summary collapse
-
#initialize(token: nil) ⇒ Object
constructor
Network token details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token: nil) ⇒ Object
Network token details. Present when type is network_token.
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 10976
|
Instance Attribute Details
#ach ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::ACH?
ACH account details. Present when ‘type` is `ach`.
10860 10861 10862 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10860 optional :ach, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::ACH }, nil?: true |
#attribute ⇒ String, ...
The latest attribute ID. This field is expandable. When expanded, returns the full AccountAttribute object.
10869 10870 10871 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10869 optional :attribute, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Attribute }, nil?: true |
#balance ⇒ String, ...
The latest balance ID. This field is expandable. When expanded, returns the full AccountBalance object.
10878 10879 10880 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10878 optional :balance, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Balance }, nil?: true |
#card_brand ⇒ String, ...
The latest card brand ID. This field is expandable. When expanded, returns the full AccountCardBrand object.
10887 10888 10889 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10887 optional :card_brand, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::CardBrand }, nil?: true |
#clearing ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Clearing?
Clearing account details. Present when ‘type` is `clearing`.
10895 10896 10897 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10895 optional :clearing, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Clearing }, nil?: true |
#consent_status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::ConsentStatus
Current consent status for data access on this account.
10810 10811 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10810 required :consent_status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::ConsentStatus } |
#created_at ⇒ Time
Timestamp when the account was created.
10817 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10817 required :created_at, Time |
#debit_card ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::DebitCard?
Debit card account details. Present when ‘type` is `debit_card`.
10903 10904 10905 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10903 optional :debit_card, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::DebitCard }, nil?: true |
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Error?
Error details when an account is disabled.
10911 10912 10913 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10911 optional :error, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Error }, nil?: true |
#holder_id ⇒ String
The entity ID that owns this account.
10823 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10823 required :holder_id, String |
#id ⇒ String
Unique identifier for the account.
10804 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10804 required :id, String |
#latest_verification_session ⇒ String, ...
The latest verification session ID. This field is expandable. When expanded, returns the full AccountVerificationSession object.
10920 10921 10922 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10920 optional :latest_verification_session, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession }, nil?: true |
#liability ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Liability?
Liability account details. Present when ‘type` is `liability`.
10928 10929 10930 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10928 optional :liability, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Liability }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
10936 10937 10938 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10936 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#payment_instrument ⇒ String, ...
The latest payment instrument ID. This field is expandable. When expanded, returns the full AccountPaymentInstrument object.
10945 10946 10947 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10945 optional :payment_instrument, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::PaymentInstrument }, nil?: true |
#payoff ⇒ String, ...
The latest payoff ID. This field is expandable. When expanded, returns the full AccountPayoff object.
10954 10955 10956 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10954 optional :payoff, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Payoff }, nil?: true |
#products ⇒ Array<String>
Products currently active for this account.
10829 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10829 required :products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_products ⇒ Array<String>
Products restricted from this account.
10835 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10835 required :restricted_products, MethodRuby::Internal::Type::ArrayOf[String] |
#sensitive ⇒ String, ...
The latest sensitive ID. This field is expandable. When expanded, returns the full AccountSensitive object.
10963 10964 10965 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10963 optional :sensitive, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Sensitive }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Status
Current status of the account.
10841 10842 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10841 required :status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Status } |
#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Type
10847 10848 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10847 required :type, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Type } |
#update ⇒ String, ...
The latest update ID. This field is expandable. When expanded, returns the full AccountUpdate object.
10972 10973 10974 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10972 optional :update, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Update }, nil?: true |
#updated_at ⇒ Time
Timestamp when the account was last updated.
10854 |
# File 'lib/method_ruby/models/account_create_response.rb', line 10854 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 11037
|
.variants ⇒ Array(String, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::Sensitive::AccountSensitive)
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 11201
|