Class: MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession
- Defined in:
- lib/method_ruby/models/account_create_response.rb
Defined Under Namespace
Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this verification session belongs to.
-
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
-
#created_at ⇒ Time
Timestamp when the verification session was created.
-
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
-
#id ⇒ String
Unique identifier for the verification session.
-
#instant ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
-
#micro_deposits ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
-
#mx ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
-
#network ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
-
#plaid ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
-
#pre_auth ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
-
#standard ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
-
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
-
#teller ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
-
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
-
#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
-
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(number: nil) ⇒ Object
constructor
Populated when the verification session is of type standard.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(number: nil) ⇒ Object
Populated when the verification session is of type standard.
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 11916
|
Instance Attribute Details
#account_id ⇒ String
The account this verification session belongs to.
11804 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11804 required :account_id, String |
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
11836 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11836 optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true |
#created_at ⇒ Time
Timestamp when the verification session was created.
11810 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11810 required :created_at, Time |
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
11842 11843 11844 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11842 optional :error, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Error }, nil?: true |
#id ⇒ String
Unique identifier for the verification session.
11798 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11798 required :id, String |
#instant ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
11850 11851 11852 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11850 optional :instant, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Instant }, nil?: true |
#micro_deposits ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
11858 11859 11860 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11858 optional :micro_deposits, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits }, nil?: true |
#mx ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
11866 11867 11868 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11866 optional :mx, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Mx }, nil?: true |
#network ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
11874 11875 11876 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11874 optional :network, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network }, nil?: true |
#plaid ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
11882 11883 11884 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11882 optional :plaid, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Plaid }, nil?: true |
#pre_auth ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
11890 11891 11892 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11890 optional :pre_auth, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth }, nil?: true |
#standard ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
11898 11899 11900 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11898 optional :standard, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Standard }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
11816 11817 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11816 required :status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Status } |
#teller ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
11906 11907 11908 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11906 optional :teller, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Teller }, nil?: true |
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
11914 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11914 optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
11823 11824 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11823 required :type, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Type } |
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
11830 |
# File 'lib/method_ruby/models/account_create_response.rb', line 11830 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 11964
|