Class: MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/account_create_response.rb,
sig/method_ruby/models/account_create_response.rbs

Overview

See Also:

  • MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession#pre_auth

Defined Under Namespace

Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, PreAuthCheck

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, number: nil, pre_auth_check: nil) ⇒ Object

Populated when the verification session is of type pre_auth.

Parameters:



# File 'lib/method_ruby/models/account_create_response.rb', line 12392

Instance Attribute Details

#billing_zip_code ⇒ String?

The masked billing zip code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


12334
# File 'lib/method_ruby/models/account_create_response.rb', line 12334

optional :billing_zip_code, String, nil?: true

#billing_zip_code_check ⇒ Symbol, ...

The billing zip code verification check result.

Parameters:

  • value (MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::billing_zip_code_check, nil)

Returns:



12340
12341
12342
# File 'lib/method_ruby/models/account_create_response.rb', line 12340

optional :billing_zip_code_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::BillingZipCodeCheck },
nil?: true

#cvv ⇒ String?

The masked card CVV. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


12348
# File 'lib/method_ruby/models/account_create_response.rb', line 12348

optional :cvv, String, nil?: true

#cvv_check ⇒ Symbol, ...

The card CVV verification check result.

Parameters:

  • value (MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::cvv_check, nil)

Returns:



12354
12355
12356
# File 'lib/method_ruby/models/account_create_response.rb', line 12354

optional :cvv_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::CvvCheck },
nil?: true

#exp_check ⇒ Symbol, ...

The card expiration verification check result.

Parameters:

  • value (MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::exp_check, nil)

Returns:



12362
12363
12364
# File 'lib/method_ruby/models/account_create_response.rb', line 12362

optional :exp_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::ExpCheck },
nil?: true

#exp_month ⇒ String?

The masked card expiration month. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


12370
# File 'lib/method_ruby/models/account_create_response.rb', line 12370

optional :exp_month, String, nil?: true

#exp_year ⇒ String?

The masked card expiration year. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


12376
# File 'lib/method_ruby/models/account_create_response.rb', line 12376

optional :exp_year, String, nil?: true

#number ⇒ String?

The masked card number. Null if the number still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


12382
# File 'lib/method_ruby/models/account_create_response.rb', line 12382

optional :number, String, nil?: true

#pre_auth_check ⇒ Symbol, ...

The pre-auth verification check result.

Parameters:

  • value (MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::pre_auth_check, nil)

Returns:



12388
12389
12390
# File 'lib/method_ruby/models/account_create_response.rb', line 12388

optional :pre_auth_check,
enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::PreAuthCheck },
nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/account_create_response.rb', line 12423

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


9645
# File 'sig/method_ruby/models/account_create_response.rbs', line 9645

def to_hash: -> {