Class: MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource
- Defined in:
- lib/method_ruby/models/account_create_response.rb
Defined Under Namespace
Modules: Attribute, Balance, CardBrand, ConsentStatus, LatestVerificationSession, PaymentInstrument, Payoff, Sensitive, Status, Type, Update Classes: ACH, Clearing, DebitCard, Error, Liability
Instance Attribute Summary collapse
-
#ach ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::ACH?
ACH account details.
-
#attribute ⇒ String, ...
The latest attribute ID.
-
#available_subscriptions ⇒ Array<String>
Subscriptions available to be enrolled for this account.
-
#balance ⇒ String, ...
The latest balance ID.
-
#card_brand ⇒ String, ...
The latest card brand ID.
-
#clearing ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Clearing?
Clearing account details.
-
#consent_status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::ConsentStatus
Current consent status for data access on this account.
-
#created_at ⇒ Time
Timestamp when the account was created.
-
#debit_card ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::DebitCard?
Debit card account details.
-
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Error?
Error details when an account is disabled.
-
#holder_id ⇒ String
The entity ID that owns this account.
-
#id ⇒ String
Unique identifier for the account.
-
#latest_verification_session ⇒ String, ...
The latest verification session ID.
-
#liability ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Liability?
Liability account details.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#payment_instrument ⇒ String, ...
The latest payment instrument ID.
-
#payoff ⇒ String, ...
The latest payoff ID.
-
#products ⇒ Array<String>
Products currently active for this account.
-
#restricted_products ⇒ Array<String>
Products restricted from this account.
-
#restricted_subscriptions ⇒ Array<String>
Subscriptions restricted from this account.
-
#sensitive ⇒ String, ...
The latest sensitive ID.
-
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Status
Current status of the account.
-
#subscriptions ⇒ Array<String>
Subscriptions currently active for this account.
- #type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Type
-
#update ⇒ String, ...
The latest update ID.
-
#updated_at ⇒ Time
Timestamp when the account was last updated.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Sensitive::AccountSensitive)
Instance Method Summary collapse
-
#initialize(token: nil) ⇒ Object
constructor
Network token details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token: nil) ⇒ Object
Network token details. Present when type is network_token.
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 3814
|
Instance Attribute Details
#ach ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::ACH?
ACH account details. Present when ‘type` is `ach`.
3698 3699 3700 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3698 optional :ach, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::ACH }, nil?: true |
#attribute ⇒ String, ...
The latest attribute ID. This field is expandable. When expanded, returns the full AccountAttribute object.
3707 3708 3709 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3707 optional :attribute, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Attribute }, nil?: true |
#available_subscriptions ⇒ Array<String>
Subscriptions available to be enrolled for this account.
3630 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3630 required :available_subscriptions, MethodRuby::Internal::Type::ArrayOf[String] |
#balance ⇒ String, ...
The latest balance ID. This field is expandable. When expanded, returns the full AccountBalance object.
3716 3717 3718 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3716 optional :balance, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Balance }, nil?: true |
#card_brand ⇒ String, ...
The latest card brand ID. This field is expandable. When expanded, returns the full AccountCardBrand object.
3725 3726 3727 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3725 optional :card_brand, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::CardBrand }, nil?: true |
#clearing ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Clearing?
Clearing account details. Present when ‘type` is `clearing`.
3733 3734 3735 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3733 optional :clearing, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Clearing }, nil?: true |
#consent_status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::ConsentStatus
Current consent status for data access on this account.
3636 3637 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3636 required :consent_status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::ConsentStatus } |
#created_at ⇒ Time
Timestamp when the account was created.
3643 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3643 required :created_at, Time |
#debit_card ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::DebitCard?
Debit card account details. Present when ‘type` is `debit_card`.
3741 3742 3743 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3741 optional :debit_card, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::DebitCard }, nil?: true |
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Error?
Error details when an account is disabled.
3749 3750 3751 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3749 optional :error, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Error }, nil?: true |
#holder_id ⇒ String
The entity ID that owns this account.
3649 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3649 required :holder_id, String |
#id ⇒ String
Unique identifier for the account.
3624 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3624 required :id, String |
#latest_verification_session ⇒ String, ...
The latest verification session ID. This field is expandable. When expanded, returns the full AccountVerificationSession object.
3758 3759 3760 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3758 optional :latest_verification_session, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession }, nil?: true |
#liability ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Liability?
Liability account details. Present when ‘type` is `liability`.
3766 3767 3768 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3766 optional :liability, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Liability }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
3774 3775 3776 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3774 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#payment_instrument ⇒ String, ...
The latest payment instrument ID. This field is expandable. When expanded, returns the full AccountPaymentInstrument object.
3783 3784 3785 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3783 optional :payment_instrument, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::PaymentInstrument }, nil?: true |
#payoff ⇒ String, ...
The latest payoff ID. This field is expandable. When expanded, returns the full AccountPayoff object.
3792 3793 3794 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3792 optional :payoff, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Payoff }, nil?: true |
#products ⇒ Array<String>
Products currently active for this account.
3655 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3655 required :products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_products ⇒ Array<String>
Products restricted from this account.
3661 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3661 required :restricted_products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_subscriptions ⇒ Array<String>
Subscriptions restricted from this account.
3667 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3667 required :restricted_subscriptions, MethodRuby::Internal::Type::ArrayOf[String] |
#sensitive ⇒ String, ...
The latest sensitive ID. This field is expandable. When expanded, returns the full AccountSensitive object.
3801 3802 3803 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3801 optional :sensitive, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Sensitive }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Status
Current status of the account.
3673 3674 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3673 required :status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Status } |
#subscriptions ⇒ Array<String>
Subscriptions currently active for this account.
3680 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3680 required :subscriptions, MethodRuby::Internal::Type::ArrayOf[String] |
#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Type
3685 3686 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3685 required :type, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Type } |
#update ⇒ String, ...
The latest update ID. This field is expandable. When expanded, returns the full AccountUpdate object.
3810 3811 3812 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3810 optional :update, union: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Update }, nil?: true |
#updated_at ⇒ Time
Timestamp when the account was last updated.
3692 |
# File 'lib/method_ruby/models/account_create_response.rb', line 3692 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 3881
|
.variants ⇒ Array(String, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::Sensitive::AccountSensitive)
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 4045
|