Class: MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession
- Defined in:
- lib/method_ruby/models/account_create_response.rb
Defined Under Namespace
Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this verification session belongs to.
-
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
-
#created_at ⇒ Time
Timestamp when the verification session was created.
-
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
-
#id ⇒ String
Unique identifier for the verification session.
-
#instant ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
-
#micro_deposits ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
-
#mx ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
-
#network ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
-
#plaid ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
-
#pre_auth ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
-
#standard ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
-
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
-
#teller ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
-
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
-
#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
-
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(number: nil) ⇒ Object
constructor
Populated when the verification session is of type standard.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(number: nil) ⇒ Object
Populated when the verification session is of type standard.
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 4760
|
Instance Attribute Details
#account_id ⇒ String
The account this verification session belongs to.
4648 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4648 required :account_id, String |
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
4680 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4680 optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true |
#created_at ⇒ Time
Timestamp when the verification session was created.
4654 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4654 required :created_at, Time |
#error ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
4686 4687 4688 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4686 optional :error, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error }, nil?: true |
#id ⇒ String
Unique identifier for the verification session.
4642 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4642 required :id, String |
#instant ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
4694 4695 4696 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4694 optional :instant, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant }, nil?: true |
#micro_deposits ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
4702 4703 4704 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4702 optional :micro_deposits, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits }, nil?: true |
#mx ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
4710 4711 4712 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4710 optional :mx, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx }, nil?: true |
#network ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
4718 4719 4720 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4718 optional :network, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network }, nil?: true |
#plaid ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
4726 4727 4728 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4726 optional :plaid, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid }, nil?: true |
#pre_auth ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
4734 4735 4736 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4734 optional :pre_auth, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth }, nil?: true |
#standard ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
4742 4743 4744 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4742 optional :standard, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
4660 4661 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4660 required :status, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status } |
#teller ⇒ MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
4750 4751 4752 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4750 optional :teller, -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller }, nil?: true |
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
4758 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4758 optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
4667 4668 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4667 required :type, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type } |
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
4674 |
# File 'lib/method_ruby/models/account_create_response.rb', line 4674 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 4808
|