Class: MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network
- Defined in:
- lib/method_ruby/models/account_create_response.rb
Overview
Defined Under Namespace
Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, NetworkCheck
Instance Attribute Summary collapse
-
#billing_zip_code ⇒ String?
The masked billing zip code.
-
#billing_zip_code_check ⇒ Symbol, ...
The billing zip code verification check result.
-
#cvv ⇒ String?
The masked card CVV.
-
#cvv_check ⇒ Symbol, ...
The card CVV verification check result.
-
#exp_check ⇒ Symbol, ...
The card expiration verification check result.
-
#exp_month ⇒ String?
The masked card expiration month.
-
#exp_year ⇒ String?
The masked card expiration year.
-
#network_check ⇒ Symbol, ...
The network verification check result.
-
#number ⇒ String?
The masked card number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, network_check: nil, number: nil) ⇒ Object
constructor
Populated when the verification session is of type network.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, network_check: nil, number: nil) ⇒ Object
Populated when the verification session is of type network.
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 5072
|
Instance Attribute Details
#billing_zip_code ⇒ String?
The masked billing zip code.
5014 |
# File 'lib/method_ruby/models/account_create_response.rb', line 5014 optional :billing_zip_code, String, nil?: true |
#billing_zip_code_check ⇒ Symbol, ...
The billing zip code verification check result.
5020 5021 5022 |
# File 'lib/method_ruby/models/account_create_response.rb', line 5020 optional :billing_zip_code_check, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::BillingZipCodeCheck }, nil?: true |
#cvv ⇒ String?
The masked card CVV. Null if it still needs to be provided.
5028 |
# File 'lib/method_ruby/models/account_create_response.rb', line 5028 optional :cvv, String, nil?: true |
#cvv_check ⇒ Symbol, ...
The card CVV verification check result.
5034 5035 5036 |
# File 'lib/method_ruby/models/account_create_response.rb', line 5034 optional :cvv_check, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::CvvCheck }, nil?: true |
#exp_check ⇒ Symbol, ...
The card expiration verification check result.
5042 5043 5044 |
# File 'lib/method_ruby/models/account_create_response.rb', line 5042 optional :exp_check, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::ExpCheck }, nil?: true |
#exp_month ⇒ String?
The masked card expiration month. Null if it still needs to be provided.
5050 |
# File 'lib/method_ruby/models/account_create_response.rb', line 5050 optional :exp_month, String, nil?: true |
#exp_year ⇒ String?
The masked card expiration year. Null if it still needs to be provided.
5056 |
# File 'lib/method_ruby/models/account_create_response.rb', line 5056 optional :exp_year, String, nil?: true |
#network_check ⇒ Symbol, ...
The network verification check result.
5062 5063 5064 |
# File 'lib/method_ruby/models/account_create_response.rb', line 5062 optional :network_check, enum: -> { MethodRuby::Models::AccountCreateResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::NetworkCheck }, nil?: true |
#number ⇒ String?
The masked card number. Null if the number still needs to be provided.
5070 |
# File 'lib/method_ruby/models/account_create_response.rb', line 5070 optional :number, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_create_response.rb', line 5103
|