Class: MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource
- Defined in:
- lib/method_ruby/models/account_retrieve_response.rb
Defined Under Namespace
Modules: Attribute, Balance, CardBrand, ConsentStatus, LatestVerificationSession, PaymentInstrument, Payoff, Sensitive, Status, Type, Update Classes: ACH, Clearing, DebitCard, Error, Liability
Instance Attribute Summary collapse
-
#ach ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::ACH?
ACH account details.
-
#attribute ⇒ String, ...
The latest attribute ID.
-
#balance ⇒ String, ...
The latest balance ID.
-
#card_brand ⇒ String, ...
The latest card brand ID.
-
#clearing ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Clearing?
Clearing account details.
-
#consent_status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::ConsentStatus
Current consent status for data access on this account.
-
#created_at ⇒ Time
Timestamp when the account was created.
-
#debit_card ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::DebitCard?
Debit card account details.
-
#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Error?
Error details when an account is disabled.
-
#holder_id ⇒ String
The entity ID that owns this account.
-
#id ⇒ String
Unique identifier for the account.
-
#latest_verification_session ⇒ String, ...
The latest verification session ID.
-
#liability ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Liability?
Liability account details.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#payment_instrument ⇒ String, ...
The latest payment instrument ID.
-
#payoff ⇒ String, ...
The latest payoff ID.
-
#products ⇒ Array<String>
Products currently active for this account.
-
#restricted_products ⇒ Array<String>
Products restricted from this account.
-
#sensitive ⇒ String, ...
The latest sensitive ID.
-
#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Status
Current status of the account.
- #type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Type
-
#update ⇒ String, ...
The latest update ID.
-
#updated_at ⇒ Time
Timestamp when the account was last updated.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Sensitive::AccountSensitive)
Instance Method Summary collapse
-
#initialize(token: nil) ⇒ Object
constructor
Network token details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token: nil) ⇒ Object
Network token details. Present when type is network_token.
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 229
|
Instance Attribute Details
#ach ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::ACH?
ACH account details. Present when ‘type` is `ach`.
113 114 115 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 113 optional :ach, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::ACH }, nil?: true |
#attribute ⇒ String, ...
The latest attribute ID. This field is expandable. When expanded, returns the full AccountAttribute object.
122 123 124 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 122 optional :attribute, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Attribute }, nil?: true |
#balance ⇒ String, ...
The latest balance ID. This field is expandable. When expanded, returns the full AccountBalance object.
131 132 133 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 131 optional :balance, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Balance }, nil?: true |
#card_brand ⇒ String, ...
The latest card brand ID. This field is expandable. When expanded, returns the full AccountCardBrand object.
140 141 142 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 140 optional :card_brand, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::CardBrand }, nil?: true |
#clearing ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Clearing?
Clearing account details. Present when ‘type` is `clearing`.
148 149 150 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 148 optional :clearing, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Clearing }, nil?: true |
#consent_status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::ConsentStatus
Current consent status for data access on this account.
64 65 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 64 required :consent_status, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::ConsentStatus } |
#created_at ⇒ Time
Timestamp when the account was created.
71 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 71 required :created_at, Time |
#debit_card ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::DebitCard?
Debit card account details. Present when ‘type` is `debit_card`.
156 157 158 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 156 optional :debit_card, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::DebitCard }, nil?: true |
#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Error?
Error details when an account is disabled.
164 165 166 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 164 optional :error, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Error }, nil?: true |
#holder_id ⇒ String
The entity ID that owns this account.
77 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 77 required :holder_id, String |
#id ⇒ String
Unique identifier for the account.
58 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 58 required :id, String |
#latest_verification_session ⇒ String, ...
The latest verification session ID. This field is expandable. When expanded, returns the full AccountVerificationSession object.
173 174 175 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 173 optional :latest_verification_session, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::LatestVerificationSession }, nil?: true |
#liability ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Liability?
Liability account details. Present when ‘type` is `liability`.
181 182 183 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 181 optional :liability, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Liability }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
189 190 191 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 189 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#payment_instrument ⇒ String, ...
The latest payment instrument ID. This field is expandable. When expanded, returns the full AccountPaymentInstrument object.
198 199 200 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 198 optional :payment_instrument, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::PaymentInstrument }, nil?: true |
#payoff ⇒ String, ...
The latest payoff ID. This field is expandable. When expanded, returns the full AccountPayoff object.
207 208 209 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 207 optional :payoff, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Payoff }, nil?: true |
#products ⇒ Array<String>
Products currently active for this account.
83 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 83 required :products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_products ⇒ Array<String>
Products restricted from this account.
89 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 89 required :restricted_products, MethodRuby::Internal::Type::ArrayOf[String] |
#sensitive ⇒ String, ...
The latest sensitive ID. This field is expandable. When expanded, returns the full AccountSensitive object.
216 217 218 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 216 optional :sensitive, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Sensitive }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Status
Current status of the account.
95 96 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 95 required :status, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Status } |
#type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Type
101 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 101 required :type, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Type } |
#update ⇒ String, ...
The latest update ID. This field is expandable. When expanded, returns the full AccountUpdate object.
225 226 227 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 225 optional :update, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Update }, nil?: true |
#updated_at ⇒ Time
Timestamp when the account was last updated.
107 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 107 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 290
|
.variants ⇒ Array(String, MethodRuby::Models::AccountRetrieveResponse::Data::AccountACHResource::Sensitive::AccountSensitive)
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 454
|