Class: MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource
- Defined in:
- lib/method_ruby/models/account_retrieve_response.rb
Defined Under Namespace
Modules: Attribute, Balance, CardBrand, ConsentStatus, LatestVerificationSession, PaymentInstrument, Payoff, Sensitive, Status, Type, Update Classes: ACH, Clearing, DebitCard, Error, Liability
Instance Attribute Summary collapse
-
#ach ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::ACH?
ACH account details.
-
#attribute ⇒ String, ...
The latest attribute ID.
-
#balance ⇒ String, ...
The latest balance ID.
-
#card_brand ⇒ String, ...
The latest card brand ID.
-
#clearing ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Clearing?
Clearing account details.
-
#consent_status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::ConsentStatus
Current consent status for data access on this account.
-
#created_at ⇒ Time
Timestamp when the account was created.
-
#debit_card ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::DebitCard?
Debit card account details.
-
#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Error?
Error details when an account is disabled.
-
#holder_id ⇒ String
The entity ID that owns this account.
-
#id ⇒ String
Unique identifier for the account.
-
#latest_verification_session ⇒ String, ...
The latest verification session ID.
-
#liability ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Liability?
Liability account details.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#payment_instrument ⇒ String, ...
The latest payment instrument ID.
-
#payoff ⇒ String, ...
The latest payoff ID.
-
#products ⇒ Array<String>
Products currently active for this account.
-
#restricted_products ⇒ Array<String>
Products restricted from this account.
-
#sensitive ⇒ String, ...
The latest sensitive ID.
-
#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Status
Current status of the account.
- #type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Type
-
#update ⇒ String, ...
The latest update ID.
-
#updated_at ⇒ Time
Timestamp when the account was last updated.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Sensitive::AccountSensitive)
Instance Method Summary collapse
-
#initialize(token: nil) ⇒ Object
constructor
Network token details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token: nil) ⇒ Object
Network token details. Present when type is network_token.
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7401
|
Instance Attribute Details
#ach ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::ACH?
ACH account details. Present when ‘type` is `ach`.
7285 7286 7287 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7285 optional :ach, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::ACH }, nil?: true |
#attribute ⇒ String, ...
The latest attribute ID. This field is expandable. When expanded, returns the full AccountAttribute object.
7294 7295 7296 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7294 optional :attribute, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Attribute }, nil?: true |
#balance ⇒ String, ...
The latest balance ID. This field is expandable. When expanded, returns the full AccountBalance object.
7303 7304 7305 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7303 optional :balance, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Balance }, nil?: true |
#card_brand ⇒ String, ...
The latest card brand ID. This field is expandable. When expanded, returns the full AccountCardBrand object.
7312 7313 7314 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7312 optional :card_brand, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::CardBrand }, nil?: true |
#clearing ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Clearing?
Clearing account details. Present when ‘type` is `clearing`.
7320 7321 7322 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7320 optional :clearing, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Clearing }, nil?: true |
#consent_status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::ConsentStatus
Current consent status for data access on this account.
7235 7236 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7235 required :consent_status, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::ConsentStatus } |
#created_at ⇒ Time
Timestamp when the account was created.
7242 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7242 required :created_at, Time |
#debit_card ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::DebitCard?
Debit card account details. Present when ‘type` is `debit_card`.
7328 7329 7330 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7328 optional :debit_card, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::DebitCard }, nil?: true |
#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Error?
Error details when an account is disabled.
7336 7337 7338 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7336 optional :error, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Error }, nil?: true |
#holder_id ⇒ String
The entity ID that owns this account.
7248 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7248 required :holder_id, String |
#id ⇒ String
Unique identifier for the account.
7229 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7229 required :id, String |
#latest_verification_session ⇒ String, ...
The latest verification session ID. This field is expandable. When expanded, returns the full AccountVerificationSession object.
7345 7346 7347 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7345 optional :latest_verification_session, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession }, nil?: true |
#liability ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Liability?
Liability account details. Present when ‘type` is `liability`.
7353 7354 7355 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7353 optional :liability, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Liability }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
7361 7362 7363 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7361 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#payment_instrument ⇒ String, ...
The latest payment instrument ID. This field is expandable. When expanded, returns the full AccountPaymentInstrument object.
7370 7371 7372 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7370 optional :payment_instrument, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::PaymentInstrument }, nil?: true |
#payoff ⇒ String, ...
The latest payoff ID. This field is expandable. When expanded, returns the full AccountPayoff object.
7379 7380 7381 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7379 optional :payoff, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Payoff }, nil?: true |
#products ⇒ Array<String>
Products currently active for this account.
7254 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7254 required :products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_products ⇒ Array<String>
Products restricted from this account.
7260 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7260 required :restricted_products, MethodRuby::Internal::Type::ArrayOf[String] |
#sensitive ⇒ String, ...
The latest sensitive ID. This field is expandable. When expanded, returns the full AccountSensitive object.
7388 7389 7390 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7388 optional :sensitive, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Sensitive }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Status
Current status of the account.
7266 7267 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7266 required :status, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Status } |
#type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Type
7272 7273 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7272 required :type, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Type } |
#update ⇒ String, ...
The latest update ID. This field is expandable. When expanded, returns the full AccountUpdate object.
7397 7398 7399 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7397 optional :update, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update }, nil?: true |
#updated_at ⇒ Time
Timestamp when the account was last updated.
7279 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7279 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7462
|
.variants ⇒ Array(String, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Sensitive::AccountSensitive)
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 7626
|