Class: MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/account_retrieve_response.rb,
sig/method_ruby/models/account_retrieve_response.rbs

Defined Under Namespace

Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(number: nil) ⇒ Object

Populated when the verification session is of type standard.

Parameters:

  • number (String, nil) (defaults to: nil) —

    The masked card number. Null if the number still needs to be provided.



# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8341

Instance Attribute Details

#account_id ⇒ String

The account this verification session belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


8229
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8229

required :account_id, String

#auto_verify ⇒ Object?

Populated when the verification session is of type auto_verify.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


8261
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8261

optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true

#created_at ⇒ Time

Timestamp when the verification session was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


8235
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8235

required :created_at, Time

#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Error?

Error details when an account verification session fails.



8267
8268
8269
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8267

optional :error,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Error },
nil?: true

#id ⇒ String

Unique identifier for the verification session.

Parameters:

  • value (String)

Returns:

  • (String)


8223
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8223

required :id, String

#instant ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Instant?

Populated when the verification session is of type instant.



8275
8276
8277
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8275

optional :instant,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Instant },
nil?: true

#micro_deposits ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?

Populated when the verification session is of type micro_deposits.



8283
8284
8285
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8283

optional :micro_deposits,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits },
nil?: true

#mx ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Mx?

Populated when the verification session is of type mx.



8291
8292
8293
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8291

optional :mx,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Mx },
nil?: true

#network ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network?

Populated when the verification session is of type network.



8299
8300
8301
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8299

optional :network,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network },
nil?: true

#plaid ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Plaid?

Populated when the verification session is of type plaid.



8307
8308
8309
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8307

optional :plaid,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Plaid },
nil?: true

#pre_auth ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth?

Populated when the verification session is of type pre_auth.



8315
8316
8317
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8315

optional :pre_auth,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth },
nil?: true

#standard ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Standard?

Populated when the verification session is of type standard.



8323
8324
8325
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8323

optional :standard,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Standard },
nil?: true

#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Status

Current status of the verification session.

Parameters:

  • value (MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::status)

Returns:



8241
8242
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8241

required :status,
enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Status }

#teller ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Teller?

Populated when the verification session is of type teller.



8331
8332
8333
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8331

optional :teller,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Teller },
nil?: true

#trusted_provisioner ⇒ Object?

Populated when the verification session is of type trusted_provisioner.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


8339
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8339

optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true

#type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Type

The type of verification.

Parameters:

  • value (MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::type_)

Returns:



8248
8249
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8248

required :type,
enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Type }

#updated_at ⇒ Time

Timestamp when the verification session was last updated.

Parameters:

  • value (Time)

Returns:

  • (Time)


8255
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8255

required :updated_at, Time

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8389

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


6472
# File 'sig/method_ruby/models/account_retrieve_response.rbs', line 6472

def to_hash: -> {