Class: MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth
- Defined in:
- lib/method_ruby/models/account_retrieve_response.rb
Overview
Defined Under Namespace
Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, PreAuthCheck
Instance Attribute Summary collapse
-
#billing_zip_code ⇒ String?
The masked billing zip code.
-
#billing_zip_code_check ⇒ Symbol, ...
The billing zip code verification check result.
-
#cvv ⇒ String?
The masked card CVV.
-
#cvv_check ⇒ Symbol, ...
The card CVV verification check result.
-
#exp_check ⇒ Symbol, ...
The card expiration verification check result.
-
#exp_month ⇒ String?
The masked card expiration month.
-
#exp_year ⇒ String?
The masked card expiration year.
-
#number ⇒ String?
The masked card number.
-
#pre_auth_check ⇒ Symbol, ...
The pre-auth verification check result.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, number: nil, pre_auth_check: nil) ⇒ Object
constructor
Populated when the verification session is of type pre_auth.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, number: nil, pre_auth_check: nil) ⇒ Object
Populated when the verification session is of type pre_auth.
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8817
|
Instance Attribute Details
#billing_zip_code ⇒ String?
The masked billing zip code.
8759 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8759 optional :billing_zip_code, String, nil?: true |
#billing_zip_code_check ⇒ Symbol, ...
The billing zip code verification check result.
8765 8766 8767 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8765 optional :billing_zip_code_check, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth::BillingZipCodeCheck }, nil?: true |
#cvv ⇒ String?
The masked card CVV. Null if it still needs to be provided.
8773 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8773 optional :cvv, String, nil?: true |
#cvv_check ⇒ Symbol, ...
The card CVV verification check result.
8779 8780 8781 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8779 optional :cvv_check, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth::CvvCheck }, nil?: true |
#exp_check ⇒ Symbol, ...
The card expiration verification check result.
8787 8788 8789 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8787 optional :exp_check, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth::ExpCheck }, nil?: true |
#exp_month ⇒ String?
The masked card expiration month. Null if it still needs to be provided.
8795 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8795 optional :exp_month, String, nil?: true |
#exp_year ⇒ String?
The masked card expiration year. Null if it still needs to be provided.
8801 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8801 optional :exp_year, String, nil?: true |
#number ⇒ String?
The masked card number. Null if the number still needs to be provided.
8807 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8807 optional :number, String, nil?: true |
#pre_auth_check ⇒ Symbol, ...
The pre-auth verification check result.
8813 8814 8815 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8813 optional :pre_auth_check, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth::PreAuthCheck }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 8848
|