Class: MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate
- Defined in:
- lib/method_ruby/models/account_retrieve_response.rb,
sig/method_ruby/models/account_retrieve_response.rbs
Defined Under Namespace
Modules: Source, Status, Type Classes: AutoLoan, Bnpl, CreditCard, Error, Fintech, Mortgage, PersonalLoan, StudentLoan, StudentLoans
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this update belongs to.
-
#auto_loan ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::AutoLoan?
Auto loan update data.
-
#bnpl ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Bnpl?
Buy now pay later update data.
-
#created_at ⇒ Time
Timestamp when the update was created.
-
#credit_card ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::CreditCard?
Credit card update data.
-
#data_as_of ⇒ Time?
The timestamp of the data used to complete this update.
-
#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Error?
Error details when an account update fails.
-
#fintech ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Fintech?
Fintech account update data.
-
#id ⇒ String
Unique identifier for the update.
-
#mortgage ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Mortgage?
Mortgage update data.
-
#personal_loan ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::PersonalLoan?
Personal loan update data.
-
#source ⇒ Symbol, ...
The data source used for this update.
-
#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Status
Current status of the update.
-
#student_loan ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoan?
Student loan update data.
-
#student_loans ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoans?
Student loans aggregate update data.
-
#type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Type
The liability type of the account being updated.
-
#updated_at ⇒ Time
Timestamp when the update was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(balance: nil, closed_at: nil, expected_payoff_date: nil, interest_rate_percentage: nil, interest_rate_source: nil, interest_rate_type: nil, last_payment_amount: nil, last_payment_date: nil, next_payment_due_date: nil, next_payment_minimum_amount: nil, opened_at: nil, original_loan_amount: nil, sub_type: nil, term_length: nil) ⇒ Object
constructor
Student loan update data.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(balance: nil, closed_at: nil, expected_payoff_date: nil, interest_rate_percentage: nil, interest_rate_source: nil, interest_rate_type: nil, last_payment_amount: nil, last_payment_date: nil, next_payment_due_date: nil, next_payment_minimum_amount: nil, opened_at: nil, original_loan_amount: nil, sub_type: nil, term_length: nil) ⇒ Object
Student loan update data. Present when type is student_loan.
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9935
|
Instance Attribute Details
#account_id ⇒ String
The account this update belongs to.
9822 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9822 required :account_id, String |
#auto_loan ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::AutoLoan?
Auto loan update data. Present when type is auto_loan.
9854 9855 9856 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9854 optional :auto_loan, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::AutoLoan }, nil?: true |
#bnpl ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Bnpl?
Buy now pay later update data. Present when type is bnpl.
9862 9863 9864 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9862 optional :bnpl, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Bnpl }, nil?: true |
#created_at ⇒ Time
Timestamp when the update was created.
9828 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9828 required :created_at, Time |
#credit_card ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::CreditCard?
Credit card update data. Present when type is credit_card.
9870 9871 9872 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9870 optional :credit_card, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::CreditCard }, nil?: true |
#data_as_of ⇒ Time?
The timestamp of the data used to complete this update.
9878 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9878 optional :data_as_of, Time, nil?: true |
#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Error?
Error details when an account update fails.
9884 9885 9886 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9884 optional :error, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Error }, nil?: true |
#fintech ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Fintech?
Fintech account update data. Present when type is fintech.
9892 9893 9894 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9892 optional :fintech, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Fintech }, nil?: true |
#id ⇒ String
Unique identifier for the update.
9816 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9816 required :id, String |
#mortgage ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Mortgage?
Mortgage update data. Present when type is mortgage.
9900 9901 9902 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9900 optional :mortgage, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Mortgage }, nil?: true |
#personal_loan ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::PersonalLoan?
Personal loan update data. Present when type is personal_loan.
9908 9909 9910 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9908 optional :personal_loan, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::PersonalLoan }, nil?: true |
#source ⇒ Symbol, ...
The data source used for this update.
9916 9917 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9916 optional :source, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Source } |
#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Status
Current status of the update.
9834 9835 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9834 required :status, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Status } |
#student_loan ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoan?
Student loan update data. Present when type is student_loan.
9923 9924 9925 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9923 optional :student_loan, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoan }, nil?: true |
#student_loans ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoans?
Student loans aggregate update data. Present when type is student_loans.
9931 9932 9933 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9931 optional :student_loans, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoans }, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Type
The liability type of the account being updated.
9841 9842 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9841 required :type, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountClearingResource::Update::AccountUpdate::Type } |
#updated_at ⇒ Time
Timestamp when the update was last updated.
9848 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9848 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 9982
|
Instance Method Details
#to_hash ⇒ {
7762 |
# File 'sig/method_ruby/models/account_retrieve_response.rbs', line 7762
def to_hash: -> {
|