Class: MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource
- Defined in:
- lib/method_ruby/models/account_retrieve_response.rb
Defined Under Namespace
Modules: Attribute, Balance, CardBrand, ConsentStatus, LatestVerificationSession, PaymentInstrument, Payoff, Sensitive, Status, Type, Update Classes: ACH, Clearing, DebitCard, Error, Liability
Instance Attribute Summary collapse
-
#ach ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::ACH?
ACH account details.
-
#attribute ⇒ String, ...
The latest attribute ID.
-
#balance ⇒ String, ...
The latest balance ID.
-
#card_brand ⇒ String, ...
The latest card brand ID.
-
#clearing ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Clearing?
Clearing account details.
-
#consent_status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::ConsentStatus
Current consent status for data access on this account.
-
#created_at ⇒ Time
Timestamp when the account was created.
-
#debit_card ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::DebitCard?
Debit card account details.
-
#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Error?
Error details when an account is disabled.
-
#holder_id ⇒ String
The entity ID that owns this account.
-
#id ⇒ String
Unique identifier for the account.
-
#latest_verification_session ⇒ String, ...
The latest verification session ID.
-
#liability ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Liability?
Liability account details.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#payment_instrument ⇒ String, ...
The latest payment instrument ID.
-
#payoff ⇒ String, ...
The latest payoff ID.
-
#products ⇒ Array<String>
Products currently active for this account.
-
#restricted_products ⇒ Array<String>
Products restricted from this account.
-
#sensitive ⇒ String, ...
The latest sensitive ID.
-
#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Status
Current status of the account.
- #type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Type
-
#update ⇒ String, ...
The latest update ID.
-
#updated_at ⇒ Time
Timestamp when the account was last updated.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Sensitive::AccountSensitive)
Instance Method Summary collapse
-
#initialize(token: nil) ⇒ Object
constructor
Network token details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token: nil) ⇒ Object
Network token details. Present when type is network_token.
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10979
|
Instance Attribute Details
#ach ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::ACH?
ACH account details. Present when ‘type` is `ach`.
10863 10864 10865 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10863 optional :ach, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::ACH }, nil?: true |
#attribute ⇒ String, ...
The latest attribute ID. This field is expandable. When expanded, returns the full AccountAttribute object.
10872 10873 10874 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10872 optional :attribute, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Attribute }, nil?: true |
#balance ⇒ String, ...
The latest balance ID. This field is expandable. When expanded, returns the full AccountBalance object.
10881 10882 10883 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10881 optional :balance, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Balance }, nil?: true |
#card_brand ⇒ String, ...
The latest card brand ID. This field is expandable. When expanded, returns the full AccountCardBrand object.
10890 10891 10892 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10890 optional :card_brand, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::CardBrand }, nil?: true |
#clearing ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Clearing?
Clearing account details. Present when ‘type` is `clearing`.
10898 10899 10900 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10898 optional :clearing, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Clearing }, nil?: true |
#consent_status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::ConsentStatus
Current consent status for data access on this account.
10813 10814 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10813 required :consent_status, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::ConsentStatus } |
#created_at ⇒ Time
Timestamp when the account was created.
10820 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10820 required :created_at, Time |
#debit_card ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::DebitCard?
Debit card account details. Present when ‘type` is `debit_card`.
10906 10907 10908 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10906 optional :debit_card, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::DebitCard }, nil?: true |
#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Error?
Error details when an account is disabled.
10914 10915 10916 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10914 optional :error, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Error }, nil?: true |
#holder_id ⇒ String
The entity ID that owns this account.
10826 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10826 required :holder_id, String |
#id ⇒ String
Unique identifier for the account.
10807 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10807 required :id, String |
#latest_verification_session ⇒ String, ...
The latest verification session ID. This field is expandable. When expanded, returns the full AccountVerificationSession object.
10923 10924 10925 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10923 optional :latest_verification_session, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession }, nil?: true |
#liability ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Liability?
Liability account details. Present when ‘type` is `liability`.
10931 10932 10933 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10931 optional :liability, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Liability }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
10939 10940 10941 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10939 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#payment_instrument ⇒ String, ...
The latest payment instrument ID. This field is expandable. When expanded, returns the full AccountPaymentInstrument object.
10948 10949 10950 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10948 optional :payment_instrument, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::PaymentInstrument }, nil?: true |
#payoff ⇒ String, ...
The latest payoff ID. This field is expandable. When expanded, returns the full AccountPayoff object.
10957 10958 10959 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10957 optional :payoff, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Payoff }, nil?: true |
#products ⇒ Array<String>
Products currently active for this account.
10832 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10832 required :products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_products ⇒ Array<String>
Products restricted from this account.
10838 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10838 required :restricted_products, MethodRuby::Internal::Type::ArrayOf[String] |
#sensitive ⇒ String, ...
The latest sensitive ID. This field is expandable. When expanded, returns the full AccountSensitive object.
10966 10967 10968 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10966 optional :sensitive, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Sensitive }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Status
Current status of the account.
10844 10845 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10844 required :status, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Status } |
#type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Type
10850 10851 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10850 required :type, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Type } |
#update ⇒ String, ...
The latest update ID. This field is expandable. When expanded, returns the full AccountUpdate object.
10975 10976 10977 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10975 optional :update, union: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Update }, nil?: true |
#updated_at ⇒ Time
Timestamp when the account was last updated.
10857 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 10857 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11040
|
.variants ⇒ Array(String, MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::Sensitive::AccountSensitive)
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11204
|