Class: MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/account_retrieve_response.rb,
sig/method_ruby/models/account_retrieve_response.rbs

Defined Under Namespace

Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(number: nil) ⇒ Object

Populated when the verification session is of type standard.

Parameters:

  • number (String, nil) (defaults to: nil) —

    The masked card number. Null if the number still needs to be provided.



# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11919


Instance Attribute Details

#account_id ⇒ String

The account this verification session belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


11807
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11807

required :account_id, String

#auto_verify ⇒ Object?

Populated when the verification session is of type auto_verify.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


11839
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11839

optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true

#created_at ⇒ Time

Timestamp when the verification session was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


11813
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11813

required :created_at, Time

#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Error?

Error details when an account verification session fails.



11845
11846
11847
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11845

optional :error,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Error },
nil?: true

#id ⇒ String

Unique identifier for the verification session.

Parameters:

  • value (String)

Returns:

  • (String)


11801
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11801

required :id, String

#instant ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Instant?

Populated when the verification session is of type instant.



11853
11854
11855
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11853

optional :instant,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Instant },
nil?: true

#micro_deposits ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?

Populated when the verification session is of type micro_deposits.



11861
11862
11863
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11861

optional :micro_deposits,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits },
nil?: true

#mx ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Mx?

Populated when the verification session is of type mx.



11869
11870
11871
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11869

optional :mx,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Mx },
nil?: true

#network ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network?

Populated when the verification session is of type network.



11877
11878
11879
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11877

optional :network,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network },
nil?: true

#plaid ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Plaid?

Populated when the verification session is of type plaid.



11885
11886
11887
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11885

optional :plaid,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Plaid },
nil?: true

#pre_auth ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth?

Populated when the verification session is of type pre_auth.



11893
11894
11895
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11893

optional :pre_auth,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth },
nil?: true

#standard ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Standard?

Populated when the verification session is of type standard.



11901
11902
11903
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11901

optional :standard,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Standard },
nil?: true

#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Status

Current status of the verification session.

Parameters:

  • value (MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::status)

Returns:



11819
11820
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11819

required :status,
enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Status }

#teller ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Teller?

Populated when the verification session is of type teller.



11909
11910
11911
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11909

optional :teller,
-> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Teller },
nil?: true

#trusted_provisioner ⇒ Object?

Populated when the verification session is of type trusted_provisioner.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


11917
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11917

optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true

#type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Type

The type of verification.

Parameters:

  • value (MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::type_)

Returns:



11826
11827
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11826

required :type,
enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Type }

#updated_at ⇒ Time

Timestamp when the verification session was last updated.

Parameters:

  • value (Time)

Returns:

  • (Time)


11833
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11833

required :updated_at, Time

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/account_retrieve_response.rb', line 11967


Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


9264
# File 'sig/method_ruby/models/account_retrieve_response.rbs', line 9264

def to_hash: -> {