Class: MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession
- Defined in:
- lib/method_ruby/models/account_retrieve_response.rb
Defined Under Namespace
Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this verification session belongs to.
-
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
-
#created_at ⇒ Time
Timestamp when the verification session was created.
-
#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
-
#id ⇒ String
Unique identifier for the verification session.
-
#instant ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
-
#micro_deposits ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
-
#mx ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
-
#network ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
-
#plaid ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
-
#pre_auth ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
-
#standard ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
-
#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
-
#teller ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
-
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
-
#type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
-
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(number: nil) ⇒ Object
constructor
Populated when the verification session is of type standard.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(number: nil) ⇒ Object
Populated when the verification session is of type standard.
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4763
|
Instance Attribute Details
#account_id ⇒ String
The account this verification session belongs to.
4651 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4651 required :account_id, String |
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
4683 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4683 optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true |
#created_at ⇒ Time
Timestamp when the verification session was created.
4657 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4657 required :created_at, Time |
#error ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
4689 4690 4691 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4689 optional :error, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error }, nil?: true |
#id ⇒ String
Unique identifier for the verification session.
4645 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4645 required :id, String |
#instant ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
4697 4698 4699 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4697 optional :instant, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant }, nil?: true |
#micro_deposits ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
4705 4706 4707 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4705 optional :micro_deposits, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits }, nil?: true |
#mx ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
4713 4714 4715 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4713 optional :mx, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx }, nil?: true |
#network ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
4721 4722 4723 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4721 optional :network, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network }, nil?: true |
#plaid ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
4729 4730 4731 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4729 optional :plaid, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid }, nil?: true |
#pre_auth ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
4737 4738 4739 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4737 optional :pre_auth, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth }, nil?: true |
#standard ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
4745 4746 4747 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4745 optional :standard, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
4663 4664 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4663 required :status, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status } |
#teller ⇒ MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
4753 4754 4755 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4753 optional :teller, -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller }, nil?: true |
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
4761 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4761 optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
4670 4671 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4670 required :type, enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type } |
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
4677 |
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4677 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 4811
|