Class: MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/account_retrieve_response.rb,
sig/method_ruby/models/account_retrieve_response.rbs

Overview

See Also:

  • MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession#network

Defined Under Namespace

Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, NetworkCheck

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, network_check: nil, number: nil) ⇒ Object

Populated when the verification session is of type network.

Parameters:



# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5075


Instance Attribute Details

#billing_zip_code ⇒ String?

The masked billing zip code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5017
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5017

optional :billing_zip_code, String, nil?: true

#billing_zip_code_check ⇒ Symbol, ...

The billing zip code verification check result.

Parameters:

  • value (MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::billing_zip_code_check, nil)

Returns:



5023
5024
5025
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5023

optional :billing_zip_code_check,
enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::BillingZipCodeCheck },
nil?: true

#cvv ⇒ String?

The masked card CVV. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5031
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5031

optional :cvv, String, nil?: true

#cvv_check ⇒ Symbol, ...

The card CVV verification check result.

Parameters:

  • value (MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::cvv_check, nil)

Returns:



5037
5038
5039
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5037

optional :cvv_check,
enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::CvvCheck },
nil?: true

#exp_check ⇒ Symbol, ...

The card expiration verification check result.

Parameters:

  • value (MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::exp_check, nil)

Returns:



5045
5046
5047
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5045

optional :exp_check,
enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::ExpCheck },
nil?: true

#exp_month ⇒ String?

The masked card expiration month. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5053
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5053

optional :exp_month, String, nil?: true

#exp_year ⇒ String?

The masked card expiration year. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5059
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5059

optional :exp_year, String, nil?: true

#network_check ⇒ Symbol, ...

The network verification check result.

Parameters:

  • value (MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::network_check, nil)

Returns:



5065
5066
5067
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5065

optional :network_check,
enum: -> { MethodRuby::Models::AccountRetrieveResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network::NetworkCheck },
nil?: true

#number ⇒ String?

The masked card number. Null if the number still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5073
# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5073

optional :number, String, nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/account_retrieve_response.rb', line 5106


Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


3937
# File 'sig/method_ruby/models/account_retrieve_response.rbs', line 3937

def to_hash: -> {