Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::Attribute::AccountAttribute
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::Attribute::AccountAttribute
- Defined in:
- lib/method_ruby/models/accounts/consent_withdraw_response.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this attribute belongs to.
-
#attributes ⇒ Hash{Symbol=>Object}
Financial data attributes for the account.
-
#created_at ⇒ Time
Timestamp when the attribute was created.
- #error ⇒ MethodRuby::Models::ResourceError?
-
#id ⇒ String
Unique identifier for the account attribute.
-
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::Attribute::AccountAttribute::Status
Current status of the attribute request.
-
#updated_at ⇒ Time
Timestamp when the attribute was last updated.
Instance Method Summary collapse
-
#initialize(id:, account_id:, attributes:, created_at:, status:, updated_at:, error: nil) ⇒ Object
constructor
An attribute record for an account containing financial data attributes.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, account_id:, attributes:, created_at:, status:, updated_at:, error: nil) ⇒ Object
An attribute record for an account containing financial data attributes.
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 424
|
Instance Attribute Details
#account_id ⇒ String
The account this attribute belongs to.
392 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 392 required :account_id, String |
#attributes ⇒ Hash{Symbol=>Object}
Financial data attributes for the account.
398 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 398 required :attributes, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown] |
#created_at ⇒ Time
Timestamp when the attribute was created.
404 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 404 required :created_at, Time |
#error ⇒ MethodRuby::Models::ResourceError?
422 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 422 optional :error, -> { MethodRuby::ResourceError }, nil?: true |
#id ⇒ String
Unique identifier for the account attribute.
386 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 386 required :id, String |
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::Attribute::AccountAttribute::Status
Current status of the attribute request.
410 411 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 410 required :status, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::Attribute::AccountAttribute::Status } |
#updated_at ⇒ Time
Timestamp when the attribute was last updated.
417 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 417 required :updated_at, Time |