Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession
- Defined in:
- lib/method_ruby/models/accounts/consent_withdraw_response.rb
Defined Under Namespace
Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this verification session belongs to.
-
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
-
#created_at ⇒ Time
Timestamp when the verification session was created.
-
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
-
#id ⇒ String
Unique identifier for the verification session.
-
#instant ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
-
#micro_deposits ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
-
#mx ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
-
#network ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
-
#plaid ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
-
#pre_auth ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
-
#standard ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
-
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
-
#teller ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
-
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
-
#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
-
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(number: nil) ⇒ Object
constructor
Populated when the verification session is of type standard.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(number: nil) ⇒ Object
Populated when the verification session is of type standard.
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1171
|
Instance Attribute Details
#account_id ⇒ String
The account this verification session belongs to.
1059 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1059 required :account_id, String |
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
1091 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1091 optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true |
#created_at ⇒ Time
Timestamp when the verification session was created.
1065 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1065 required :created_at, Time |
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
1097 1098 1099 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1097 optional :error, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Error }, nil?: true |
#id ⇒ String
Unique identifier for the verification session.
1053 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1053 required :id, String |
#instant ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
1105 1106 1107 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1105 optional :instant, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant }, nil?: true |
#micro_deposits ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
1113 1114 1115 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1113 optional :micro_deposits, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits }, nil?: true |
#mx ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
1121 1122 1123 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1121 optional :mx, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Mx }, nil?: true |
#network ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
1129 1130 1131 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1129 optional :network, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network }, nil?: true |
#plaid ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
1137 1138 1139 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1137 optional :plaid, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Plaid }, nil?: true |
#pre_auth ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
1145 1146 1147 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1145 optional :pre_auth, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth }, nil?: true |
#standard ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
1153 1154 1155 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1153 optional :standard, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Standard }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
1071 1072 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1071 required :status, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Status } |
#teller ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
1161 1162 1163 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1161 optional :teller, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Teller }, nil?: true |
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
1169 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1169 optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
1078 1079 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1078 required :type, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Type } |
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
1085 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1085 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1219
|