Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/accounts/consent_withdraw_response.rb,
sig/method_ruby/models/accounts/consent_withdraw_response.rbs

Overview

See Also:

  • MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession#pre_auth

Defined Under Namespace

Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, PreAuthCheck

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, number: nil, pre_auth_check: nil) ⇒ Object

Populated when the verification session is of type pre_auth.

Parameters:



# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1647

Instance Attribute Details

#billing_zip_code ⇒ String?

The masked billing zip code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1589
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1589

optional :billing_zip_code, String, nil?: true

#billing_zip_code_check ⇒ Symbol, ...

The billing zip code verification check result.

Parameters:

  • value (MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth::billing_zip_code_check, nil)

Returns:



1595
1596
1597
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1595

optional :billing_zip_code_check,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth::BillingZipCodeCheck },
nil?: true

#cvv ⇒ String?

The masked card CVV. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1603
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1603

optional :cvv, String, nil?: true

#cvv_check ⇒ Symbol, ...

The card CVV verification check result.

Parameters:

  • value (MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth::cvv_check, nil)

Returns:



1609
1610
1611
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1609

optional :cvv_check,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth::CvvCheck },
nil?: true

#exp_check ⇒ Symbol, ...

The card expiration verification check result.

Parameters:

  • value (MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth::exp_check, nil)

Returns:



1617
1618
1619
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1617

optional :exp_check,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth::ExpCheck },
nil?: true

#exp_month ⇒ String?

The masked card expiration month. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1625
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1625

optional :exp_month, String, nil?: true

#exp_year ⇒ String?

The masked card expiration year. Null if it still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1631
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1631

optional :exp_year, String, nil?: true

#number ⇒ String?

The masked card number. Null if the number still needs to be provided.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1637
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1637

optional :number, String, nil?: true

#pre_auth_check ⇒ Symbol, ...

The pre-auth verification check result.

Parameters:

  • value (MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth::pre_auth_check, nil)

Returns:



1643
1644
1645
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1643

optional :pre_auth_check,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth::PreAuthCheck },
nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 1678

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1255
# File 'sig/method_ruby/models/accounts/consent_withdraw_response.rbs', line 1255

def to_hash: -> {