Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource
- Defined in:
- lib/method_ruby/models/accounts/consent_withdraw_response.rb
Defined Under Namespace
Modules: Attribute, Balance, CardBrand, ConsentStatus, LatestVerificationSession, PaymentInstrument, Payoff, Sensitive, Status, Type, Update Classes: ACH, Clearing, DebitCard, Error, Liability
Instance Attribute Summary collapse
-
#ach ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::ACH?
ACH account details.
-
#attribute ⇒ String, ...
The latest attribute ID.
-
#balance ⇒ String, ...
The latest balance ID.
-
#card_brand ⇒ String, ...
The latest card brand ID.
-
#clearing ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Clearing?
Clearing account details.
-
#consent_status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::ConsentStatus
Current consent status for data access on this account.
-
#created_at ⇒ Time
Timestamp when the account was created.
-
#debit_card ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::DebitCard?
Debit card account details.
-
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Error?
Error details when an account is disabled.
-
#holder_id ⇒ String
The entity ID that owns this account.
-
#id ⇒ String
Unique identifier for the account.
-
#latest_verification_session ⇒ String, ...
The latest verification session ID.
-
#liability ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Liability?
Liability account details.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#payment_instrument ⇒ String, ...
The latest payment instrument ID.
-
#payoff ⇒ String, ...
The latest payoff ID.
-
#products ⇒ Array<String>
Products currently active for this account.
-
#restricted_products ⇒ Array<String>
Products restricted from this account.
-
#sensitive ⇒ String, ...
The latest sensitive ID.
-
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Status
Current status of the account.
- #type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Type
-
#update ⇒ String, ...
The latest update ID.
-
#updated_at ⇒ Time
Timestamp when the account was last updated.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Sensitive::AccountSensitive)
Instance Method Summary collapse
-
#initialize(token: nil) ⇒ Object
constructor
Network token details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token: nil) ⇒ Object
Network token details. Present when type is network_token.
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7411
|
Instance Attribute Details
#ach ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::ACH?
ACH account details. Present when ‘type` is `ach`.
7295 7296 7297 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7295 optional :ach, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::ACH }, nil?: true |
#attribute ⇒ String, ...
The latest attribute ID. This field is expandable. When expanded, returns the full AccountAttribute object.
7304 7305 7306 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7304 optional :attribute, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Attribute }, nil?: true |
#balance ⇒ String, ...
The latest balance ID. This field is expandable. When expanded, returns the full AccountBalance object.
7313 7314 7315 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7313 optional :balance, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Balance }, nil?: true |
#card_brand ⇒ String, ...
The latest card brand ID. This field is expandable. When expanded, returns the full AccountCardBrand object.
7322 7323 7324 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7322 optional :card_brand, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::CardBrand }, nil?: true |
#clearing ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Clearing?
Clearing account details. Present when ‘type` is `clearing`.
7330 7331 7332 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7330 optional :clearing, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Clearing }, nil?: true |
#consent_status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::ConsentStatus
Current consent status for data access on this account.
7245 7246 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7245 required :consent_status, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::ConsentStatus } |
#created_at ⇒ Time
Timestamp when the account was created.
7252 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7252 required :created_at, Time |
#debit_card ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::DebitCard?
Debit card account details. Present when ‘type` is `debit_card`.
7338 7339 7340 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7338 optional :debit_card, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::DebitCard }, nil?: true |
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Error?
Error details when an account is disabled.
7346 7347 7348 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7346 optional :error, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Error }, nil?: true |
#holder_id ⇒ String
The entity ID that owns this account.
7258 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7258 required :holder_id, String |
#id ⇒ String
Unique identifier for the account.
7239 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7239 required :id, String |
#latest_verification_session ⇒ String, ...
The latest verification session ID. This field is expandable. When expanded, returns the full AccountVerificationSession object.
7355 7356 7357 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7355 optional :latest_verification_session, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession }, nil?: true |
#liability ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Liability?
Liability account details. Present when ‘type` is `liability`.
7363 7364 7365 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7363 optional :liability, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Liability }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
7371 7372 7373 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7371 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#payment_instrument ⇒ String, ...
The latest payment instrument ID. This field is expandable. When expanded, returns the full AccountPaymentInstrument object.
7380 7381 7382 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7380 optional :payment_instrument, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::PaymentInstrument }, nil?: true |
#payoff ⇒ String, ...
The latest payoff ID. This field is expandable. When expanded, returns the full AccountPayoff object.
7389 7390 7391 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7389 optional :payoff, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Payoff }, nil?: true |
#products ⇒ Array<String>
Products currently active for this account.
7264 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7264 required :products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_products ⇒ Array<String>
Products restricted from this account.
7270 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7270 required :restricted_products, MethodRuby::Internal::Type::ArrayOf[String] |
#sensitive ⇒ String, ...
The latest sensitive ID. This field is expandable. When expanded, returns the full AccountSensitive object.
7398 7399 7400 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7398 optional :sensitive, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Sensitive }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Status
Current status of the account.
7276 7277 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7276 required :status, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Status } |
#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Type
7282 7283 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7282 required :type, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Type } |
#update ⇒ String, ...
The latest update ID. This field is expandable. When expanded, returns the full AccountUpdate object.
7407 7408 7409 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7407 optional :update, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update }, nil?: true |
#updated_at ⇒ Time
Timestamp when the account was last updated.
7289 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7289 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7472
|
.variants ⇒ Array(String, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Sensitive::AccountSensitive)
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 7636
|