Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/accounts/consent_withdraw_response.rb,
sig/method_ruby/models/accounts/consent_withdraw_response.rbs

Defined Under Namespace

Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(number: nil) ⇒ Object

Populated when the verification session is of type standard.

Parameters:

  • number (String, nil) (defaults to: nil) —

    The masked card number. Null if the number still needs to be provided.



# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8351

Instance Attribute Details

#account_id ⇒ String

The account this verification session belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


8239
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8239

required :account_id, String

#auto_verify ⇒ Object?

Populated when the verification session is of type auto_verify.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


8271
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8271

optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true

#created_at ⇒ Time

Timestamp when the verification session was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


8245
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8245

required :created_at, Time

#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Error?

Error details when an account verification session fails.



8277
8278
8279
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8277

optional :error,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Error },
nil?: true

#id ⇒ String

Unique identifier for the verification session.

Parameters:

  • value (String)

Returns:

  • (String)


8233
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8233

required :id, String

#instant ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Instant?

Populated when the verification session is of type instant.



8285
8286
8287
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8285

optional :instant,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Instant },
nil?: true

#micro_deposits ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?

Populated when the verification session is of type micro_deposits.



8293
8294
8295
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8293

optional :micro_deposits,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits },
nil?: true

#mx ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Mx?

Populated when the verification session is of type mx.



8301
8302
8303
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8301

optional :mx,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Mx },
nil?: true

#network ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network?

Populated when the verification session is of type network.



8309
8310
8311
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8309

optional :network,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network },
nil?: true

#plaid ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Plaid?

Populated when the verification session is of type plaid.



8317
8318
8319
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8317

optional :plaid,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Plaid },
nil?: true

#pre_auth ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth?

Populated when the verification session is of type pre_auth.



8325
8326
8327
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8325

optional :pre_auth,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth },
nil?: true

#standard ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Standard?

Populated when the verification session is of type standard.



8333
8334
8335
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8333

optional :standard,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Standard },
nil?: true

#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Status

Current status of the verification session.

Parameters:

  • value (MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::status)

Returns:



8251
8252
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8251

required :status,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Status }

#teller ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Teller?

Populated when the verification session is of type teller.



8341
8342
8343
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8341

optional :teller,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Teller },
nil?: true

#trusted_provisioner ⇒ Object?

Populated when the verification session is of type trusted_provisioner.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


8349
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8349

optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true

#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Type

The type of verification.

Parameters:

  • value (MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::type_)

Returns:



8258
8259
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8258

required :type,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Type }

#updated_at ⇒ Time

Timestamp when the verification session was last updated.

Parameters:

  • value (Time)

Returns:

  • (Time)


8265
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8265

required :updated_at, Time

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8399

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


6475
# File 'sig/method_ruby/models/accounts/consent_withdraw_response.rbs', line 6475

def to_hash: -> {