Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate
- Defined in:
- lib/method_ruby/models/accounts/consent_withdraw_response.rb
Defined Under Namespace
Modules: Source, Status, Type Classes: AutoLoan, Bnpl, CreditCard, Error, Fintech, Mortgage, PersonalLoan, StudentLoan, StudentLoans
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this update belongs to.
-
#auto_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::AutoLoan?
Auto loan update data.
-
#bnpl ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Bnpl?
Buy now pay later update data.
-
#created_at ⇒ Time
Timestamp when the update was created.
-
#credit_card ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::CreditCard?
Credit card update data.
-
#data_as_of ⇒ Time?
The timestamp of the data used to complete this update.
-
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Error?
Error details when an account update fails.
-
#fintech ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Fintech?
Fintech account update data.
-
#id ⇒ String
Unique identifier for the update.
-
#mortgage ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Mortgage?
Mortgage update data.
-
#personal_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::PersonalLoan?
Personal loan update data.
-
#source ⇒ Symbol, ...
The data source used for this update.
-
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Status
Current status of the update.
-
#student_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoan?
Student loan update data.
-
#student_loans ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoans?
Student loans aggregate update data.
-
#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Type
The liability type of the account being updated.
-
#updated_at ⇒ Time
Timestamp when the update was last updated.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(balance: nil, closed_at: nil, expected_payoff_date: nil, interest_rate_percentage: nil, interest_rate_source: nil, interest_rate_type: nil, last_payment_amount: nil, last_payment_date: nil, next_payment_due_date: nil, next_payment_minimum_amount: nil, opened_at: nil, original_loan_amount: nil, sub_type: nil, term_length: nil) ⇒ Object
Student loan update data. Present when ‘type` is `student_loan`.
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9945
|
Instance Attribute Details
#account_id ⇒ String
The account this update belongs to.
9832 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9832 required :account_id, String |
#auto_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::AutoLoan?
Auto loan update data. Present when ‘type` is `auto_loan`.
9864 9865 9866 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9864 optional :auto_loan, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::AutoLoan }, nil?: true |
#bnpl ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Bnpl?
Buy now pay later update data. Present when ‘type` is `bnpl`.
9872 9873 9874 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9872 optional :bnpl, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Bnpl }, nil?: true |
#created_at ⇒ Time
Timestamp when the update was created.
9838 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9838 required :created_at, Time |
#credit_card ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::CreditCard?
Credit card update data. Present when ‘type` is `credit_card`.
9880 9881 9882 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9880 optional :credit_card, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::CreditCard }, nil?: true |
#data_as_of ⇒ Time?
The timestamp of the data used to complete this update.
9888 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9888 optional :data_as_of, Time, nil?: true |
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Error?
Error details when an account update fails.
9894 9895 9896 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9894 optional :error, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Error }, nil?: true |
#fintech ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Fintech?
Fintech account update data. Present when ‘type` is `fintech`.
9902 9903 9904 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9902 optional :fintech, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Fintech }, nil?: true |
#id ⇒ String
Unique identifier for the update.
9826 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9826 required :id, String |
#mortgage ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Mortgage?
Mortgage update data. Present when ‘type` is `mortgage`.
9910 9911 9912 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9910 optional :mortgage, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Mortgage }, nil?: true |
#personal_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::PersonalLoan?
Personal loan update data. Present when ‘type` is `personal_loan`.
9918 9919 9920 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9918 optional :personal_loan, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::PersonalLoan }, nil?: true |
#source ⇒ Symbol, ...
The data source used for this update.
9926 9927 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9926 optional :source, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Source } |
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Status
Current status of the update.
9844 9845 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9844 required :status, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Status } |
#student_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoan?
Student loan update data. Present when ‘type` is `student_loan`.
9933 9934 9935 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9933 optional :student_loan, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoan }, nil?: true |
#student_loans ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoans?
Student loans aggregate update data. Present when ‘type` is `student_loans`.
9941 9942 9943 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9941 optional :student_loans, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::StudentLoans }, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Type
The liability type of the account being updated.
9851 9852 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9851 required :type, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::Update::AccountUpdate::Type } |
#updated_at ⇒ Time
Timestamp when the update was last updated.
9858 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9858 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 9992
|