Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource
- Defined in:
- lib/method_ruby/models/accounts/consent_withdraw_response.rb
Defined Under Namespace
Modules: Attribute, Balance, CardBrand, ConsentStatus, LatestVerificationSession, PaymentInstrument, Payoff, Sensitive, Status, Type, Update Classes: ACH, Clearing, DebitCard, Error, Liability
Instance Attribute Summary collapse
-
#ach ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::ACH?
ACH account details.
-
#attribute ⇒ String, ...
The latest attribute ID.
-
#balance ⇒ String, ...
The latest balance ID.
-
#card_brand ⇒ String, ...
The latest card brand ID.
-
#clearing ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Clearing?
Clearing account details.
-
#consent_status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::ConsentStatus
Current consent status for data access on this account.
-
#created_at ⇒ Time
Timestamp when the account was created.
-
#debit_card ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::DebitCard?
Debit card account details.
-
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Error?
Error details when an account is disabled.
-
#holder_id ⇒ String
The entity ID that owns this account.
-
#id ⇒ String
Unique identifier for the account.
-
#latest_verification_session ⇒ String, ...
The latest verification session ID.
-
#liability ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Liability?
Liability account details.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#payment_instrument ⇒ String, ...
The latest payment instrument ID.
-
#payoff ⇒ String, ...
The latest payoff ID.
-
#products ⇒ Array<String>
Products currently active for this account.
-
#restricted_products ⇒ Array<String>
Products restricted from this account.
-
#sensitive ⇒ String, ...
The latest sensitive ID.
-
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Status
Current status of the account.
- #type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Type
-
#update ⇒ String, ...
The latest update ID.
-
#updated_at ⇒ Time
Timestamp when the account was last updated.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Sensitive::AccountSensitive)
Instance Method Summary collapse
-
#initialize(token: nil) ⇒ Object
constructor
Network token details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token: nil) ⇒ Object
Network token details. Present when type is network_token.
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10989
|
Instance Attribute Details
#ach ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::ACH?
ACH account details. Present when ‘type` is `ach`.
10873 10874 10875 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10873 optional :ach, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::ACH }, nil?: true |
#attribute ⇒ String, ...
The latest attribute ID. This field is expandable. When expanded, returns the full AccountAttribute object.
10882 10883 10884 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10882 optional :attribute, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Attribute }, nil?: true |
#balance ⇒ String, ...
The latest balance ID. This field is expandable. When expanded, returns the full AccountBalance object.
10891 10892 10893 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10891 optional :balance, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Balance }, nil?: true |
#card_brand ⇒ String, ...
The latest card brand ID. This field is expandable. When expanded, returns the full AccountCardBrand object.
10900 10901 10902 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10900 optional :card_brand, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::CardBrand }, nil?: true |
#clearing ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Clearing?
Clearing account details. Present when ‘type` is `clearing`.
10908 10909 10910 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10908 optional :clearing, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Clearing }, nil?: true |
#consent_status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::ConsentStatus
Current consent status for data access on this account.
10823 10824 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10823 required :consent_status, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::ConsentStatus } |
#created_at ⇒ Time
Timestamp when the account was created.
10830 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10830 required :created_at, Time |
#debit_card ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::DebitCard?
Debit card account details. Present when ‘type` is `debit_card`.
10916 10917 10918 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10916 optional :debit_card, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::DebitCard }, nil?: true |
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Error?
Error details when an account is disabled.
10924 10925 10926 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10924 optional :error, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Error }, nil?: true |
#holder_id ⇒ String
The entity ID that owns this account.
10836 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10836 required :holder_id, String |
#id ⇒ String
Unique identifier for the account.
10817 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10817 required :id, String |
#latest_verification_session ⇒ String, ...
The latest verification session ID. This field is expandable. When expanded, returns the full AccountVerificationSession object.
10933 10934 10935 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10933 optional :latest_verification_session, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession }, nil?: true |
#liability ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Liability?
Liability account details. Present when ‘type` is `liability`.
10941 10942 10943 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10941 optional :liability, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Liability }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
10949 10950 10951 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10949 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#payment_instrument ⇒ String, ...
The latest payment instrument ID. This field is expandable. When expanded, returns the full AccountPaymentInstrument object.
10958 10959 10960 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10958 optional :payment_instrument, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::PaymentInstrument }, nil?: true |
#payoff ⇒ String, ...
The latest payoff ID. This field is expandable. When expanded, returns the full AccountPayoff object.
10967 10968 10969 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10967 optional :payoff, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Payoff }, nil?: true |
#products ⇒ Array<String>
Products currently active for this account.
10842 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10842 required :products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_products ⇒ Array<String>
Products restricted from this account.
10848 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10848 required :restricted_products, MethodRuby::Internal::Type::ArrayOf[String] |
#sensitive ⇒ String, ...
The latest sensitive ID. This field is expandable. When expanded, returns the full AccountSensitive object.
10976 10977 10978 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10976 optional :sensitive, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Sensitive }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Status
Current status of the account.
10854 10855 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10854 required :status, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Status } |
#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Type
10860 10861 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10860 required :type, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Type } |
#update ⇒ String, ...
The latest update ID. This field is expandable. When expanded, returns the full AccountUpdate object.
10985 10986 10987 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10985 optional :update, union: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Update }, nil?: true |
#updated_at ⇒ Time
Timestamp when the account was last updated.
10867 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 10867 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11050
|
.variants ⇒ Array(String, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::Sensitive::AccountSensitive)
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11214
|