Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession
- Defined in:
- lib/method_ruby/models/accounts/consent_withdraw_response.rb
Defined Under Namespace
Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this verification session belongs to.
-
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
-
#created_at ⇒ Time
Timestamp when the verification session was created.
-
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
-
#id ⇒ String
Unique identifier for the verification session.
-
#instant ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
-
#micro_deposits ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
-
#mx ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
-
#network ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
-
#plaid ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
-
#pre_auth ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
-
#standard ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
-
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
-
#teller ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
-
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
-
#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
-
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(number: nil) ⇒ Object
constructor
Populated when the verification session is of type standard.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(number: nil) ⇒ Object
Populated when the verification session is of type standard.
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11929
|
Instance Attribute Details
#account_id ⇒ String
The account this verification session belongs to.
11817 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11817 required :account_id, String |
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
11849 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11849 optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true |
#created_at ⇒ Time
Timestamp when the verification session was created.
11823 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11823 required :created_at, Time |
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
11855 11856 11857 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11855 optional :error, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Error }, nil?: true |
#id ⇒ String
Unique identifier for the verification session.
11811 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11811 required :id, String |
#instant ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
11863 11864 11865 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11863 optional :instant, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Instant }, nil?: true |
#micro_deposits ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
11871 11872 11873 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11871 optional :micro_deposits, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits }, nil?: true |
#mx ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
11879 11880 11881 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11879 optional :mx, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Mx }, nil?: true |
#network ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
11887 11888 11889 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11887 optional :network, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network }, nil?: true |
#plaid ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
11895 11896 11897 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11895 optional :plaid, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Plaid }, nil?: true |
#pre_auth ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
11903 11904 11905 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11903 optional :pre_auth, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth }, nil?: true |
#standard ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
11911 11912 11913 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11911 optional :standard, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Standard }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
11829 11830 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11829 required :status, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Status } |
#teller ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
11919 11920 11921 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11919 optional :teller, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Teller }, nil?: true |
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
11927 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11927 optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
11836 11837 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11836 required :type, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Type } |
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
11843 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11843 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 11977
|