Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/accounts/consent_withdraw_response.rb

Overview

See Also:

Defined Under Namespace

Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, NetworkCheck

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, network_check: nil, number: nil) ⇒ Object

Populated when the verification session is of type network.

Parameters:



# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12241

Instance Attribute Details

#billing_zip_codeString?

The masked billing zip code.

Returns:

  • (String, nil)


12183
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12183

optional :billing_zip_code, String, nil?: true

#billing_zip_code_checkSymbol, ...

The billing zip code verification check result.



12189
12190
12191
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12189

optional :billing_zip_code_check,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network::BillingZipCodeCheck },
nil?: true

#cvvString?

The masked card CVV. Null if it still needs to be provided.

Returns:

  • (String, nil)


12197
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12197

optional :cvv, String, nil?: true

#cvv_checkSymbol, ...

The card CVV verification check result.



12203
12204
12205
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12203

optional :cvv_check,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network::CvvCheck },
nil?: true

#exp_checkSymbol, ...

The card expiration verification check result.



12211
12212
12213
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12211

optional :exp_check,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network::ExpCheck },
nil?: true

#exp_monthString?

The masked card expiration month. Null if it still needs to be provided.

Returns:

  • (String, nil)


12219
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12219

optional :exp_month, String, nil?: true

#exp_yearString?

The masked card expiration year. Null if it still needs to be provided.

Returns:

  • (String, nil)


12225
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12225

optional :exp_year, String, nil?: true

#network_checkSymbol, ...

The network verification check result.



12231
12232
12233
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12231

optional :network_check,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network::NetworkCheck },
nil?: true

#numberString?

The masked card number. Null if the number still needs to be provided.

Returns:

  • (String, nil)


12239
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12239

optional :number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 12272