Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/accounts/consent_withdraw_response.rb,
sig/method_ruby/models/accounts/consent_withdraw_response.rbs

Defined Under Namespace

Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(number: nil) ⇒ Object

Populated when the verification session is of type standard.

Parameters:

  • number (String, nil) (defaults to: nil) —

    The masked card number. Null if the number still needs to be provided.



# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4773

Instance Attribute Details

#account_id ⇒ String

The account this verification session belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


4661
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4661

required :account_id, String

#auto_verify ⇒ Object?

Populated when the verification session is of type auto_verify.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


4693
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4693

optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true

#created_at ⇒ Time

Timestamp when the verification session was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


4667
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4667

required :created_at, Time

#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error?

Error details when an account verification session fails.



4699
4700
4701
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4699

optional :error,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error },
nil?: true

#id ⇒ String

Unique identifier for the verification session.

Parameters:

  • value (String)

Returns:

  • (String)


4655
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4655

required :id, String

#instant ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant?

Populated when the verification session is of type instant.



4707
4708
4709
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4707

optional :instant,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant },
nil?: true

#micro_deposits ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?

Populated when the verification session is of type micro_deposits.



4715
4716
4717
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4715

optional :micro_deposits,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits },
nil?: true

#mx ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx?

Populated when the verification session is of type mx.



4723
4724
4725
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4723

optional :mx,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx },
nil?: true

#network ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network?

Populated when the verification session is of type network.



4731
4732
4733
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4731

optional :network,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network },
nil?: true

#plaid ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid?

Populated when the verification session is of type plaid.



4739
4740
4741
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4739

optional :plaid,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid },
nil?: true

#pre_auth ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth?

Populated when the verification session is of type pre_auth.



4747
4748
4749
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4747

optional :pre_auth,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth },
nil?: true

#standard ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard?

Populated when the verification session is of type standard.



4755
4756
4757
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4755

optional :standard,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard },
nil?: true

#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status

Current status of the verification session.

Parameters:

  • value (MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::status)

Returns:



4673
4674
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4673

required :status,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status }

#teller ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller?

Populated when the verification session is of type teller.



4763
4764
4765
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4763

optional :teller,
-> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller },
nil?: true

#trusted_provisioner ⇒ Object?

Populated when the verification session is of type trusted_provisioner.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


4771
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4771

optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true

#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type

The type of verification.

Parameters:

  • value (MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::type_)

Returns:



4680
4681
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4680

required :type,
enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type }

#updated_at ⇒ Time

Timestamp when the verification session was last updated.

Parameters:

  • value (Time)

Returns:

  • (Time)


4687
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4687

required :updated_at, Time

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 4821

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


3682
# File 'sig/method_ruby/models/accounts/consent_withdraw_response.rbs', line 3682

def to_hash: -> {