Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate
- Defined in:
- lib/method_ruby/models/accounts/consent_withdraw_response.rb
Defined Under Namespace
Modules: Source, Status, Type Classes: AutoLoan, Bnpl, CreditCard, Error, Fintech, Mortgage, PersonalLoan, StudentLoan, StudentLoans
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this update belongs to.
-
#auto_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::AutoLoan?
Auto loan update data.
-
#bnpl ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Bnpl?
Buy now pay later update data.
-
#created_at ⇒ Time
Timestamp when the update was created.
-
#credit_card ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::CreditCard?
Credit card update data.
-
#data_as_of ⇒ Time?
The timestamp of the data used to complete this update.
-
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Error?
Error details when an account update fails.
-
#fintech ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Fintech?
Fintech account update data.
-
#id ⇒ String
Unique identifier for the update.
-
#mortgage ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Mortgage?
Mortgage update data.
-
#personal_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::PersonalLoan?
Personal loan update data.
-
#source ⇒ Symbol, ...
The data source used for this update.
-
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Status
Current status of the update.
-
#student_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::StudentLoan?
Student loan update data.
-
#student_loans ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::StudentLoans?
Student loans aggregate update data.
-
#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Type
The liability type of the account being updated.
-
#updated_at ⇒ Time
Timestamp when the update was last updated.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(balance: nil, closed_at: nil, expected_payoff_date: nil, interest_rate_percentage: nil, interest_rate_source: nil, interest_rate_type: nil, last_payment_amount: nil, last_payment_date: nil, next_payment_due_date: nil, next_payment_minimum_amount: nil, opened_at: nil, original_loan_amount: nil, sub_type: nil, term_length: nil) ⇒ Object
Student loan update data. Present when ‘type` is `student_loan`.
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6367
|
Instance Attribute Details
#account_id ⇒ String
The account this update belongs to.
6254 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6254 required :account_id, String |
#auto_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::AutoLoan?
Auto loan update data. Present when ‘type` is `auto_loan`.
6286 6287 6288 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6286 optional :auto_loan, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::AutoLoan }, nil?: true |
#bnpl ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Bnpl?
Buy now pay later update data. Present when ‘type` is `bnpl`.
6294 6295 6296 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6294 optional :bnpl, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Bnpl }, nil?: true |
#created_at ⇒ Time
Timestamp when the update was created.
6260 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6260 required :created_at, Time |
#credit_card ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::CreditCard?
Credit card update data. Present when ‘type` is `credit_card`.
6302 6303 6304 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6302 optional :credit_card, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::CreditCard }, nil?: true |
#data_as_of ⇒ Time?
The timestamp of the data used to complete this update.
6310 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6310 optional :data_as_of, Time, nil?: true |
#error ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Error?
Error details when an account update fails.
6316 6317 6318 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6316 optional :error, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Error }, nil?: true |
#fintech ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Fintech?
Fintech account update data. Present when ‘type` is `fintech`.
6324 6325 6326 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6324 optional :fintech, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Fintech }, nil?: true |
#id ⇒ String
Unique identifier for the update.
6248 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6248 required :id, String |
#mortgage ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Mortgage?
Mortgage update data. Present when ‘type` is `mortgage`.
6332 6333 6334 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6332 optional :mortgage, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Mortgage }, nil?: true |
#personal_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::PersonalLoan?
Personal loan update data. Present when ‘type` is `personal_loan`.
6340 6341 6342 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6340 optional :personal_loan, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::PersonalLoan }, nil?: true |
#source ⇒ Symbol, ...
The data source used for this update.
6348 6349 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6348 optional :source, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Source } |
#status ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Status
Current status of the update.
6266 6267 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6266 required :status, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Status } |
#student_loan ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::StudentLoan?
Student loan update data. Present when ‘type` is `student_loan`.
6355 6356 6357 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6355 optional :student_loan, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::StudentLoan }, nil?: true |
#student_loans ⇒ MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::StudentLoans?
Student loans aggregate update data. Present when ‘type` is `student_loans`.
6363 6364 6365 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6363 optional :student_loans, -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::StudentLoans }, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Type
The liability type of the account being updated.
6273 6274 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6273 required :type, enum: -> { MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountLiabilityResource::Update::AccountUpdate::Type } |
#updated_at ⇒ Time
Timestamp when the update was last updated.
6280 |
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6280 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 6414
|