Class: MethodRuby::Models::Entity::EntityCorporationResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Entity::EntityCorporationResource
- Defined in:
- lib/method_ruby/models/entity.rb
Defined Under Namespace
Modules: Status, Type Classes: Error
Instance Attribute Summary collapse
-
#address ⇒ MethodRuby::Models::Address?
Postal mailing address.
- #corporation ⇒ MethodRuby::Models::EntityCorporation?
-
#created_at ⇒ Time
Timestamp when the entity was created.
-
#error ⇒ MethodRuby::Models::Entity::EntityCorporationResource::Error?
Error details when an entity is disabled or verification fails.
-
#id ⇒ String
Unique identifier for the entity.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityCorporationResource::Status
Current status of the entity.
- #type ⇒ Symbol, MethodRuby::Models::Entity::EntityCorporationResource::Type
-
#updated_at ⇒ Time
Timestamp when the entity was last updated.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, status:, type:, updated_at:, address: nil, corporation: nil, error: nil, metadata: nil) ⇒ Object
|
|
# File 'lib/method_ruby/models/entity.rb', line 16816
|
Instance Attribute Details
#address ⇒ MethodRuby::Models::Address?
Postal mailing address.
16795 |
# File 'lib/method_ruby/models/entity.rb', line 16795 optional :address, -> { MethodRuby::Address } |
#corporation ⇒ MethodRuby::Models::EntityCorporation?
16800 |
# File 'lib/method_ruby/models/entity.rb', line 16800 optional :corporation, -> { MethodRuby::EntityCorporation }, nil?: true |
#created_at ⇒ Time
Timestamp when the entity was created.
16772 |
# File 'lib/method_ruby/models/entity.rb', line 16772 required :created_at, Time |
#error ⇒ MethodRuby::Models::Entity::EntityCorporationResource::Error?
Error details when an entity is disabled or verification fails.
16806 |
# File 'lib/method_ruby/models/entity.rb', line 16806 optional :error, -> { MethodRuby::Entity::EntityCorporationResource::Error }, nil?: true |
#id ⇒ String
Unique identifier for the entity.
16766 |
# File 'lib/method_ruby/models/entity.rb', line 16766 required :id, String |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
16812 16813 16814 |
# File 'lib/method_ruby/models/entity.rb', line 16812 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityCorporationResource::Status
Current status of the entity.
16778 |
# File 'lib/method_ruby/models/entity.rb', line 16778 required :status, enum: -> { MethodRuby::Entity::EntityCorporationResource::Status } |
#type ⇒ Symbol, MethodRuby::Models::Entity::EntityCorporationResource::Type
16783 |
# File 'lib/method_ruby/models/entity.rb', line 16783 required :type, enum: -> { MethodRuby::Entity::EntityCorporationResource::Type } |
#updated_at ⇒ Time
Timestamp when the entity was last updated.
16789 |
# File 'lib/method_ruby/models/entity.rb', line 16789 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/entity.rb', line 16845
|