Class: MethodRuby::Models::Entity::EntityIndividualResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Entity::EntityIndividualResource
- Defined in:
- lib/method_ruby/models/entity.rb
Defined Under Namespace
Modules: Attribute, Connect, CreditScore, Status, Type, Vehicle Classes: Error, Verification
Instance Attribute Summary collapse
-
#address ⇒ MethodRuby::Models::Address?
Postal mailing address.
-
#attribute ⇒ String, ...
Expandable.
-
#available_subscriptions ⇒ Array<String>
Subscriptions available for this entity.
-
#connect ⇒ String, ...
Expandable.
-
#created_at ⇒ Time
Timestamp when the entity was created.
-
#credit_score ⇒ String, ...
Expandable.
-
#error ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Error?
Error details when an entity is disabled or verification fails.
-
#id ⇒ String
Unique identifier for the entity.
- #individual ⇒ MethodRuby::Models::EntityIndividual?
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
-
#products ⇒ Array<String>
Products currently active for this entity.
-
#restricted_products ⇒ Array<String>
Products restricted for this entity.
-
#restricted_subscriptions ⇒ Array<String>
Subscriptions restricted for this entity.
-
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Status
Current status of the entity.
-
#subscriptions ⇒ Array<String>
Active subscriptions for this entity.
- #type ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Type
-
#updated_at ⇒ Time
Timestamp when the entity was last updated.
-
#vehicle ⇒ String, ...
Expandable.
- #verification ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Verification?
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, MethodRuby::Models::Entity::EntityIndividualResource::Vehicle::EntityVehicle)
Instance Method Summary collapse
- #initialize(major_color: nil, make: nil, model: nil, series: nil, style: nil, vin: nil, year: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(major_color: nil, make: nil, model: nil, series: nil, style: nil, vin: nil, year: nil) ⇒ Object
|
|
# File 'lib/method_ruby/models/entity.rb', line 131
|
Instance Attribute Details
#address ⇒ MethodRuby::Models::Address?
Postal mailing address.
79 |
# File 'lib/method_ruby/models/entity.rb', line 79 optional :address, -> { MethodRuby::Address } |
#attribute ⇒ String, ...
Expandable. The entity attribute ID or expanded attribute object.
85 |
# File 'lib/method_ruby/models/entity.rb', line 85 optional :attribute, union: -> { MethodRuby::Entity::EntityIndividualResource::Attribute }, nil?: true |
#available_subscriptions ⇒ Array<String>
Subscriptions available for this entity.
26 |
# File 'lib/method_ruby/models/entity.rb', line 26 required :available_subscriptions, MethodRuby::Internal::Type::ArrayOf[String] |
#connect ⇒ String, ...
Expandable. The entity connect session ID or expanded connect object.
91 |
# File 'lib/method_ruby/models/entity.rb', line 91 optional :connect, union: -> { MethodRuby::Entity::EntityIndividualResource::Connect }, nil?: true |
#created_at ⇒ Time
Timestamp when the entity was created.
32 |
# File 'lib/method_ruby/models/entity.rb', line 32 required :created_at, Time |
#credit_score ⇒ String, ...
Expandable. The entity credit score ID or expanded credit score object.
97 98 99 |
# File 'lib/method_ruby/models/entity.rb', line 97 optional :credit_score, union: -> { MethodRuby::Entity::EntityIndividualResource::CreditScore }, nil?: true |
#error ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Error?
Error details when an entity is disabled or verification fails.
105 |
# File 'lib/method_ruby/models/entity.rb', line 105 optional :error, -> { MethodRuby::Entity::EntityIndividualResource::Error }, nil?: true |
#id ⇒ String
Unique identifier for the entity.
20 |
# File 'lib/method_ruby/models/entity.rb', line 20 required :id, String |
#individual ⇒ MethodRuby::Models::EntityIndividual?
110 |
# File 'lib/method_ruby/models/entity.rb', line 110 optional :individual, -> { MethodRuby::EntityIndividual }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
116 117 118 |
# File 'lib/method_ruby/models/entity.rb', line 116 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#products ⇒ Array<String>
Products currently active for this entity.
38 |
# File 'lib/method_ruby/models/entity.rb', line 38 required :products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_products ⇒ Array<String>
Products restricted for this entity.
44 |
# File 'lib/method_ruby/models/entity.rb', line 44 required :restricted_products, MethodRuby::Internal::Type::ArrayOf[String] |
#restricted_subscriptions ⇒ Array<String>
Subscriptions restricted for this entity.
50 |
# File 'lib/method_ruby/models/entity.rb', line 50 required :restricted_subscriptions, MethodRuby::Internal::Type::ArrayOf[String] |
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Status
Current status of the entity.
56 |
# File 'lib/method_ruby/models/entity.rb', line 56 required :status, enum: -> { MethodRuby::Entity::EntityIndividualResource::Status } |
#subscriptions ⇒ Array<String>
Active subscriptions for this entity.
62 |
# File 'lib/method_ruby/models/entity.rb', line 62 required :subscriptions, MethodRuby::Internal::Type::ArrayOf[String] |
#type ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Type
67 |
# File 'lib/method_ruby/models/entity.rb', line 67 required :type, enum: -> { MethodRuby::Entity::EntityIndividualResource::Type } |
#updated_at ⇒ Time
Timestamp when the entity was last updated.
73 |
# File 'lib/method_ruby/models/entity.rb', line 73 required :updated_at, Time |
#vehicle ⇒ String, ...
Expandable. The entity vehicle ID or expanded vehicle object.
124 |
# File 'lib/method_ruby/models/entity.rb', line 124 optional :vehicle, union: -> { MethodRuby::Entity::EntityIndividualResource::Vehicle }, nil?: true |
#verification ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Verification?
129 |
# File 'lib/method_ruby/models/entity.rb', line 129 optional :verification, -> { MethodRuby::Entity::EntityIndividualResource::Verification }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/entity.rb', line 180
|
.variants ⇒ Array(String, MethodRuby::Models::Entity::EntityIndividualResource::Vehicle::EntityVehicle)
|
|
# File 'lib/method_ruby/models/entity.rb', line 673
|