Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession
- Defined in:
- lib/method_ruby/models/entity.rb
Defined Under Namespace
Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this verification session belongs to.
-
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
-
#created_at ⇒ Time
Timestamp when the verification session was created.
-
#error ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
-
#id ⇒ String
Unique identifier for the verification session.
-
#instant ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
-
#micro_deposits ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
-
#mx ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
-
#network ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
-
#plaid ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
-
#pre_auth ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
-
#standard ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
-
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
-
#teller ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
-
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
-
#type ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
-
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(number: nil) ⇒ Object
constructor
Populated when the verification session is of type standard.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(number: nil) ⇒ Object
Populated when the verification session is of type standard.
|
|
# File 'lib/method_ruby/models/entity.rb', line 1945
|
Instance Attribute Details
#account_id ⇒ String
The account this verification session belongs to.
1815 |
# File 'lib/method_ruby/models/entity.rb', line 1815 required :account_id, String |
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
1847 |
# File 'lib/method_ruby/models/entity.rb', line 1847 optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true |
#created_at ⇒ Time
Timestamp when the verification session was created.
1821 |
# File 'lib/method_ruby/models/entity.rb', line 1821 required :created_at, Time |
#error ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
1853 1854 1855 1856 1857 |
# File 'lib/method_ruby/models/entity.rb', line 1853 optional :error, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Error }, nil?: true |
#id ⇒ String
Unique identifier for the verification session.
1809 |
# File 'lib/method_ruby/models/entity.rb', line 1809 required :id, String |
#instant ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
1863 1864 1865 1866 1867 |
# File 'lib/method_ruby/models/entity.rb', line 1863 optional :instant, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant }, nil?: true |
#micro_deposits ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
1873 1874 1875 1876 1877 |
# File 'lib/method_ruby/models/entity.rb', line 1873 optional :micro_deposits, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits }, nil?: true |
#mx ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
1883 1884 1885 1886 1887 |
# File 'lib/method_ruby/models/entity.rb', line 1883 optional :mx, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Mx }, nil?: true |
#network ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
1893 1894 1895 1896 1897 |
# File 'lib/method_ruby/models/entity.rb', line 1893 optional :network, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Network }, nil?: true |
#plaid ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
1903 1904 1905 1906 1907 |
# File 'lib/method_ruby/models/entity.rb', line 1903 optional :plaid, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Plaid }, nil?: true |
#pre_auth ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
1913 1914 1915 1916 1917 |
# File 'lib/method_ruby/models/entity.rb', line 1913 optional :pre_auth, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::PreAuth }, nil?: true |
#standard ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
1923 1924 1925 1926 1927 |
# File 'lib/method_ruby/models/entity.rb', line 1923 optional :standard, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Standard }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
1827 1828 |
# File 'lib/method_ruby/models/entity.rb', line 1827 required :status, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Status } |
#teller ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
1933 1934 1935 1936 1937 |
# File 'lib/method_ruby/models/entity.rb', line 1933 optional :teller, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Teller }, nil?: true |
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
1943 |
# File 'lib/method_ruby/models/entity.rb', line 1943 optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
1834 1835 |
# File 'lib/method_ruby/models/entity.rb', line 1834 required :type, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Type } |
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
1841 |
# File 'lib/method_ruby/models/entity.rb', line 1841 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/entity.rb', line 1993
|