Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant
- Defined in:
- lib/method_ruby/models/entity.rb
Overview
Defined Under Namespace
Modules: ExpCheck
Instance Attribute Summary collapse
-
#exp_check ⇒ Symbol, ...
The card expiration verification check result.
-
#exp_month ⇒ String?
The masked card expiration month.
-
#exp_year ⇒ String?
The masked card expiration year.
-
#number ⇒ String?
The masked card number.
Instance Method Summary collapse
-
#initialize(exp_check: nil, exp_month: nil, exp_year: nil, number: nil) ⇒ Object
constructor
Populated when the verification session is of type instant.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(exp_check: nil, exp_month: nil, exp_year: nil, number: nil) ⇒ Object
Populated when the verification session is of type instant.
|
|
# File 'lib/method_ruby/models/entity.rb', line 2133
|
Instance Attribute Details
#exp_check ⇒ Symbol, ...
The card expiration verification check result.
2109 2110 2111 2112 2113 |
# File 'lib/method_ruby/models/entity.rb', line 2109 optional :exp_check, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::Instant::ExpCheck }, nil?: true |
#exp_month ⇒ String?
The masked card expiration month. Null if it still needs to be provided.
2119 |
# File 'lib/method_ruby/models/entity.rb', line 2119 optional :exp_month, String, nil?: true |
#exp_year ⇒ String?
The masked card expiration year. Null if it still needs to be provided.
2125 |
# File 'lib/method_ruby/models/entity.rb', line 2125 optional :exp_year, String, nil?: true |
#number ⇒ String?
The masked card number. Null if the number still needs to be provided.
2131 |
# File 'lib/method_ruby/models/entity.rb', line 2131 optional :number, String, nil?: true |