Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountACHResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits
- Defined in:
- lib/method_ruby/models/entity.rb,
sig/method_ruby/models/entity.rbs
Overview
Instance Attribute Summary collapse
-
#amounts ⇒ Array<Integer>?
The latest amounts that this verification session was updated with.
Instance Method Summary collapse
-
#initialize ⇒ MicroDeposits
constructor
A new instance of MicroDeposits.
- #to_hash ⇒ { amounts: ::Array[Integer] }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ MicroDeposits
Returns a new instance of MicroDeposits.
1610 |
# File 'sig/method_ruby/models/entity.rbs', line 1610
def initialize: (?amounts: ::Array[Integer]) -> void
|
Instance Attribute Details
#amounts ⇒ Array<Integer>?
The latest amounts that this verification session was updated with.
2165 |
# File 'lib/method_ruby/models/entity.rb', line 2165 optional :amounts, MethodRuby::Internal::Type::ArrayOf[Integer] |
Instance Method Details
#to_hash ⇒ { amounts: ::Array[Integer] }
1612 |
# File 'sig/method_ruby/models/entity.rbs', line 1612
def to_hash: -> { amounts: ::Array[Integer] }
|