Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Attribute::AccountAttribute
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Attribute::AccountAttribute
- Defined in:
- lib/method_ruby/models/entity.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this attribute belongs to.
-
#attributes ⇒ Hash{Symbol=>Object}
Financial data attributes for the account.
-
#created_at ⇒ Time
Timestamp when the attribute was created.
- #error ⇒ MethodRuby::Models::ResourceError?
-
#id ⇒ String
Unique identifier for the account attribute.
-
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Attribute::AccountAttribute::Status
Current status of the attribute request.
-
#updated_at ⇒ Time
Timestamp when the attribute was last updated.
Instance Method Summary collapse
-
#initialize(id:, account_id:, attributes:, created_at:, status:, updated_at:, error: nil) ⇒ Object
constructor
An attribute record for an account containing financial data attributes.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, account_id:, attributes:, created_at:, status:, updated_at:, error: nil) ⇒ Object
An attribute record for an account containing financial data attributes.
|
|
# File 'lib/method_ruby/models/entity.rb', line 8550
|
Instance Attribute Details
#account_id ⇒ String
The account this attribute belongs to.
8518 |
# File 'lib/method_ruby/models/entity.rb', line 8518 required :account_id, String |
#attributes ⇒ Hash{Symbol=>Object}
Financial data attributes for the account.
8524 |
# File 'lib/method_ruby/models/entity.rb', line 8524 required :attributes, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown] |
#created_at ⇒ Time
Timestamp when the attribute was created.
8530 |
# File 'lib/method_ruby/models/entity.rb', line 8530 required :created_at, Time |
#error ⇒ MethodRuby::Models::ResourceError?
8548 |
# File 'lib/method_ruby/models/entity.rb', line 8548 optional :error, -> { MethodRuby::ResourceError }, nil?: true |
#id ⇒ String
Unique identifier for the account attribute.
8512 |
# File 'lib/method_ruby/models/entity.rb', line 8512 required :id, String |
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Attribute::AccountAttribute::Status
Current status of the attribute request.
8536 8537 |
# File 'lib/method_ruby/models/entity.rb', line 8536 required :status, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Attribute::AccountAttribute::Status } |
#updated_at ⇒ Time
Timestamp when the attribute was last updated.
8543 |
# File 'lib/method_ruby/models/entity.rb', line 8543 required :updated_at, Time |