Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/entity.rb

Defined Under Namespace

Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(number: nil) ⇒ Object

Populated when the verification session is of type standard.

Parameters:

  • number (String, nil) (defaults to: nil)

    The masked card number. Null if the number still needs to be provided.



# File 'lib/method_ruby/models/entity.rb', line 9321

Instance Attribute Details

#account_idString

The account this verification session belongs to.

Returns:

  • (String)


9191
# File 'lib/method_ruby/models/entity.rb', line 9191

required :account_id, String

#auto_verifyObject?

Populated when the verification session is of type auto_verify.

Returns:

  • (Object, nil)


9223
# File 'lib/method_ruby/models/entity.rb', line 9223

optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true

#created_atTime

Timestamp when the verification session was created.

Returns:

  • (Time)


9197
# File 'lib/method_ruby/models/entity.rb', line 9197

required :created_at, Time

#errorMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Error?

Error details when an account verification session fails.



9229
9230
9231
9232
9233
# File 'lib/method_ruby/models/entity.rb', line 9229

optional :error,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Error
},
nil?: true

#idString

Unique identifier for the verification session.

Returns:

  • (String)


9185
# File 'lib/method_ruby/models/entity.rb', line 9185

required :id, String

#instantMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Instant?

Populated when the verification session is of type instant.



9239
9240
9241
9242
9243
# File 'lib/method_ruby/models/entity.rb', line 9239

optional :instant,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Instant
},
nil?: true

#micro_depositsMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?

Populated when the verification session is of type micro_deposits.



9249
9250
9251
9252
9253
# File 'lib/method_ruby/models/entity.rb', line 9249

optional :micro_deposits,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits
},
nil?: true

#mxMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Mx?

Populated when the verification session is of type mx.



9259
9260
9261
9262
9263
# File 'lib/method_ruby/models/entity.rb', line 9259

optional :mx,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Mx
},
nil?: true

#networkMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network?

Populated when the verification session is of type network.



9269
9270
9271
9272
9273
# File 'lib/method_ruby/models/entity.rb', line 9269

optional :network,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Network
},
nil?: true

#plaidMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Plaid?

Populated when the verification session is of type plaid.



9279
9280
9281
9282
9283
# File 'lib/method_ruby/models/entity.rb', line 9279

optional :plaid,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Plaid
},
nil?: true

#pre_authMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth?

Populated when the verification session is of type pre_auth.



9289
9290
9291
9292
9293
# File 'lib/method_ruby/models/entity.rb', line 9289

optional :pre_auth,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth
},
nil?: true

#standardMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Standard?

Populated when the verification session is of type standard.



9299
9300
9301
9302
9303
# File 'lib/method_ruby/models/entity.rb', line 9299

optional :standard,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Standard
},
nil?: true

#statusSymbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Status

Current status of the verification session.



9203
9204
# File 'lib/method_ruby/models/entity.rb', line 9203

required :status,
enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Status }

#tellerMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Teller?

Populated when the verification session is of type teller.



9309
9310
9311
9312
9313
# File 'lib/method_ruby/models/entity.rb', line 9309

optional :teller,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Teller
},
nil?: true

#trusted_provisionerObject?

Populated when the verification session is of type trusted_provisioner.

Returns:

  • (Object, nil)


9319
# File 'lib/method_ruby/models/entity.rb', line 9319

optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true

#typeSymbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Type

The type of verification.



9210
9211
# File 'lib/method_ruby/models/entity.rb', line 9210

required :type,
enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::Type }

#updated_atTime

Timestamp when the verification session was last updated.

Returns:

  • (Time)


9217
# File 'lib/method_ruby/models/entity.rb', line 9217

required :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/entity.rb', line 9369