Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/entity.rb

Overview

See Also:

Defined Under Namespace

Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, PreAuthCheck

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, number: nil, pre_auth_check: nil) ⇒ Object

Populated when the verification session is of type pre_auth.

Parameters:



# File 'lib/method_ruby/models/entity.rb', line 9815

Instance Attribute Details

#billing_zip_codeString?

The masked billing zip code.

Returns:

  • (String, nil)


9749
# File 'lib/method_ruby/models/entity.rb', line 9749

optional :billing_zip_code, String, nil?: true

#billing_zip_code_checkSymbol, ...

The billing zip code verification check result.



9755
9756
9757
9758
9759
# File 'lib/method_ruby/models/entity.rb', line 9755

optional :billing_zip_code_check,
enum: -> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth::BillingZipCodeCheck
},
nil?: true

#cvvString?

The masked card CVV. Null if it still needs to be provided.

Returns:

  • (String, nil)


9765
# File 'lib/method_ruby/models/entity.rb', line 9765

optional :cvv, String, nil?: true

#cvv_checkSymbol, ...

The card CVV verification check result.



9771
9772
9773
9774
9775
# File 'lib/method_ruby/models/entity.rb', line 9771

optional :cvv_check,
enum: -> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth::CvvCheck
},
nil?: true

#exp_checkSymbol, ...

The card expiration verification check result.



9781
9782
9783
9784
9785
# File 'lib/method_ruby/models/entity.rb', line 9781

optional :exp_check,
enum: -> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth::ExpCheck
},
nil?: true

#exp_monthString?

The masked card expiration month. Null if it still needs to be provided.

Returns:

  • (String, nil)


9791
# File 'lib/method_ruby/models/entity.rb', line 9791

optional :exp_month, String, nil?: true

#exp_yearString?

The masked card expiration year. Null if it still needs to be provided.

Returns:

  • (String, nil)


9797
# File 'lib/method_ruby/models/entity.rb', line 9797

optional :exp_year, String, nil?: true

#numberString?

The masked card number. Null if the number still needs to be provided.

Returns:

  • (String, nil)


9803
# File 'lib/method_ruby/models/entity.rb', line 9803

optional :number, String, nil?: true

#pre_auth_checkSymbol, ...

The pre-auth verification check result.



9809
9810
9811
9812
9813
# File 'lib/method_ruby/models/entity.rb', line 9809

optional :pre_auth_check,
enum: -> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::LatestVerificationSession::AccountVerificationSession::PreAuth::PreAuthCheck
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/entity.rb', line 9846