Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate
- Defined in:
- lib/method_ruby/models/entity.rb
Defined Under Namespace
Modules: Source, Status, Type Classes: AutoLoan, Bnpl, CreditCard, Error, Fintech, Mortgage, PersonalLoan, StudentLoan, StudentLoans
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this update belongs to.
-
#auto_loan ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::AutoLoan?
Auto loan update data.
-
#bnpl ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Bnpl?
Buy now pay later update data.
-
#created_at ⇒ Time
Timestamp when the update was created.
-
#credit_card ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::CreditCard?
Credit card update data.
-
#data_as_of ⇒ Time?
The timestamp of the data used to complete this update.
-
#error ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Error?
Error details when an account update fails.
-
#fintech ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Fintech?
Fintech account update data.
-
#id ⇒ String
Unique identifier for the update.
-
#mortgage ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Mortgage?
Mortgage update data.
-
#personal_loan ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::PersonalLoan?
Personal loan update data.
-
#source ⇒ Symbol, ...
The data source used for this update.
-
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Status
Current status of the update.
-
#student_loan ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::StudentLoan?
Student loan update data.
-
#student_loans ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::StudentLoans?
Student loans aggregate update data.
-
#type ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Type
The liability type of the account being updated.
-
#updated_at ⇒ Time
Timestamp when the update was last updated.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(balance: nil, closed_at: nil, expected_payoff_date: nil, interest_rate_percentage: nil, interest_rate_source: nil, interest_rate_type: nil, last_payment_amount: nil, last_payment_date: nil, next_payment_due_date: nil, next_payment_minimum_amount: nil, opened_at: nil, original_loan_amount: nil, sub_type: nil, term_length: nil) ⇒ Object
Student loan update data. Present when ‘type` is `student_loan`.
|
|
# File 'lib/method_ruby/models/entity.rb', line 10963
|
Instance Attribute Details
#account_id ⇒ String
The account this update belongs to.
10832 |
# File 'lib/method_ruby/models/entity.rb', line 10832 required :account_id, String |
#auto_loan ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::AutoLoan?
Auto loan update data. Present when ‘type` is `auto_loan`.
10864 10865 10866 10867 10868 |
# File 'lib/method_ruby/models/entity.rb', line 10864 optional :auto_loan, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::AutoLoan }, nil?: true |
#bnpl ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Bnpl?
Buy now pay later update data. Present when ‘type` is `bnpl`.
10874 10875 10876 10877 10878 |
# File 'lib/method_ruby/models/entity.rb', line 10874 optional :bnpl, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Bnpl }, nil?: true |
#created_at ⇒ Time
Timestamp when the update was created.
10838 |
# File 'lib/method_ruby/models/entity.rb', line 10838 required :created_at, Time |
#credit_card ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::CreditCard?
Credit card update data. Present when ‘type` is `credit_card`.
10884 10885 10886 10887 10888 |
# File 'lib/method_ruby/models/entity.rb', line 10884 optional :credit_card, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::CreditCard }, nil?: true |
#data_as_of ⇒ Time?
The timestamp of the data used to complete this update.
10894 |
# File 'lib/method_ruby/models/entity.rb', line 10894 optional :data_as_of, Time, nil?: true |
#error ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Error?
Error details when an account update fails.
10900 10901 10902 10903 10904 |
# File 'lib/method_ruby/models/entity.rb', line 10900 optional :error, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Error }, nil?: true |
#fintech ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Fintech?
Fintech account update data. Present when ‘type` is `fintech`.
10910 10911 10912 10913 10914 |
# File 'lib/method_ruby/models/entity.rb', line 10910 optional :fintech, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Fintech }, nil?: true |
#id ⇒ String
Unique identifier for the update.
10826 |
# File 'lib/method_ruby/models/entity.rb', line 10826 required :id, String |
#mortgage ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Mortgage?
Mortgage update data. Present when ‘type` is `mortgage`.
10920 10921 10922 10923 10924 |
# File 'lib/method_ruby/models/entity.rb', line 10920 optional :mortgage, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Mortgage }, nil?: true |
#personal_loan ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::PersonalLoan?
Personal loan update data. Present when ‘type` is `personal_loan`.
10930 10931 10932 10933 10934 |
# File 'lib/method_ruby/models/entity.rb', line 10930 optional :personal_loan, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::PersonalLoan }, nil?: true |
#source ⇒ Symbol, ...
The data source used for this update.
10940 10941 |
# File 'lib/method_ruby/models/entity.rb', line 10940 optional :source, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Source } |
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Status
Current status of the update.
10844 10845 |
# File 'lib/method_ruby/models/entity.rb', line 10844 required :status, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Status } |
#student_loan ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::StudentLoan?
Student loan update data. Present when ‘type` is `student_loan`.
10947 10948 10949 10950 10951 |
# File 'lib/method_ruby/models/entity.rb', line 10947 optional :student_loan, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::StudentLoan }, nil?: true |
#student_loans ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::StudentLoans?
Student loans aggregate update data. Present when ‘type` is `student_loans`.
10957 10958 10959 10960 10961 |
# File 'lib/method_ruby/models/entity.rb', line 10957 optional :student_loans, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::StudentLoans }, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Type
The liability type of the account being updated.
10851 10852 |
# File 'lib/method_ruby/models/entity.rb', line 10851 required :type, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountClearingResource::Update::AccountUpdate::Type } |
#updated_at ⇒ Time
Timestamp when the update was last updated.
10858 |
# File 'lib/method_ruby/models/entity.rb', line 10858 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/entity.rb', line 11010
|