Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/entity.rb

Defined Under Namespace

Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(number: nil) ⇒ Object

Populated when the verification session is of type standard.

Parameters:

  • number (String, nil) (defaults to: nil)

    The masked card number. Null if the number still needs to be provided.



# File 'lib/method_ruby/models/entity.rb', line 12997

Instance Attribute Details

#account_idString

The account this verification session belongs to.

Returns:

  • (String)


12867
# File 'lib/method_ruby/models/entity.rb', line 12867

required :account_id, String

#auto_verifyObject?

Populated when the verification session is of type auto_verify.

Returns:

  • (Object, nil)


12899
# File 'lib/method_ruby/models/entity.rb', line 12899

optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true

#created_atTime

Timestamp when the verification session was created.

Returns:

  • (Time)


12873
# File 'lib/method_ruby/models/entity.rb', line 12873

required :created_at, Time

#errorMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Error?

Error details when an account verification session fails.



12905
12906
12907
12908
12909
# File 'lib/method_ruby/models/entity.rb', line 12905

optional :error,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Error
},
nil?: true

#idString

Unique identifier for the verification session.

Returns:

  • (String)


12861
# File 'lib/method_ruby/models/entity.rb', line 12861

required :id, String

#instantMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Instant?

Populated when the verification session is of type instant.



12915
12916
12917
12918
12919
# File 'lib/method_ruby/models/entity.rb', line 12915

optional :instant,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Instant
},
nil?: true

#micro_depositsMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?

Populated when the verification session is of type micro_deposits.



12925
12926
12927
12928
12929
# File 'lib/method_ruby/models/entity.rb', line 12925

optional :micro_deposits,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits
},
nil?: true

#mxMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Mx?

Populated when the verification session is of type mx.



12935
12936
12937
12938
12939
# File 'lib/method_ruby/models/entity.rb', line 12935

optional :mx,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Mx
},
nil?: true

#networkMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network?

Populated when the verification session is of type network.



12945
12946
12947
12948
12949
# File 'lib/method_ruby/models/entity.rb', line 12945

optional :network,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Network
},
nil?: true

#plaidMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Plaid?

Populated when the verification session is of type plaid.



12955
12956
12957
12958
12959
# File 'lib/method_ruby/models/entity.rb', line 12955

optional :plaid,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Plaid
},
nil?: true

#pre_authMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth?

Populated when the verification session is of type pre_auth.



12965
12966
12967
12968
12969
# File 'lib/method_ruby/models/entity.rb', line 12965

optional :pre_auth,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth
},
nil?: true

#standardMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Standard?

Populated when the verification session is of type standard.



12975
12976
12977
12978
12979
# File 'lib/method_ruby/models/entity.rb', line 12975

optional :standard,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Standard
},
nil?: true

#statusSymbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Status

Current status of the verification session.



12879
12880
# File 'lib/method_ruby/models/entity.rb', line 12879

required :status,
enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Status }

#tellerMethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Teller?

Populated when the verification session is of type teller.



12985
12986
12987
12988
12989
# File 'lib/method_ruby/models/entity.rb', line 12985

optional :teller,
-> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Teller
},
nil?: true

#trusted_provisionerObject?

Populated when the verification session is of type trusted_provisioner.

Returns:

  • (Object, nil)


12995
# File 'lib/method_ruby/models/entity.rb', line 12995

optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true

#typeSymbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Type

The type of verification.



12886
12887
# File 'lib/method_ruby/models/entity.rb', line 12886

required :type,
enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::Type }

#updated_atTime

Timestamp when the verification session was last updated.

Returns:

  • (Time)


12893
# File 'lib/method_ruby/models/entity.rb', line 12893

required :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/entity.rb', line 13045