Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/entity.rb

Overview

See Also:

Defined Under Namespace

Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, PreAuthCheck

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, number: nil, pre_auth_check: nil) ⇒ Object

Populated when the verification session is of type pre_auth.

Parameters:



# File 'lib/method_ruby/models/entity.rb', line 13491

Instance Attribute Details

#billing_zip_codeString?

The masked billing zip code.

Returns:

  • (String, nil)


13425
# File 'lib/method_ruby/models/entity.rb', line 13425

optional :billing_zip_code, String, nil?: true

#billing_zip_code_checkSymbol, ...

The billing zip code verification check result.



13431
13432
13433
13434
13435
# File 'lib/method_ruby/models/entity.rb', line 13431

optional :billing_zip_code_check,
enum: -> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::BillingZipCodeCheck
},
nil?: true

#cvvString?

The masked card CVV. Null if it still needs to be provided.

Returns:

  • (String, nil)


13441
# File 'lib/method_ruby/models/entity.rb', line 13441

optional :cvv, String, nil?: true

#cvv_checkSymbol, ...

The card CVV verification check result.



13447
13448
13449
13450
13451
# File 'lib/method_ruby/models/entity.rb', line 13447

optional :cvv_check,
enum: -> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::CvvCheck
},
nil?: true

#exp_checkSymbol, ...

The card expiration verification check result.



13457
13458
13459
13460
13461
# File 'lib/method_ruby/models/entity.rb', line 13457

optional :exp_check,
enum: -> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::ExpCheck
},
nil?: true

#exp_monthString?

The masked card expiration month. Null if it still needs to be provided.

Returns:

  • (String, nil)


13467
# File 'lib/method_ruby/models/entity.rb', line 13467

optional :exp_month, String, nil?: true

#exp_yearString?

The masked card expiration year. Null if it still needs to be provided.

Returns:

  • (String, nil)


13473
# File 'lib/method_ruby/models/entity.rb', line 13473

optional :exp_year, String, nil?: true

#numberString?

The masked card number. Null if the number still needs to be provided.

Returns:

  • (String, nil)


13479
# File 'lib/method_ruby/models/entity.rb', line 13479

optional :number, String, nil?: true

#pre_auth_checkSymbol, ...

The pre-auth verification check result.



13485
13486
13487
13488
13489
# File 'lib/method_ruby/models/entity.rb', line 13485

optional :pre_auth_check,
enum: -> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountDebitCardResource::LatestVerificationSession::AccountVerificationSession::PreAuth::PreAuthCheck
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/entity.rb', line 13522