Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession
- Defined in:
- lib/method_ruby/models/entity.rb
Defined Under Namespace
Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account this verification session belongs to.
-
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
-
#created_at ⇒ Time
Timestamp when the verification session was created.
-
#error ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
-
#id ⇒ String
Unique identifier for the verification session.
-
#instant ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
-
#micro_deposits ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
-
#mx ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
-
#network ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
-
#plaid ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
-
#pre_auth ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
-
#standard ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
-
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
-
#teller ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
-
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
-
#type ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
-
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(number: nil) ⇒ Object
constructor
Populated when the verification session is of type standard.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(number: nil) ⇒ Object
Populated when the verification session is of type standard.
|
|
# File 'lib/method_ruby/models/entity.rb', line 5645
|
Instance Attribute Details
#account_id ⇒ String
The account this verification session belongs to.
5515 |
# File 'lib/method_ruby/models/entity.rb', line 5515 required :account_id, String |
#auto_verify ⇒ Object?
Populated when the verification session is of type auto_verify.
5547 |
# File 'lib/method_ruby/models/entity.rb', line 5547 optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true |
#created_at ⇒ Time
Timestamp when the verification session was created.
5521 |
# File 'lib/method_ruby/models/entity.rb', line 5521 required :created_at, Time |
#error ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error?
Error details when an account verification session fails.
5553 5554 5555 5556 5557 |
# File 'lib/method_ruby/models/entity.rb', line 5553 optional :error, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Error }, nil?: true |
#id ⇒ String
Unique identifier for the verification session.
5509 |
# File 'lib/method_ruby/models/entity.rb', line 5509 required :id, String |
#instant ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant?
Populated when the verification session is of type instant.
5563 5564 5565 5566 5567 |
# File 'lib/method_ruby/models/entity.rb', line 5563 optional :instant, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant }, nil?: true |
#micro_deposits ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits?
Populated when the verification session is of type micro_deposits.
5573 5574 5575 5576 5577 |
# File 'lib/method_ruby/models/entity.rb', line 5573 optional :micro_deposits, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::MicroDeposits }, nil?: true |
#mx ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx?
Populated when the verification session is of type mx.
5583 5584 5585 5586 5587 |
# File 'lib/method_ruby/models/entity.rb', line 5583 optional :mx, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Mx }, nil?: true |
#network ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network?
Populated when the verification session is of type network.
5593 5594 5595 5596 5597 |
# File 'lib/method_ruby/models/entity.rb', line 5593 optional :network, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Network }, nil?: true |
#plaid ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid?
Populated when the verification session is of type plaid.
5603 5604 5605 5606 5607 |
# File 'lib/method_ruby/models/entity.rb', line 5603 optional :plaid, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Plaid }, nil?: true |
#pre_auth ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth?
Populated when the verification session is of type pre_auth.
5613 5614 5615 5616 5617 |
# File 'lib/method_ruby/models/entity.rb', line 5613 optional :pre_auth, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth }, nil?: true |
#standard ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard?
Populated when the verification session is of type standard.
5623 5624 5625 5626 5627 |
# File 'lib/method_ruby/models/entity.rb', line 5623 optional :standard, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Standard }, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status
Current status of the verification session.
5527 5528 |
# File 'lib/method_ruby/models/entity.rb', line 5527 required :status, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Status } |
#teller ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller?
Populated when the verification session is of type teller.
5633 5634 5635 5636 5637 |
# File 'lib/method_ruby/models/entity.rb', line 5633 optional :teller, -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Teller }, nil?: true |
#trusted_provisioner ⇒ Object?
Populated when the verification session is of type trusted_provisioner.
5643 |
# File 'lib/method_ruby/models/entity.rb', line 5643 optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true |
#type ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type
The type of verification.
5534 5535 |
# File 'lib/method_ruby/models/entity.rb', line 5534 required :type, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Type } |
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
5541 |
# File 'lib/method_ruby/models/entity.rb', line 5541 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/entity.rb', line 5693
|