Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/entity.rb

Overview

See Also:

Defined Under Namespace

Modules: ExpCheck

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(exp_check: nil, exp_month: nil, exp_year: nil, number: nil) ⇒ Object

Populated when the verification session is of type instant.

Parameters:



# File 'lib/method_ruby/models/entity.rb', line 5833

Instance Attribute Details

#exp_checkSymbol, ...

The card expiration verification check result.



5809
5810
5811
5812
5813
# File 'lib/method_ruby/models/entity.rb', line 5809

optional :exp_check,
enum: -> {
  MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::Instant::ExpCheck
},
nil?: true

#exp_monthString?

The masked card expiration month. Null if it still needs to be provided.

Returns:

  • (String, nil)


5819
# File 'lib/method_ruby/models/entity.rb', line 5819

optional :exp_month, String, nil?: true

#exp_yearString?

The masked card expiration year. Null if it still needs to be provided.

Returns:

  • (String, nil)


5825
# File 'lib/method_ruby/models/entity.rb', line 5825

optional :exp_year, String, nil?: true

#numberString?

The masked card number. Null if the number still needs to be provided.

Returns:

  • (String, nil)


5831
# File 'lib/method_ruby/models/entity.rb', line 5831

optional :number, String, nil?: true