Class: MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth
- Defined in:
- lib/method_ruby/models/entity.rb
Overview
Defined Under Namespace
Modules: BillingZipCodeCheck, CvvCheck, ExpCheck, PreAuthCheck
Instance Attribute Summary collapse
-
#billing_zip_code ⇒ String?
The masked billing zip code.
-
#billing_zip_code_check ⇒ Symbol, ...
The billing zip code verification check result.
-
#cvv ⇒ String?
The masked card CVV.
-
#cvv_check ⇒ Symbol, ...
The card CVV verification check result.
-
#exp_check ⇒ Symbol, ...
The card expiration verification check result.
-
#exp_month ⇒ String?
The masked card expiration month.
-
#exp_year ⇒ String?
The masked card expiration year.
-
#number ⇒ String?
The masked card number.
-
#pre_auth_check ⇒ Symbol, ...
The pre-auth verification check result.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, number: nil, pre_auth_check: nil) ⇒ Object
constructor
Populated when the verification session is of type pre_auth.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing_zip_code: nil, billing_zip_code_check: nil, cvv: nil, cvv_check: nil, exp_check: nil, exp_month: nil, exp_year: nil, number: nil, pre_auth_check: nil) ⇒ Object
Populated when the verification session is of type pre_auth.
|
|
# File 'lib/method_ruby/models/entity.rb', line 6139
|
Instance Attribute Details
#billing_zip_code ⇒ String?
The masked billing zip code.
6073 |
# File 'lib/method_ruby/models/entity.rb', line 6073 optional :billing_zip_code, String, nil?: true |
#billing_zip_code_check ⇒ Symbol, ...
The billing zip code verification check result.
6079 6080 6081 6082 6083 |
# File 'lib/method_ruby/models/entity.rb', line 6079 optional :billing_zip_code_check, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth::BillingZipCodeCheck }, nil?: true |
#cvv ⇒ String?
The masked card CVV. Null if it still needs to be provided.
6089 |
# File 'lib/method_ruby/models/entity.rb', line 6089 optional :cvv, String, nil?: true |
#cvv_check ⇒ Symbol, ...
The card CVV verification check result.
6095 6096 6097 6098 6099 |
# File 'lib/method_ruby/models/entity.rb', line 6095 optional :cvv_check, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth::CvvCheck }, nil?: true |
#exp_check ⇒ Symbol, ...
The card expiration verification check result.
6105 6106 6107 6108 6109 |
# File 'lib/method_ruby/models/entity.rb', line 6105 optional :exp_check, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth::ExpCheck }, nil?: true |
#exp_month ⇒ String?
The masked card expiration month. Null if it still needs to be provided.
6115 |
# File 'lib/method_ruby/models/entity.rb', line 6115 optional :exp_month, String, nil?: true |
#exp_year ⇒ String?
The masked card expiration year. Null if it still needs to be provided.
6121 |
# File 'lib/method_ruby/models/entity.rb', line 6121 optional :exp_year, String, nil?: true |
#number ⇒ String?
The masked card number. Null if the number still needs to be provided.
6127 |
# File 'lib/method_ruby/models/entity.rb', line 6127 optional :number, String, nil?: true |
#pre_auth_check ⇒ Symbol, ...
The pre-auth verification check result.
6133 6134 6135 6136 6137 |
# File 'lib/method_ruby/models/entity.rb', line 6133 optional :pre_auth_check, enum: -> { MethodRuby::Entity::EntityIndividualResource::Connect::EntityConnect::Account::AccountLiabilityResource::LatestVerificationSession::AccountVerificationSession::PreAuth::PreAuthCheck }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/entity.rb', line 6170
|