Class: MethodRuby::Models::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession
- Defined in:
- lib/method_ruby/models/entity.rb
Defined Under Namespace
Modules: Method, Status, Type Classes: Error
Instance Attribute Summary collapse
-
#byo_kyc ⇒ Object?
BYO KYC verification details.
-
#byo_sms ⇒ Object?
BYO SMS verification details.
-
#created_at ⇒ Time
Timestamp when the verification session was created.
-
#element ⇒ Object?
Element verification details.
-
#entity_id ⇒ String
The ID of the entity this verification session belongs to.
-
#error ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession::Error?
Error details when an entity verification session fails.
-
#expired_at ⇒ Time?
Timestamp when the verification session expired.
-
#id ⇒ String
Unique identifier for the verification session.
-
#kba ⇒ Object?
KBA verification details.
-
#method_ ⇒ Symbol, ...
The verification method used.
-
#opal ⇒ Object?
Opal verification details.
-
#sms ⇒ Object?
SMS verification details.
-
#sna ⇒ Object?
SNA verification details.
-
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession::Status
Current status of the verification session.
-
#type ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession::Type
The type of verification being performed.
-
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, entity_id:, method_:, status:, type:, updated_at:, byo_kyc: nil, byo_sms: nil, element: nil, error: nil, expired_at: nil, kba: nil, opal: nil, sms: nil, sna: nil) ⇒ Object
|
|
# File 'lib/method_ruby/models/entity.rb', line 16590
|
Instance Attribute Details
#byo_kyc ⇒ Object?
BYO KYC verification details. Present when method is byo_kyc.
16536 |
# File 'lib/method_ruby/models/entity.rb', line 16536 optional :byo_kyc, MethodRuby::Internal::Type::Unknown, nil?: true |
#byo_sms ⇒ Object?
BYO SMS verification details. Present when method is byo_sms.
16542 |
# File 'lib/method_ruby/models/entity.rb', line 16542 optional :byo_sms, MethodRuby::Internal::Type::Unknown, nil?: true |
#created_at ⇒ Time
Timestamp when the verification session was created.
16493 |
# File 'lib/method_ruby/models/entity.rb', line 16493 required :created_at, Time |
#element ⇒ Object?
Element verification details. Present when method is element.
16548 |
# File 'lib/method_ruby/models/entity.rb', line 16548 optional :element, MethodRuby::Internal::Type::Unknown, nil?: true |
#entity_id ⇒ String
The ID of the entity this verification session belongs to.
16499 |
# File 'lib/method_ruby/models/entity.rb', line 16499 required :entity_id, String |
#error ⇒ MethodRuby::Models::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession::Error?
Error details when an entity verification session fails.
16554 16555 16556 16557 16558 |
# File 'lib/method_ruby/models/entity.rb', line 16554 optional :error, -> { MethodRuby::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession::Error }, nil?: true |
#expired_at ⇒ Time?
Timestamp when the verification session expired.
16564 |
# File 'lib/method_ruby/models/entity.rb', line 16564 optional :expired_at, Time, nil?: true |
#id ⇒ String
Unique identifier for the verification session.
16487 |
# File 'lib/method_ruby/models/entity.rb', line 16487 required :id, String |
#kba ⇒ Object?
KBA verification details. Present when method is kba.
16570 |
# File 'lib/method_ruby/models/entity.rb', line 16570 optional :kba, MethodRuby::Internal::Type::Unknown, nil?: true |
#method_ ⇒ Symbol, ...
The verification method used.
16505 16506 16507 16508 16509 16510 |
# File 'lib/method_ruby/models/entity.rb', line 16505 required :method_, enum: -> { MethodRuby::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession::Method }, api_name: :method, nil?: true |
#opal ⇒ Object?
Opal verification details. Present when method is opal.
16576 |
# File 'lib/method_ruby/models/entity.rb', line 16576 optional :opal, MethodRuby::Internal::Type::Unknown, nil?: true |
#sms ⇒ Object?
SMS verification details. Present when method is sms.
16582 |
# File 'lib/method_ruby/models/entity.rb', line 16582 optional :sms, MethodRuby::Internal::Type::Unknown, nil?: true |
#sna ⇒ Object?
SNA verification details. Present when method is sna.
16588 |
# File 'lib/method_ruby/models/entity.rb', line 16588 optional :sna, MethodRuby::Internal::Type::Unknown, nil?: true |
#status ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession::Status
Current status of the verification session.
16516 16517 |
# File 'lib/method_ruby/models/entity.rb', line 16516 required :status, enum: -> { MethodRuby::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession::Status } |
#type ⇒ Symbol, MethodRuby::Models::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession::Type
The type of verification being performed.
16523 16524 |
# File 'lib/method_ruby/models/entity.rb', line 16523 required :type, enum: -> { MethodRuby::Entity::EntityIndividualResource::Verification::Phone::LatestVerificationSession::EntityVerificationSession::Type } |
#updated_at ⇒ Time
Timestamp when the verification session was last updated.
16530 |
# File 'lib/method_ruby/models/entity.rb', line 16530 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/entity.rb', line 16638
|