Class: MethodRuby::Models::ForwardingRequestCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::ForwardingRequestCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/method_ruby/models/forwarding_request_create_params.rb
Overview
Defined Under Namespace
Modules: Method, MethodVersion
Instance Attribute Summary collapse
-
#bindings ⇒ Hash{Symbol=>String}
Key-value map of secret bindings to inject into the request.
-
#body ⇒ String
Body to send with the forwarded request.
-
#headers ⇒ Hash{Symbol=>String}
HTTP headers to include in the forwarded request.
- #idempotency_key ⇒ String?
-
#metadata ⇒ Object?
Optional metadata to attach to the forwarding request.
-
#method_ ⇒ Symbol, MethodRuby::Models::ForwardingRequestCreateParams::Method
HTTP method to use.
- #method_version ⇒ Symbol, MethodRuby::Models::ForwardingRequestCreateParams::MethodVersion
-
#url ⇒ String
The destination URL for the forwarded request.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bindings:, body:, headers:, method_:, url:, method_version:, metadata: nil, idempotency_key: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/method_ruby/models/forwarding_request_create_params.rb', line 56
|
Instance Attribute Details
#bindings ⇒ Hash{Symbol=>String}
Key-value map of secret bindings to inject into the request.
14 |
# File 'lib/method_ruby/models/forwarding_request_create_params.rb', line 14 required :bindings, MethodRuby::Internal::Type::HashOf[String] |
#body ⇒ String
Body to send with the forwarded request.
20 |
# File 'lib/method_ruby/models/forwarding_request_create_params.rb', line 20 required :body, String |
#headers ⇒ Hash{Symbol=>String}
HTTP headers to include in the forwarded request.
26 |
# File 'lib/method_ruby/models/forwarding_request_create_params.rb', line 26 required :headers, MethodRuby::Internal::Type::HashOf[String] |
#idempotency_key ⇒ String?
54 |
# File 'lib/method_ruby/models/forwarding_request_create_params.rb', line 54 optional :idempotency_key, String |
#metadata ⇒ Object?
Optional metadata to attach to the forwarding request.
49 |
# File 'lib/method_ruby/models/forwarding_request_create_params.rb', line 49 optional :metadata, MethodRuby::Internal::Type::Unknown, nil?: true |
#method_ ⇒ Symbol, MethodRuby::Models::ForwardingRequestCreateParams::Method
HTTP method to use.
32 |
# File 'lib/method_ruby/models/forwarding_request_create_params.rb', line 32 required :method_, enum: -> { MethodRuby::ForwardingRequestCreateParams::Method }, api_name: :method |
#method_version ⇒ Symbol, MethodRuby::Models::ForwardingRequestCreateParams::MethodVersion
43 |
# File 'lib/method_ruby/models/forwarding_request_create_params.rb', line 43 required :method_version, enum: -> { MethodRuby::ForwardingRequestCreateParams::MethodVersion } |
#url ⇒ String
The destination URL for the forwarded request.
38 |
# File 'lib/method_ruby/models/forwarding_request_create_params.rb', line 38 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/forwarding_request_create_params.rb', line 85
|