Class: MethodRuby::Models::PaymentCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::PaymentCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/method_ruby/models/payment_create_params.rb
Overview
Defined Under Namespace
Modules: MethodVersion Classes: Fee
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Payment amount in cents.
-
#description ⇒ String
Human-readable description for the payment.
-
#destination ⇒ String
The destination account ID.
-
#dry_run ⇒ Boolean?
Validate the payment request without moving funds.
-
#fee ⇒ MethodRuby::Models::PaymentCreateParams::Fee?
Optional fee configuration for the payment.
- #idempotency_key ⇒ String?
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
- #method_version ⇒ Symbol, MethodRuby::Models::PaymentCreateParams::MethodVersion
-
#reversal_account ⇒ String?
Account ID to use for the reversal leg of the payment, if applicable.
-
#source ⇒ String
The source account ID.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from MethodRuby::Internal::Type::BaseModel
Instance Attribute Details
#amount ⇒ Integer
Payment amount in cents.
14 |
# File 'lib/method_ruby/models/payment_create_params.rb', line 14 required :amount, Integer |
#description ⇒ String
Human-readable description for the payment.
20 |
# File 'lib/method_ruby/models/payment_create_params.rb', line 20 required :description, String |
#destination ⇒ String
The destination account ID.
26 |
# File 'lib/method_ruby/models/payment_create_params.rb', line 26 required :destination, String |
#dry_run ⇒ Boolean?
Validate the payment request without moving funds.
43 |
# File 'lib/method_ruby/models/payment_create_params.rb', line 43 optional :dry_run, MethodRuby::Internal::Type::Boolean |
#fee ⇒ MethodRuby::Models::PaymentCreateParams::Fee?
Optional fee configuration for the payment.
49 |
# File 'lib/method_ruby/models/payment_create_params.rb', line 49 optional :fee, -> { MethodRuby::PaymentCreateParams::Fee } |
#idempotency_key ⇒ String?
66 |
# File 'lib/method_ruby/models/payment_create_params.rb', line 66 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
55 |
# File 'lib/method_ruby/models/payment_create_params.rb', line 55 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#method_version ⇒ Symbol, MethodRuby::Models::PaymentCreateParams::MethodVersion
37 |
# File 'lib/method_ruby/models/payment_create_params.rb', line 37 required :method_version, enum: -> { MethodRuby::PaymentCreateParams::MethodVersion } |
#reversal_account ⇒ String?
Account ID to use for the reversal leg of the payment, if applicable.
61 |
# File 'lib/method_ruby/models/payment_create_params.rb', line 61 optional :reversal_account, String |
#source ⇒ String
The source account ID.
32 |
# File 'lib/method_ruby/models/payment_create_params.rb', line 32 required :source, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/payment_create_params.rb', line 96
|