Class: MethodRuby::Models::PaymentListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::PaymentListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/method_ruby/models/payment_list_params.rb
Overview
Defined Under Namespace
Modules: Expand, MethodVersion, Status, Type
Instance Attribute Summary collapse
-
#acc_id ⇒ String?
Filter payments by either the source or destination account ID.
-
#destination ⇒ String?
Filter payments by destination account ID.
-
#destination_holder_id ⇒ String?
Filter payments by destination entity ID.
-
#expand ⇒ Array<Symbol, MethodRuby::Models::PaymentListParams::Expand>?
Expand payment source or destination accounts inline.
-
#from_date ⇒ Date?
Filter results from this date (inclusive, YYYY-MM-DD format).
-
#holder_id ⇒ String?
Filter payments by either the source or destination entity ID.
- #method_version ⇒ Symbol, MethodRuby::Models::PaymentListParams::MethodVersion
-
#page ⇒ Integer?
Page number for pagination (1-indexed).
-
#page_cursor ⇒ String?
Cursor for cursor-based pagination.
-
#page_limit ⇒ Integer?
Number of items per page.
-
#reversal_id ⇒ String?
Filter payments by reversal ID.
-
#source ⇒ String?
Filter payments by source account ID.
-
#source_holder_id ⇒ String?
Filter payments by source entity ID.
-
#status ⇒ Symbol, ...
Filter payments by status.
-
#to_date ⇒ Date?
Filter results to this date (inclusive, YYYY-MM-DD format).
-
#type ⇒ Symbol, ...
Filter payments by payment type.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from MethodRuby::Internal::Type::BaseModel
Instance Attribute Details
#acc_id ⇒ String?
Filter payments by either the source or destination account ID.
19 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 19 optional :acc_id, String |
#destination ⇒ String?
Filter payments by destination account ID.
25 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 25 optional :destination, String |
#destination_holder_id ⇒ String?
Filter payments by destination entity ID.
31 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 31 optional :destination_holder_id, String |
#expand ⇒ Array<Symbol, MethodRuby::Models::PaymentListParams::Expand>?
Expand payment source or destination accounts inline. Nested account expansion is supported for latest verification sessions on the source or destination.
38 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 38 optional :expand, -> { MethodRuby::Internal::Type::ArrayOf[enum: MethodRuby::PaymentListParams::Expand] } |
#from_date ⇒ Date?
Filter results from this date (inclusive, YYYY-MM-DD format).
44 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 44 optional :from_date, Date |
#holder_id ⇒ String?
Filter payments by either the source or destination entity ID.
50 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 50 optional :holder_id, String |
#method_version ⇒ Symbol, MethodRuby::Models::PaymentListParams::MethodVersion
13 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 13 required :method_version, enum: -> { MethodRuby::PaymentListParams::MethodVersion } |
#page ⇒ Integer?
Page number for pagination (1-indexed).
56 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 56 optional :page, Integer |
#page_cursor ⇒ String?
Cursor for cursor-based pagination. Use the value from ‘Pagination-Page-Cursor-Next` or `Pagination-Page-Cursor-Prev` response headers.
63 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 63 optional :page_cursor, String |
#page_limit ⇒ Integer?
Number of items per page.
69 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 69 optional :page_limit, Integer |
#reversal_id ⇒ String?
Filter payments by reversal ID.
75 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 75 optional :reversal_id, String |
#source ⇒ String?
Filter payments by source account ID.
81 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 81 optional :source, String |
#source_holder_id ⇒ String?
Filter payments by source entity ID.
87 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 87 optional :source_holder_id, String |
#status ⇒ Symbol, ...
Filter payments by status.
93 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 93 optional :status, enum: -> { MethodRuby::PaymentListParams::Status } |
#to_date ⇒ Date?
Filter results to this date (inclusive, YYYY-MM-DD format).
99 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 99 optional :to_date, Date |
#type ⇒ Symbol, ...
Filter payments by payment type.
105 |
# File 'lib/method_ruby/models/payment_list_params.rb', line 105 optional :type, enum: -> { MethodRuby::PaymentListParams::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/payment_list_params.rb', line 150
|