Module: MethodRuby::Models::PaymentListParams::MethodVersion

Extended by:
Internal::Type::Enum
Defined in:
lib/method_ruby/models/payment_list_params.rb

Constant Summary collapse

METHOD_VERSION_2025_12_01 =
:"2025-12-01"

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(method_version:, acc_id: nil, destination: nil, destination_holder_id: nil, expand: nil, from_date: nil, holder_id: nil, page: nil, page_cursor: nil, page_limit: nil, reversal_id: nil, source: nil, source_holder_id: nil, status: nil, to_date: nil, type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see MethodRuby::Models::PaymentListParams for more details.

Parameters:

  • method_version (Symbol, MethodRuby::Models::PaymentListParams::MethodVersion)
  • acc_id (String) (defaults to: nil)

    Filter payments by either the source or destination account ID.

  • destination (String) (defaults to: nil)

    Filter payments by destination account ID.

  • destination_holder_id (String) (defaults to: nil)

    Filter payments by destination entity ID.

  • expand (Array<Symbol, MethodRuby::Models::PaymentListParams::Expand>) (defaults to: nil)

    Expand payment source or destination accounts inline. Nested account expansion

  • from_date (Date) (defaults to: nil)

    Filter results from this date (inclusive, YYYY-MM-DD format).

  • holder_id (String) (defaults to: nil)

    Filter payments by either the source or destination entity ID.

  • page (Integer) (defaults to: nil)

    Page number for pagination (1-indexed).

  • page_cursor (String) (defaults to: nil)

    Cursor for cursor-based pagination. Use the value from ‘Pagination-Page-Cursor-N

  • page_limit (Integer) (defaults to: nil)

    Number of items per page.

  • reversal_id (String) (defaults to: nil)

    Filter payments by reversal ID.

  • source (String) (defaults to: nil)

    Filter payments by source account ID.

  • source_holder_id (String) (defaults to: nil)

    Filter payments by source entity ID.

  • status (Symbol, MethodRuby::Models::PaymentListParams::Status) (defaults to: nil)

    Filter payments by status.

  • to_date (Date) (defaults to: nil)

    Filter results to this date (inclusive, YYYY-MM-DD format).

  • type (Symbol, MethodRuby::Models::PaymentListParams::Type) (defaults to: nil)

    Filter payments by payment type.

  • request_options (MethodRuby::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


145
146
147
148
149
150
151
152
# File 'lib/method_ruby/models/payment_list_params.rb', line 145

module MethodVersion
  extend MethodRuby::Internal::Type::Enum

  METHOD_VERSION_2025_12_01 = :"2025-12-01"

  # @!method self.values
  #   @return [Array<Symbol>]
end