Class: MethodRuby::Models::Simulate::Entities::CreditScoreCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::Simulate::Entities::CreditScoreCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/method_ruby/models/simulate/entities/credit_score_create_params.rb,
sig/method_ruby/models/simulate/entities/credit_score_create_params.rbs
Overview
Defined Under Namespace
Modules: MethodVersion
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::MethodRuby
Instance Attribute Summary collapse
- #crs_id ⇒ String
- #entity_id ⇒ String
- #method_version ⇒ Symbol, MethodRuby::Models::Simulate::Entities::CreditScoreCreateParams::MethodVersion
-
#score ⇒ Integer
The credit score value to simulate.
-
#status ⇒ String?
The status to set on the credit score resource.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
31 |
# File 'sig/method_ruby/models/simulate/entities/credit_score_create_params.rbs', line 31 def initialize: ( |
Instance Attribute Details
#crs_id ⇒ String
20 |
# File 'lib/method_ruby/models/simulate/entities/credit_score_create_params.rb', line 20 required :crs_id, String |
#entity_id ⇒ String
15 |
# File 'lib/method_ruby/models/simulate/entities/credit_score_create_params.rb', line 15 required :entity_id, String |
#method_version ⇒ Symbol, MethodRuby::Models::Simulate::Entities::CreditScoreCreateParams::MethodVersion
31 32 |
# File 'lib/method_ruby/models/simulate/entities/credit_score_create_params.rb', line 31 required :method_version, enum: -> { MethodRuby::Simulate::Entities::CreditScoreCreateParams::MethodVersion } |
#score ⇒ Integer
The credit score value to simulate.
26 |
# File 'lib/method_ruby/models/simulate/entities/credit_score_create_params.rb', line 26 required :score, Integer |
#status ⇒ String?
The status to set on the credit score resource.
38 |
# File 'lib/method_ruby/models/simulate/entities/credit_score_create_params.rb', line 38 optional :status, String |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/method_ruby/models/simulate/entities/credit_score_create_params.rbs', line 40 def to_hash: -> { |