Class: MethodRuby::Models::WebhookCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/method_ruby/models/webhook_create_params.rb

Overview

Defined Under Namespace

Modules: MethodVersion, Type

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, url:, method_version:, auth_token: nil, expand_event: nil, hmac_secret: nil, metadata: nil, idempotency_key: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see MethodRuby::Models::WebhookCreateParams for more details.

Parameters:

  • type (Symbol, MethodRuby::Models::WebhookCreateParams::Type)

    The event type this webhook subscribes to.

  • url (String)

    URL to receive webhook events.

  • method_version (Symbol, MethodRuby::Models::WebhookCreateParams::MethodVersion)
  • auth_token (String) (defaults to: nil)

    Authentication token to include in outbound webhook request headers. This value

  • expand_event (Boolean) (defaults to: nil)

    Whether to include the full resource data in the webhook payload.

  • hmac_secret (String) (defaults to: nil)

    HMAC secret used to sign outbound webhook deliveries. This value is write-only.

  • metadata (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Arbitrary key-value metadata attached to the resource.

  • idempotency_key (String) (defaults to: nil)
  • request_options (MethodRuby::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/method_ruby/models/webhook_create_params.rb', line 57

Instance Attribute Details

#auth_tokenString?

Authentication token to include in outbound webhook request headers. This value is write-only.

Returns:

  • (String, nil)


32
# File 'lib/method_ruby/models/webhook_create_params.rb', line 32

optional :auth_token, String

#expand_eventBoolean?

Whether to include the full resource data in the webhook payload.

Returns:

  • (Boolean, nil)


38
# File 'lib/method_ruby/models/webhook_create_params.rb', line 38

optional :expand_event, MethodRuby::Internal::Type::Boolean

#hmac_secretString?

HMAC secret used to sign outbound webhook deliveries. This value is write-only.

Returns:

  • (String, nil)


44
# File 'lib/method_ruby/models/webhook_create_params.rb', line 44

optional :hmac_secret, String

#idempotency_keyString?

Returns:

  • (String, nil)


55
# File 'lib/method_ruby/models/webhook_create_params.rb', line 55

optional :idempotency_key, String

#metadataHash{Symbol=>Object}?

Arbitrary key-value metadata attached to the resource.

Returns:

  • (Hash{Symbol=>Object}, nil)


50
# File 'lib/method_ruby/models/webhook_create_params.rb', line 50

optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true

#method_versionSymbol, MethodRuby::Models::WebhookCreateParams::MethodVersion



25
# File 'lib/method_ruby/models/webhook_create_params.rb', line 25

required :method_version, enum: -> { MethodRuby::WebhookCreateParams::MethodVersion }

#typeSymbol, MethodRuby::Models::WebhookCreateParams::Type

The event type this webhook subscribes to.



14
# File 'lib/method_ruby/models/webhook_create_params.rb', line 14

required :type, enum: -> { MethodRuby::WebhookCreateParams::Type }

#urlString

URL to receive webhook events.

Returns:

  • (String)


20
# File 'lib/method_ruby/models/webhook_create_params.rb', line 20

required :url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/webhook_create_params.rb', line 189