Class: MethodRuby::Resources::Accounts::Balances

Inherits:
Object
  • Object
show all
Defined in:
lib/method_ruby/resources/accounts/balances.rb

Overview

Balance data for accounts

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Balances

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Balances.

Parameters:



116
117
118
# File 'lib/method_ruby/resources/accounts/balances.rb', line 116

def initialize(client:)
  @client = client
end

Instance Method Details

#create(account_id, method_version:, idempotency_key: nil, request_options: {}) ⇒ MethodRuby::Models::Accounts::BalanceCreateResponse

Some parameter documentations has been truncated, see Models::Accounts::BalanceCreateParams for more details.

Triggers a balance sync for the specified account and returns the new balance record.

Parameters:

Returns:

See Also:



27
28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/method_ruby/resources/accounts/balances.rb', line 27

def create(, params)
  parsed, options = MethodRuby::Accounts::BalanceCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: ["accounts/%1$s/balances", ],
    headers: parsed.transform_keys(
      method_version: "method-version",
      idempotency_key: "idempotency-key"
    ),
    model: MethodRuby::Models::Accounts::BalanceCreateResponse,
    security: {secret_key: true},
    options: options
  )
end

#list(account_id, method_version:, page: nil, page_cursor: nil, page_limit: nil, request_options: {}) ⇒ MethodRuby::Models::Accounts::BalanceListResponse

Some parameter documentations has been truncated, see Models::Accounts::BalanceListParams for more details.

Returns a list of balance records for the specified account.

Parameters:

  • account_id (String)

    Path param: Unique identifier for the account.

  • method_version (Symbol, MethodRuby::Models::Accounts::BalanceListParams::MethodVersion)

    Header param: API version to use for this request. This spec targets ‘2025-12-01

  • page (Integer)

    Query param: Page number for pagination (1-indexed).

  • page_cursor (String)

    Query param: Cursor for cursor-based pagination. Use the value from ‘Pagination-

  • page_limit (Integer)

    Query param: Number of items per page.

  • request_options (MethodRuby::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/method_ruby/resources/accounts/balances.rb', line 98

def list(, params)
  query_params = [:page, :page_cursor, :page_limit]
  parsed, options = MethodRuby::Accounts::BalanceListParams.dump_request(params)
  query = MethodRuby::Internal::Util.encode_query_params(parsed.slice(*query_params))
  @client.request(
    method: :get,
    path: ["accounts/%1$s/balances", ],
    query: query,
    headers: parsed.except(*query_params).transform_keys(method_version: "method-version"),
    model: MethodRuby::Models::Accounts::BalanceListResponse,
    security: {secret_key: true},
    options: options
  )
end

#retrieve(bal_id, account_id:, method_version:, request_options: {}) ⇒ MethodRuby::Models::Accounts::BalanceRetrieveResponse

Some parameter documentations has been truncated, see Models::Accounts::BalanceRetrieveParams for more details.

Retrieves an account balance by its unique identifier.

Parameters:

Returns:

See Also:



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/method_ruby/resources/accounts/balances.rb', line 60

def retrieve(bal_id, params)
  parsed, options = MethodRuby::Accounts::BalanceRetrieveParams.dump_request(params)
   =
    parsed.delete(:account_id) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :get,
    path: ["accounts/%1$s/balances/%2$s", , bal_id],
    headers: parsed.transform_keys(method_version: "method-version"),
    model: MethodRuby::Models::Accounts::BalanceRetrieveResponse,
    security: {secret_key: true},
    options: options
  )
end