Class: MethodRuby::Resources::Accounts::Sensitive

Inherits:
Object
  • Object
show all
Defined in:
lib/method_ruby/resources/accounts/sensitive.rb

Overview

Sensitive data for accounts

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Sensitive

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Sensitive.

Parameters:



116
117
118
# File 'lib/method_ruby/resources/accounts/sensitive.rb', line 116

def initialize(client:)
  @client = client
end

Instance Method Details

#create(account_id, expand:, method_version:, idempotency_key: nil, request_options: {}) ⇒ MethodRuby::Models::Accounts::SensitiveCreateResponse

Some parameter documentations has been truncated, see Models::Accounts::SensitiveCreateParams for more details.

Creates a new sensitive data request for the specified account.

Parameters:

  • account_id (String)

    Path param: Unique identifier for the account.

  • expand (Array<String>)

    Body param: List of sensitive field names to retrieve.

  • method_version (Symbol, MethodRuby::Models::Accounts::SensitiveCreateParams::MethodVersion)

    Header param: API version to use for this request. This spec targets ‘2025-12-01

  • idempotency_key (String)

    Header param: Idempotency key for safely retrying a write request. Reuse the sam

  • request_options (MethodRuby::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/method_ruby/resources/accounts/sensitive.rb', line 28

def create(, params)
  parsed, options = MethodRuby::Accounts::SensitiveCreateParams.dump_request(params)
  header_params = {method_version: "method-version", idempotency_key: "idempotency-key"}
  @client.request(
    method: :post,
    path: ["accounts/%1$s/sensitive", ],
    headers: parsed.slice(*header_params.keys).transform_keys(header_params),
    body: parsed.except(*header_params.keys),
    model: MethodRuby::Models::Accounts::SensitiveCreateResponse,
    security: {secret_key: true},
    options: options
  )
end

#list(account_id, method_version:, page: nil, page_cursor: nil, page_limit: nil, request_options: {}) ⇒ MethodRuby::Models::Accounts::SensitiveListResponse

Some parameter documentations has been truncated, see Models::Accounts::SensitiveListParams for more details.

Returns a list of sensitive data records for the specified account.

Parameters:

  • account_id (String)

    Path param: Unique identifier for the account.

  • method_version (Symbol, MethodRuby::Models::Accounts::SensitiveListParams::MethodVersion)

    Header param: API version to use for this request. This spec targets ‘2025-12-01

  • page (Integer)

    Query param: Page number for pagination (1-indexed).

  • page_cursor (String)

    Query param: Cursor for cursor-based pagination. Use the value from ‘Pagination-

  • page_limit (Integer)

    Query param: Number of items per page.

  • request_options (MethodRuby::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/method_ruby/resources/accounts/sensitive.rb', line 98

def list(, params)
  query_params = [:page, :page_cursor, :page_limit]
  parsed, options = MethodRuby::Accounts::SensitiveListParams.dump_request(params)
  query = MethodRuby::Internal::Util.encode_query_params(parsed.slice(*query_params))
  @client.request(
    method: :get,
    path: ["accounts/%1$s/sensitive", ],
    query: query,
    headers: parsed.except(*query_params).transform_keys(method_version: "method-version"),
    model: MethodRuby::Models::Accounts::SensitiveListResponse,
    security: {secret_key: true},
    options: options
  )
end

#retrieve(astv_id, account_id:, method_version:, request_options: {}) ⇒ MethodRuby::Models::Accounts::SensitiveRetrieveResponse

Some parameter documentations has been truncated, see Models::Accounts::SensitiveRetrieveParams for more details.

Retrieves an account sensitive record by its unique identifier.

Parameters:

Returns:

See Also:



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/method_ruby/resources/accounts/sensitive.rb', line 60

def retrieve(astv_id, params)
  parsed, options = MethodRuby::Accounts::SensitiveRetrieveParams.dump_request(params)
   =
    parsed.delete(:account_id) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :get,
    path: ["accounts/%1$s/sensitive/%2$s", , astv_id],
    headers: parsed.transform_keys(method_version: "method-version"),
    model: MethodRuby::Models::Accounts::SensitiveRetrieveResponse,
    security: {secret_key: true},
    options: options
  )
end