Class: MethodRuby::Resources::Simulate::Accounts::CardBrands
- Inherits:
-
Object
- Object
- MethodRuby::Resources::Simulate::Accounts::CardBrands
- Defined in:
- lib/method_ruby/resources/simulate/accounts/card_brands.rb
Overview
Sandbox account simulation
Instance Method Summary collapse
-
#create(account_id, method_version:, request_options: {}) ⇒ MethodRuby::Models::Simulate::Accounts::CardBrandCreateResponse
Some parameter documentations has been truncated, see Models::Simulate::Accounts::CardBrandCreateParams for more details.
-
#initialize(client:) ⇒ CardBrands
constructor
private
A new instance of CardBrands.
Constructor Details
#initialize(client:) ⇒ CardBrands
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of CardBrands.
45 46 47 |
# File 'lib/method_ruby/resources/simulate/accounts/card_brands.rb', line 45 def initialize(client:) @client = client end |
Instance Method Details
#create(account_id, method_version:, request_options: {}) ⇒ MethodRuby::Models::Simulate::Accounts::CardBrandCreateResponse
Some parameter documentations has been truncated, see Models::Simulate::Accounts::CardBrandCreateParams for more details.
Creates a simulated card brand result for an account in the sandbox environment. Use this to test card brand retrieval flows during development.
**Development only** - This endpoint is only available in the sandbox environment.
30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/method_ruby/resources/simulate/accounts/card_brands.rb', line 30 def create(account_id, params) parsed, = MethodRuby::Simulate::Accounts::CardBrandCreateParams.dump_request(params) @client.request( method: :post, path: ["simulate/accounts/%1$s/card_brands", account_id], headers: parsed.transform_keys(method_version: "method-version"), model: MethodRuby::Models::Simulate::Accounts::CardBrandCreateResponse, security: {secret_key: true}, options: ) end |