Class: MethodRuby::Models::AccountCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/method_ruby/models/account_create_params.rb

Overview

Defined Under Namespace

Modules: Body, MethodVersion

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(body:, method_version:, idempotency_key: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see MethodRuby::Models::AccountCreateParams for more details.

Parameters:



# File 'lib/method_ruby/models/account_create_params.rb', line 28

Instance Attribute Details

#bodyMethodRuby::Models::AccountCreateParams::Body::ACH, ...

Request body for creating an account. ‘type` is recommended and used for discrimination in generated clients, but the API can also infer the account type from the nested object you provide.



16
# File 'lib/method_ruby/models/account_create_params.rb', line 16

required :body, union: -> { MethodRuby::AccountCreateParams::Body }

#idempotency_keyString?

Returns:

  • (String, nil)


26
# File 'lib/method_ruby/models/account_create_params.rb', line 26

optional :idempotency_key, String

#method_versionSymbol, MethodRuby::Models::AccountCreateParams::MethodVersion



21
# File 'lib/method_ruby/models/account_create_params.rb', line 21

required :method_version, enum: -> { MethodRuby::AccountCreateParams::MethodVersion }