Class: MethodRuby::Models::AccountCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::AccountCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/method_ruby/models/account_create_params.rb
Overview
Defined Under Namespace
Modules: Body, MethodVersion
Instance Attribute Summary collapse
-
#body ⇒ MethodRuby::Models::AccountCreateParams::Body::ACH, ...
Request body for creating an account.
- #idempotency_key ⇒ String?
- #method_version ⇒ Symbol, MethodRuby::Models::AccountCreateParams::MethodVersion
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(MethodRuby::Models::AccountCreateParams::Body::ACH, MethodRuby::Models::AccountCreateParams::Body::Liability, MethodRuby::Models::AccountCreateParams::Body::Clearing, MethodRuby::Models::AccountCreateParams::Body::DebitCard)
Instance Method Summary collapse
-
#initialize(body:, method_version:, idempotency_key: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccountCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(body:, method_version:, idempotency_key: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see MethodRuby::Models::AccountCreateParams for more details.
|
|
# File 'lib/method_ruby/models/account_create_params.rb', line 28
|
Instance Attribute Details
#body ⇒ MethodRuby::Models::AccountCreateParams::Body::ACH, ...
Request body for creating an account. ‘type` is recommended and used for discrimination in generated clients, but the API can also infer the account type from the nested object you provide.
16 |
# File 'lib/method_ruby/models/account_create_params.rb', line 16 required :body, union: -> { MethodRuby::AccountCreateParams::Body } |
#idempotency_key ⇒ String?
26 |
# File 'lib/method_ruby/models/account_create_params.rb', line 26 optional :idempotency_key, String |
#method_version ⇒ Symbol, MethodRuby::Models::AccountCreateParams::MethodVersion
21 |
# File 'lib/method_ruby/models/account_create_params.rb', line 21 required :method_version, enum: -> { MethodRuby::AccountCreateParams::MethodVersion } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/account_create_params.rb', line 423
|
.variants ⇒ Array(MethodRuby::Models::AccountCreateParams::Body::ACH, MethodRuby::Models::AccountCreateParams::Body::Liability, MethodRuby::Models::AccountCreateParams::Body::Clearing, MethodRuby::Models::AccountCreateParams::Body::DebitCard)
|
|
# File 'lib/method_ruby/models/account_create_params.rb', line 428
|