Class: MethodRuby::Models::Accounts::ConsentWithdrawResponse::Data::AccountClearingResource::LatestVerificationSession::AccountVerificationSession

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/method_ruby/models/accounts/consent_withdraw_response.rb

Defined Under Namespace

Modules: Status, Type Classes: Error, Instant, MicroDeposits, Mx, Network, Plaid, PreAuth, Standard, Teller

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(number: nil) ⇒ Object

Populated when the verification session is of type standard.

Parameters:

  • number (String, nil) (defaults to: nil)

    The masked card number. Null if the number still needs to be provided.



# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8351

Instance Attribute Details

#account_idString

The account this verification session belongs to.

Returns:

  • (String)


8239
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8239

required :account_id, String

#auto_verifyObject?

Populated when the verification session is of type auto_verify.

Returns:

  • (Object, nil)


8271
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8271

optional :auto_verify, MethodRuby::Internal::Type::Unknown, nil?: true

#created_atTime

Timestamp when the verification session was created.

Returns:

  • (Time)


8245
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8245

required :created_at, Time

#idString

Unique identifier for the verification session.

Returns:

  • (String)


8233
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8233

required :id, String

#trusted_provisionerObject?

Populated when the verification session is of type trusted_provisioner.

Returns:

  • (Object, nil)


8349
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8349

optional :trusted_provisioner, MethodRuby::Internal::Type::Unknown, nil?: true

#updated_atTime

Timestamp when the verification session was last updated.

Returns:

  • (Time)


8265
# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8265

required :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/method_ruby/models/accounts/consent_withdraw_response.rb', line 8399