Class: MethodRuby::Models::WebhookCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MethodRuby::Models::WebhookCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/method_ruby/models/webhook_create_params.rb
Overview
Defined Under Namespace
Modules: MethodVersion, Type
Instance Attribute Summary collapse
-
#auth_token ⇒ String?
Authentication token to include in outbound webhook request headers.
-
#expand_event ⇒ Boolean?
Whether to include the full resource data in the webhook payload.
-
#hmac_secret ⇒ String?
HMAC secret used to sign outbound webhook deliveries.
- #idempotency_key ⇒ String?
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
- #method_version ⇒ Symbol, MethodRuby::Models::WebhookCreateParams::MethodVersion
-
#type ⇒ Symbol, MethodRuby::Models::WebhookCreateParams::Type
The event type this webhook subscribes to.
-
#url ⇒ String
URL to receive webhook events.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type:, url:, method_version:, auth_token: nil, expand_event: nil, hmac_secret: nil, metadata: nil, idempotency_key: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebhookCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, url:, method_version:, auth_token: nil, expand_event: nil, hmac_secret: nil, metadata: nil, idempotency_key: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see MethodRuby::Models::WebhookCreateParams for more details.
|
|
# File 'lib/method_ruby/models/webhook_create_params.rb', line 57
|
Instance Attribute Details
#auth_token ⇒ String?
Authentication token to include in outbound webhook request headers. This value is write-only.
32 |
# File 'lib/method_ruby/models/webhook_create_params.rb', line 32 optional :auth_token, String |
#expand_event ⇒ Boolean?
Whether to include the full resource data in the webhook payload.
38 |
# File 'lib/method_ruby/models/webhook_create_params.rb', line 38 optional :expand_event, MethodRuby::Internal::Type::Boolean |
#hmac_secret ⇒ String?
HMAC secret used to sign outbound webhook deliveries. This value is write-only.
44 |
# File 'lib/method_ruby/models/webhook_create_params.rb', line 44 optional :hmac_secret, String |
#idempotency_key ⇒ String?
55 |
# File 'lib/method_ruby/models/webhook_create_params.rb', line 55 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key-value metadata attached to the resource.
50 |
# File 'lib/method_ruby/models/webhook_create_params.rb', line 50 optional :metadata, MethodRuby::Internal::Type::HashOf[MethodRuby::Internal::Type::Unknown], nil?: true |
#method_version ⇒ Symbol, MethodRuby::Models::WebhookCreateParams::MethodVersion
25 |
# File 'lib/method_ruby/models/webhook_create_params.rb', line 25 required :method_version, enum: -> { MethodRuby::WebhookCreateParams::MethodVersion } |
#type ⇒ Symbol, MethodRuby::Models::WebhookCreateParams::Type
The event type this webhook subscribes to.
14 |
# File 'lib/method_ruby/models/webhook_create_params.rb', line 14 required :type, enum: -> { MethodRuby::WebhookCreateParams::Type } |
#url ⇒ String
URL to receive webhook events.
20 |
# File 'lib/method_ruby/models/webhook_create_params.rb', line 20 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/method_ruby/models/webhook_create_params.rb', line 189
|