Class: MethodRuby::Resources::Simulate::Accounts::VerificationSessions::Amounts
- Inherits:
-
Object
- Object
- MethodRuby::Resources::Simulate::Accounts::VerificationSessions::Amounts
- Defined in:
- lib/method_ruby/resources/simulate/accounts/verification_sessions/amounts.rb
Overview
Sandbox account simulation
Instance Method Summary collapse
-
#initialize(client:) ⇒ Amounts
constructor
private
A new instance of Amounts.
-
#retrieve(avf_id, account_id:, method_version:, request_options: {}) ⇒ MethodRuby::Models::Simulate::Accounts::VerificationSessions::AmountRetrieveResponse
Some parameter documentations has been truncated, see Models::Simulate::Accounts::VerificationSessions::AmountRetrieveParams for more details.
Constructor Details
#initialize(client:) ⇒ Amounts
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Amounts.
54 55 56 |
# File 'lib/method_ruby/resources/simulate/accounts/verification_sessions/amounts.rb', line 54 def initialize(client:) @client = client end |
Instance Method Details
#retrieve(avf_id, account_id:, method_version:, request_options: {}) ⇒ MethodRuby::Models::Simulate::Accounts::VerificationSessions::AmountRetrieveResponse
Some parameter documentations has been truncated, see Models::Simulate::Accounts::VerificationSessions::AmountRetrieveParams for more details.
Returns the micro-deposit amounts for a verification session in the sandbox environment. Use this to retrieve the test amounts needed to complete micro-deposit verification during development.
**Development only** - This endpoint is only available in the sandbox environment.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/method_ruby/resources/simulate/accounts/verification_sessions/amounts.rb', line 34 def retrieve(avf_id, params) parsed, = MethodRuby::Simulate::Accounts::VerificationSessions::AmountRetrieveParams.dump_request(params) account_id = parsed.delete(:account_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["simulate/accounts/%1$s/verification_sessions/%2$s/amounts", account_id, avf_id], headers: parsed.transform_keys(method_version: "method-version"), model: MethodRuby::Models::Simulate::Accounts::VerificationSessions::AmountRetrieveResponse, security: {secret_key: true}, options: ) end |