Class: MethodRuby::Resources::Simulate::Entities::Attributes
- Inherits:
-
Object
- Object
- MethodRuby::Resources::Simulate::Entities::Attributes
- Defined in:
- lib/method_ruby/resources/simulate/entities/attributes.rb
Overview
Sandbox entity simulation
Instance Method Summary collapse
-
#create(entity_id, method_version:, request_options: {}) ⇒ MethodRuby::Models::Simulate::Entities::AttributeCreateResponse
Some parameter documentations has been truncated, see Models::Simulate::Entities::AttributeCreateParams for more details.
-
#initialize(client:) ⇒ Attributes
constructor
private
A new instance of Attributes.
Constructor Details
#initialize(client:) ⇒ Attributes
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Attributes.
45 46 47 |
# File 'lib/method_ruby/resources/simulate/entities/attributes.rb', line 45 def initialize(client:) @client = client end |
Instance Method Details
#create(entity_id, method_version:, request_options: {}) ⇒ MethodRuby::Models::Simulate::Entities::AttributeCreateResponse
Some parameter documentations has been truncated, see Models::Simulate::Entities::AttributeCreateParams for more details.
Simulates attribute data for an entity in the sandbox environment. Use this to test attribute retrieval flows during development.
**Development only** - This endpoint is only available in the sandbox environment.
30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/method_ruby/resources/simulate/entities/attributes.rb', line 30 def create(entity_id, params) parsed, = MethodRuby::Simulate::Entities::AttributeCreateParams.dump_request(params) @client.request( method: :post, path: ["simulate/entities/%1$s/attributes", entity_id], headers: parsed.transform_keys(method_version: "method-version"), model: MethodRuby::Models::Simulate::Entities::AttributeCreateResponse, security: {secret_key: true}, options: ) end |